@@ -4,6 +4,7 @@
 #include <versekey.h>
 #include <treekeyidx.h>
 #include <swbuf.h>
+#include <localemgr.h>
 
 /*
 char* swordorb::SWModule_impl::helloWorld(const char* greeting) throw(CORBA::SystemException) {
@@ -105,6 +106,9 @@ CORBA::Boolean SWMgr_impl::testConnection() throw(CORBA::SystemException) {
 	return true;
 }
 
+void SWMgr_impl::setJavascript(CORBA::Boolean val) throw(CORBA::SystemException) {
+	delegate->setJavascript(val);
+}
 
 char *SWModule_impl::getCategory() throw(CORBA::SystemException) {
 	SWBuf type = delegate->Type();
@@ -122,6 +126,8 @@ SearchHitList *SWModule_impl::search(const char *istr, SearchType searchType, CO
 	if (searchType == REGEX) stype = 0;
 	if (searchType == PHRASE) stype = -1;
 	if (searchType == MULTIWORD) stype = -2;
+	if (searchType == ENTRYATTR) stype = -3;
+	if (searchType == LUCENE) stype = -4;
 	sword::ListKey result;
 
 	if ((scope) && (strlen(scope)) > 0) {
@@ -145,7 +151,6 @@ SearchHitList *SWModule_impl::search(const char *istr, SearchType searchType, CO
 }
 
 
-
 StringList *SWModule_impl::getEntryAttribute(const char *level1, const char *level2, const char *level3) throw(CORBA::SystemException) {
 	delegate->RenderText();	// force parse
 	sword::AttributeTypeList &entryAttribs = delegate->getEntryAttributes();
@@ -228,4 +233,25 @@ StringList *SWModule_impl::getKeyChildren() throw(CORBA::SystemException) {
 	return retVal;
 }
 
+
+StringList *SWMgr_impl::getAvailableLocales() throw(CORBA::SystemException) {
+	sword::StringList localeNames = LocaleMgr::getSystemLocaleMgr()->getAvailableLocales();
+	StringList *retVal = new StringList;
+	int count = 0;
+	for (sword::StringList::iterator it = localeNames.begin(); it != localeNames.end(); it++) {
+		count++;
+	}
+	retVal->length(count);
+	count = 0;
+	for (sword::StringList::iterator it = localeNames.begin(); it != localeNames.end(); it++) {
+		(*retVal)[count++] = CORBA::string_dup(it->c_str());
+	}
+	return retVal;
+}
+
+
+void SWMgr_impl::setDefaultLocale(const char *name) throw(CORBA::SystemException) {
+	LocaleMgr::getSystemLocaleMgr()->setDefaultLocaleName(name);
+}
+
 }
