@@ -3,6 +3,7 @@
 #include "swordorb-cpp-stubs.h"
 #include "swordorb-cpp-common.h"
 #include <iostream>
+#include <swbuf.h>
 	
 int main (int argc, char *argv[])
 {
@@ -30,26 +31,40 @@ int main (int argc, char *argv[])
 		std::cout << "Connected: "  << mgr->testConnection() << "\n";
 		std::cout << "PrefixPath: " << mgr->getPrefixPath() << "\n";
 		std::cout << "ConfigPath: " << mgr->getConfigPath() << "\n";
-		modInfoList = mgr->getModInfoList();
-		std::cout << "sequence length: " << modInfoList->length() << "\n";
+//		modInfoList = mgr->getModInfoList();
+//		std::cout << "sequence length: " << modInfoList->length() << "\n";
 /*
 		for (int i = 0; i < modInfoList->length(); i++) {
 			std::cout << (*modInfoList)[i].name << ": " << (*modInfoList)[i].category << ": " << (*modInfoList)[i].language << "\n";
-			module = mgr->getModuleByName((*modInfoList)[i].name);
-			module->setKeyText("jas1:19");
-			std::cout << module->getRenderText() << "\n";
+			if (!strncmp((*modInfoList)[i].category, "Bibl", 4)) {
+				module = mgr->getModuleByName((*modInfoList)[i].name);
+				module->setKeyText("jas1:19");
+				std::cout << module->getRenderText() << "\n";
+			}
+			std::cout << "\n";
 		}
 */
-		module = mgr->getModuleByName("NASB");
-		module->setKeyText("jn3:1");
-		std::cout << module->getRenderText();
-		/*
+		swordorb::StringList *localeNames = mgr->getAvailableLocales();
+		for (int i = 0; i < localeNames->length(); i++) {
+			std::cout << (*localeNames)[i] << "\n";
+		}
+		mgr->setDefaultLocale("de");
+		mgr->setJavascript(true);
+		mgr->setGlobalOption("Textual Variants", "Secondary Reading");
+		module = mgr->getModuleByName("WHNU");
+		for (module->setKeyText("jas.1.1"); !module->error(); module->next()) {
+			std::cout << "KeyText: " << module->getKeyText() << "\n";
+			std::cout << "Text: " << module->getRenderText() << "\n";
+			break;
+		}
+/*
 		swordorb::SearchHitList *searchResults;
-		searchResults = module->search("God love world", swordorb::MULTIWORD, 0, "");
+		bool lucene = module->hasSearchFramework();
+		searchResults = module->search("God love world", (lucene)?swordorb::LUCENE:swordorb::MULTIWORD, 0, "");
 		for (int i = 0; i < searchResults->length(); i++) {
 			std::cout << (*searchResults)[i].key << "\n";
 		}
-		*/;
+*/
 
 
 		
