@@ -1,11 +1,27 @@
 /******************************************************************************
- *	swordapi.cpp	- This file contains an api usable by non-C++ windows
+ *	swordapi.cpp	- This file contains an api usable by non-C++
  *					environments
+ *
+ * $Id: flatapi.cpp 1685 2004-12-22 07:05:49Z scribe $
+ *
+ * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
-#include <string.h>
 #include <stdio.h>
-
+ 
 #include <rawtext.h>
 #include <rawcom.h>
 #include <rawld.h>
@@ -32,8 +48,8 @@ typedef struct {
 //-----------------------------------------------------------------
 // SWMgr methods
 //
-extern "C" SWHANDLE SWMgr_new() {
-	return (SWHANDLE) new SWMgr(new MarkupFilterMgr());
+extern "C" SWHANDLE SWMgr_new(char filterType) { 
+	return (SWHANDLE) new SWMgr(new MarkupFilterMgr(filterType));
 }
 
 
@@ -113,9 +129,11 @@ const char *SWMgr_getGlobalOptionTip(SWHANDLE hmgr, const char *option) {
 SWHANDLE SWMgr_getGlobalOptionsIterator(SWHANDLE hmgr) {
 	SWMgr *mgr = (SWMgr *)hmgr;
 	static StringList::iterator it;
-	
-	if (mgr) 
-		it = mgr->getGlobalOptions().begin();
+	static StringList optionslist;
+	if (mgr) {
+		optionslist = mgr->getGlobalOptions();
+		it = optionslist.begin();
+	}
 	return (SWHANDLE)&it;
 }
 
@@ -151,6 +169,19 @@ void SWModule_terminateSearch(SWHANDLE hmodule) {
 // SWModule (const const char *imodname = 0, const const char *imoddesc = 0, SWDisplay * idisp = 0, const char *imodtype = 0, SWTextEncoding encoding = ENC_UNKNOWN, SWTextDirection dir = DIRECTION_LTR, SWTextMarkup markup = FMT_UNKNOWN, const char* modlang = 0);
 // virtual ~ SWModule ();
 
+SWHANDLE SWModule_doSearch(SWHANDLE hmodule, const char *searchString, int type, int params ,void (*percent) (char, void *), void *percentUserData) {
+	
+	static ListKey results;
+	SWKey * scope = 0;
+	SWModule *module = (SWModule *)hmodule;
+	if (!module) 	
+		return -1;
+	
+	results.ClearList();
+	results = module->Search(searchString, type, params, scope, 0, percent, (void *) &percentUserData);
+	
+	return (SWHANDLE)&results;
+}
   /** Gets and clears error status
   *
   * @return error status
@@ -235,7 +266,68 @@ const char *SWModule_getRenderText(SWHANDLE hmodule) {
 	return (const char *)((module) ? module->RenderText() : 0);
 }
 
+const char *SWModule_getEntryAttributes(SWHANDLE hmodule, const char *level1, const char *level2, const char *level3) {
+	SWModule *module = (SWModule *)hmodule;
+	static SWBuf retval;	
+	module->RenderText();                 	
+	retval = module->getEntryAttributes()[level1][level2][level3].c_str();
+	return (retval.length()) ? (const char*)retval.c_str() : NULL;
+}
 
+const char *SWModule_getPreverseHeader(SWHANDLE hmodule, const char *key, int pvHeading) {
+	SWModule *module = (SWModule *)hmodule;
+	static SWBuf preverseHeading;
+	char buf[12];	
+	sprintf(buf, "%i", pvHeading);  
+	module->SetKey(key);	
+	module->RenderText();                 	
+	preverseHeading = module->getEntryAttributes()["Heading"]["Preverse"][buf].c_str();
+	return (preverseHeading.length()) ? (const char*)preverseHeading.c_str() : NULL;
+}
+
+const char *SWModule_getFootnoteType(SWHANDLE hmodule, const char *key, const char *note) {
+	SWModule *module = (SWModule *)hmodule;
+	static SWBuf type;
+	module->Error();
+	module->SetKey(key);
+	module->RenderText();	
+	type = module->getEntryAttributes()["Footnote"][note]["type"].c_str();
+	return (type) ? (const char*)type.c_str() : NULL;
+}
+
+const char *SWModule_getFootnoteBody(SWHANDLE hmodule, const char *key, const char *note) {
+	SWModule *module = (SWModule *)hmodule;
+	static SWBuf body;
+	module->Error();
+	module->setKey(key);
+	module->RenderText();
+	body = module->getEntryAttributes()["Footnote"][note]["body"].c_str();
+	SWKey *keybuf = module->getKey();;
+	module->renderFilter(body, keybuf);
+	return (body) ? (const char*)body.c_str() : NULL;
+}
+
+const char *SWModule_getFootnoteRefList(SWHANDLE hmodule, const char *key, const char *note) {
+	SWModule *module = (SWModule *)hmodule;
+	static SWBuf refList;
+	module->Error();
+	module->SetKey(key);
+	module->RenderText();	
+	refList = module->getEntryAttributes()["Footnote"][note]["refList"].c_str();
+	return (refList) ? (const char*)refList.c_str() : NULL;
+}
+
+
+
+SWHANDLE listkey_getVerselistIterator(const char * list, const char * key) {
+	VerseKey versekey;
+	static ListKey verses;
+	
+	versekey.setText(key);
+	verses.ClearList();
+	verses = versekey.ParseVerseList(list, versekey);
+	return (SWHANDLE)&verses;
+}
 
 //-----------------------------------------------------------------
 // stringlist_iterator methods
@@ -253,6 +345,24 @@ const char *stringlist_iterator_val(SWHANDLE hsli) {
 
 
 
+//-----------------------------------------------------------------
+// listkey_iterator methods
+
+void listkey_iterator_next(SWHANDLE lki) {
+	ListKey *lk = (ListKey*)lki;
+	(*lk)++;
+}
+
+
+const char *listkey_iterator_val(SWHANDLE lki) {	
+	ListKey *lk = (ListKey*)lki;
+	if(!lk->Error())
+		return (const char *) lk->getText();
+	return NULL;
+}
+
+
+
 //-----------------------------------------------------------------
 // modmap methods
 
@@ -267,4 +377,3 @@ SWHANDLE ModList_iterator_val(SWHANDLE hmmi) {
 	ModItType *it  = (ModItType *)hmmi;
 	return (it->it != it->end) ? (SWHANDLE)it->it->second : 0;
 }
-
