@@ -15,12 +15,14 @@ using sword::AttributeList;
 
 int main(int argc, char **argv)
 {
-	SWMgr manager;
+	SWMgr manager(0, 0, true, 0, true);
 	SWModule *target;
 	ModMap::iterator it;
 
 	if (argc != 3) {
-		fprintf(stderr, "usage: %s <modname> <\"lookup key\">\n", argv[0]);
+		fprintf(stderr, "\nusage: %s <modname> <\"lookup key\">\n"
+							 "\tExample: lookup KJV \"James 1:19\"\n\n", argv[0]);
+ 
 		exit(-1);
 	}
 
@@ -33,6 +35,8 @@ int main(int argc, char **argv)
 		exit(-1);
 	}
 
+	manager.setGlobalOption("Headings", "On");
+
 	target = (*it).second;
 
 	target->setKey(argv[2]);
