@@ -15,6 +15,15 @@
 
 SWORD_NAMESPACE_START
 
+#ifdef _WIN32_WCE
+#define SWTRY
+#define SWCATCH(x) if (0)
+#define GLOBCONFPATH "/Program Files/sword/sword.conf"
+#else
+#define SWTRY try
+#define SWCATCH(x) catch (x)
+#endif
+
 // _declspec works in BC++ 5 and later, as well as VC++
 #if defined(_MSC_VER)
 
@@ -92,5 +101,9 @@ SWORD_NAMESPACE_START
 #  define SWDLLIMPORT
 #endif
 
+enum {DIRECTION_LTR = 0, DIRECTION_RTL, DIRECTION_BIDI};
+enum {FMT_UNKNOWN = 0, FMT_PLAIN, FMT_THML, FMT_GBF, FMT_HTML, FMT_HTMLHREF, FMT_RTF, FMT_OSIS, FMT_WEBIF};
+enum {ENC_UNKNOWN = 0, ENC_LATIN1, ENC_UTF8, ENC_SCSU, ENC_UTF16, ENC_RTF, ENC_HTML};
+
 SWORD_NAMESPACE_END
 #endif //SWORDDEFS_H
