@@ -2,7 +2,7 @@
  *  echomod.h  - code for class 'EchoMod' - a test module that just echo back
  *		 text of key.
  *
- * $Id: echomod.h,v 1.3 2002/10/01 19:52:40 dglassey Exp $
+ * $Id: echomod.h 1793 2005-05-03 09:47:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -25,15 +25,17 @@
 
 #include <swtext.h>
 #include <versekey.h>
+#include <defs.h>
+
 
 SWORD_NAMESPACE_START
 
-class EchoMod:public SWText
+class SWDLLEXPORT EchoMod : public SWText
 {
 public:
-  EchoMod ();
-  virtual ~ EchoMod ();
-  virtual operator const char *();
+	EchoMod();
+	virtual ~EchoMod();
+	virtual SWBuf &getRawEntryBuf();
 };
 
 SWORD_NAMESPACE_END
