@@ -2,7 +2,7 @@
  *  localemgr.h   - definition of class LocaleMgr used to interact with
  *				registered locales for a sword installation
  *
- * $Id: localemgr.h,v 1.16 2003/07/05 04:58:42 scribe Exp $
+ * $Id: localemgr.h 1688 2005-01-01 04:42:26Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -51,13 +51,15 @@ private:
 	void deleteLocales();
 	char *defaultLocaleName;
 	LocaleMgr(const LocaleMgr &);
-
+	friend class __staticsystemLocaleMgr;
 protected:
 	LocaleMap *locales;
+	static LocaleMgr *systemLocaleMgr;
 
 public:
+
 	/** Default constructor of  LocaleMgr
-	* You do normally not need this constructor, use LocaleMgr::systemLocaleMgr instead.
+	* You do normally not need this constructor, use LocaleMgr::getSystemLocaleMgr() instead.
 	*/
 	LocaleMgr(const char *iConfigPath = 0);
 
@@ -103,8 +105,8 @@ public:
 	/** The LocaleMgr object used globally in the Sword world.
 	* Do not create your own LocaleMgr, use this static object instead.
 	*/
-	static LocaleMgr systemLocaleMgr;
-
+	static LocaleMgr *getSystemLocaleMgr();
+	static void setSystemLocaleMgr(LocaleMgr *newLocaleMgr);
 
 	/** Augment this localmgr with all locale.conf files in a directory
 	*/
