@@ -2,7 +2,7 @@
  *  rawld.cpp - code for class 'RawLD'- a module that reads raw lexicon and
  *				dictionary files: *.dat *.idx
  *
- * $Id: rawld.h,v 1.18 2003/02/20 07:25:19 scribe Exp $
+ * $Id: rawld.h 1790 2005-05-03 03:49:04Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -48,7 +48,7 @@ public:
 	virtual void increment(int steps = 1);
 	virtual void decrement(int steps = 1) { increment(-steps); }
 	// write interface ----------------------------
-	virtual bool isWritable() { return ((idxfd->getFd() > 0) && ((idxfd->mode & O_RDWR) == O_RDWR)); }
+	virtual bool isWritable() { return ((idxfd->getFd() > 0) && ((idxfd->mode & FileMgr::RDWR) == FileMgr::RDWR)); }
 	static char createModule(const char *path) { return RawStr::createModule (path); }
 
 	virtual void setEntry(const char *inbuf, long len = -1);	// Modify current module entry
