@@ -1,7 +1,7 @@
 /******************************************************************************
 *  swbuf.h  - code for SWBuf used as a transport and utility for data buffers
 *
-* $Id: swbuf.h,v 1.27 2003/12/21 10:57:35 scribe Exp $
+* $Id: swbuf.h 1792 2005-05-03 09:08:34Z jansorg $
 *
 * Copyright 2003 CrossWire Bible Society (http://www.crosswire.org)
 *	CrossWire Bible Society
@@ -33,6 +33,10 @@ SWORD_NAMESPACE_START
 
 /**
 * This class is used as a transport and utility for data buffers.
+*
+* @warning This class does not perform pointer validity checks (for speed reasons). 
+*	Therefore, never try to pass an invalid string (const char* 0) as an argument-
+*	it will crash your program. You need to perform the checks yourself!
 */
 class SWDLLEXPORT SWBuf {
 	char *buf;
@@ -43,37 +47,51 @@ class SWDLLEXPORT SWBuf {
 	static char *nullStr;
 	static char junkBuf[JUNKBUFSIZE];
 
-	inline void assureMore(unsigned long pastEnd) {
-		if (endAlloc-end < pastEnd) {
-			long newsize = (end-buf)+pastEnd;
-			allocSize = newsize + 16;
-			long size = (end - buf);
-			buf = (char *)((buf) ? realloc(buf, allocSize) : malloc(allocSize));
-			end = (buf + size);
-			*end = 0;
-			endAlloc = buf + allocSize-1;
-		}
-	}
-	inline void assureSize(unsigned long newsize) {
-		if (newsize > allocSize) {
-			allocSize = newsize + 16;
-			long size = (end - buf);
-			buf = (char *)((buf) ? realloc(buf, allocSize) : malloc(allocSize));
-			end = (buf + size);
-			*end = 0;
-			endAlloc = buf + allocSize-1;
+	inline void assureMore(size_t pastEnd) {
+		if (size_t(endAlloc-end) < pastEnd) {
+			assureSize(allocSize + pastEnd);
 		}
 	}
 
-	void init(unsigned long initSize);
+	inline void assureSize(size_t checkSize) {
+		if (checkSize > allocSize) {
+			long size = (end - buf);
+			checkSize += 128;
+			buf = (char *)((allocSize) ? realloc(buf, checkSize) : malloc(checkSize));
+			allocSize = checkSize;
+			end = (buf + size);
+			*end = 0;
+			endAlloc = buf + allocSize - 1;
+		}
+	}
+
+	inline void init(size_t initSize) {
+		fillByte = ' ';
+		allocSize = 0;
+		buf = nullStr;
+		end = buf;
+		endAlloc = buf;
+		if (initSize)
+			assureSize(initSize);
+	}
+
 
 public:
+
+	/******************************************************************************
+	* SWBuf Constructor - Creates an empty SWBuf object
+	*
+	*/
+	inline SWBuf() {
+		init(0);
+	}
+
 	/**
-	* SWBuf Constructor - Creates an empty SWBuf object or an SWBuf initialized
+	* SWBuf Constructor - Creates an SWBuf initialized
  	* 		to a value from a const char *
  	*
  	*/
-	SWBuf(const char *initVal = 0, unsigned long initSize = 0);
+	SWBuf(const char *initVal, unsigned long initSize = 0);
 //	SWBuf(unsigned long initSize);
 
 	/**
@@ -90,13 +108,28 @@ public:
 	*/
 	SWBuf(const SWBuf &other, unsigned long initSize = 0);
 
-	inline void setFillByte(char ch) { fillByte = ch; }
-	inline char getFillByte() { return fillByte; }
-
-  /**
+	/******************************************************************************
 	* SWBuf Destructor - Cleans up instance of SWBuf
+	*/
+	inline ~SWBuf() {
+		if ((buf) && (buf != nullStr))
+			free(buf);
+	}
+
+	/**
+	* SWBuf::setFillByte - Set the fillByte character
+	*
+	* @param ch This character is used when the SWBuf is (re)sized.
+	*   The memory will be filled with this character. \see setSize() \see resize()
  	*/
-	virtual ~SWBuf();
+	inline void setFillByte(char ch) { fillByte = ch; }
+
+	/**
+	* SWBuf::getFillByte - Get the fillByte character
+	*
+	* @return The character used for filling memory. \see setFillByte.
+ 	*/
+	inline char getFillByte() { return fillByte; }
 
 	/**
 	* @return a pointer to the buffer content (null-terminated string)
@@ -107,40 +140,81 @@ public:
 	*	@param pos The position of the requested character.
 	* @return The character at the specified position
 	*/
-	inline char &charAt(unsigned long pos) { return ((pos <= (unsigned long)(end - buf)) ? buf[pos] : nullStr[0]); }
-//	inline char &charAt(unsigned int pos) { return ((buf+pos)<=end) ? buf[pos] : nullStr[0]; }
+	inline char &charAt(unsigned long pos) { return ((pos <= (unsigned long)(end - buf)) ? buf[pos] : ((*junkBuf=0),*junkBuf)); }
 
 	/** 
-	* size() and length() return only the number of characters of the string.
+	* @return size() and length() return only the number of characters of the string.
 	* Add one for the following null and one for each char to be appended!
 	*/
 	inline unsigned long size() const { return length(); }
 
 	/**
-	* size() and length() return only the number of characters of the string.
+	* @return size() and length() return only the number of characters of the string.
 	* Add one for the following null and one for each char to be appended!
 	*/
 	inline unsigned long length() const { return end - buf; }
 
-	/**
- 	* SWBuf::set - sets this buf to a new value.
-	* If the allocated memory is bigger than the new string, it will NOT be resized.
-	* @param newVal the value to set this buffer to. 
- 	*/
-	void set(const char *newVal);
-
 	/**
  	* SWBuf::set - sets this buf to a new value
 	* If the allocated memory is bigger than the new string, it will NOT be resized.
 	* @param newVal the value to set this buffer to. 
  	*/
-	void set(const SWBuf &newVal);
+	inline void set(const SWBuf &newVal) {
+		unsigned long len = newVal.length() + 1;
+		assureSize(len);
+//		const char *n = newVal.c_str();
+//		for (end = buf;len;len--) *end++ = *n++;
+		memcpy(buf, newVal.c_str(), len);
+		end = buf + (len - 1);
+	}
+
+	/**
+ 	* SWBuf::set - sets this buf to a new value.
+	* If the allocated memory is bigger than the new string, it will NOT be resized.
+	* @param newVal the value to set this buffer to. 
+ 	*/
+	inline void set(const char *newVal) {
+		if (newVal) {
+			unsigned long len = strlen(newVal) + 1;
+			assureSize(len);
+			memcpy(buf, newVal, len);
+			end = buf + (len - 1);
+		}
+		else {
+			assureSize(1);
+			end = buf;
+			*end = 0;
+		}
+	}
+
+	/**
+ 	* SWBuf::setFormatted - sets this buf to a formatted string.
+	* If the allocated memory is bigger than the new string, it will NOT be resized.
+	*
+	* @warning This function can only write at most JUNKBUFSIZE to the string per call.
+	*
+	* @warning This function is not very fast. For loops with many iterations you might
+	*  consider replacing it by other calls. 
+	*  Example: 
+	*    \code SWBuf buf.setFormatted("<%s>", stringVal); \endcode 
+	*  should be replaced by: 
+	*    \code buf.set("<"); buf.append(stringVal); buf.append(">"); \endcode
+	*  This will produce much faster results.
+	*
+	* @param format The format string. Same syntax as printf, for example.
+	* @param ... Add all arguments here.
+ 	*/
+	void setFormatted(const char *format, ...);
 
 	/**
  	* SWBuf::setSize - Size this buffer to a specific length.
 	* @param len The new size of the buffer. One byte for the null will be added.
  	*/
 	void setSize(unsigned long len);
+	/**
+ 	* SWBuf::resize - Resize this buffer to a specific length.
+	* @param len The new size of the buffer. One byte for the null will be added.
+ 	*/
 	inline void resize(unsigned long len) { setSize(len); }
 
 	/**
@@ -171,15 +245,59 @@ public:
 	}
 
 	/**
-	* SWBuf::appendFormatted - appends formatted strings to the current value of this SWBuf
-	* WARNING: This function can only write at most
-	* JUNKBUFSIZE to the string per call.
+	* SWBuf::appendFormatted - appends formatted strings to the current value of this SWBuf.
+	*
+	* @warning This function can only write at most JUNKBUFSIZE to the string per call.
+	*
+	* @warning This function is not very fast. For loops with many iterations you might
+	*  consider replacing it by other calls. 
+	*  Example: 
+	*    \code SWBuf buf.appendFormatted("<%s>", stringVal); \endcode 
+	*  should be replaced by: 
+	*    \code buf.append("<"); buf.append(stringVal); buf.append(">"); \endcode
+	*  This will produce much faster results.
+	*
 	* @param format The format string. Same syntax as printf, for example.
 	* @param ... Add all arguments here.
- 	*/
+	*/
 	void appendFormatted(const char *format, ...);
 	
-	inline char *getRawData() { return buf; }	// be careful!  Probably setSize needs to be called in conjunction before and maybe after
+	/** 
+	* SWBuf::insert - inserts the given string at position into this string
+	* @param pos The position where to insert. pos=0 inserts at the beginning, pos=1 after the first char, etc. Using pos=length() is the same as calling append(s)
+	* @param str string to be inserted
+	* @param start start from this position in the string to be inserted
+	* @param max Insert only max chars.
+	*/
+	void insert(unsigned long pos, const char* str, unsigned long start = 0, signed long max = -1);
+
+	/** 
+	* SWBuf::insert - inserts the given string at position into this string
+	* @param pos The position where to insert. pos=0 inserts at the beginning, pos=1 after the first char, etc. Using pos=length() is the same as calling append(s)
+	* @param str string to be inserted
+	* @param start start from this position in the string to be inserted
+	* @param max Insert only max chars.
+	*/
+	inline void insert(unsigned long pos, const SWBuf &str, unsigned long start = 0, signed long max = -1) {
+		insert(pos, str.c_str(), start, max);
+	};
+
+	/** 
+	* SWBuf::insert - inserts the given character at position into this string
+	* @param pos The position where to insert. pos=0 inserts at the beginning, pos=1 after the first char, etc. Using pos=length() is the same as calling append(s)
+	* @param c Insert this.
+	*/
+	inline void insert(unsigned long pos, char c) {
+		insert(pos, SWBuf(c));
+	}
+
+	/** SWBuf::getRawData
+	*
+	* @warning be careful! Probably setSize needs to be called in conjunction before and maybe after
+	*
+	* @return Pointer to the allocated memory of the SWBuf.
+	*/
+	inline char *getRawData() { return buf; }
 
 	inline operator const char *() const { return c_str(); }
 	inline char &operator[](unsigned long pos) { return charAt(pos); }
@@ -193,7 +311,8 @@ public:
 	inline SWBuf &operator -=(unsigned long len) { setSize(length()-len); return *this; }
 	inline SWBuf &operator --(int) { operator -=(1); return *this; }
 
-	inline SWBuf &operator <<(int n) { n = (n<length())?n:(length()-1); memmove(buf, buf+n, length()-n); (*this)-=n; return *this; }
+	inline SWBuf &operator <<(unsigned long n) { n = (n<length())?n:(length()-1); memmove(buf, buf+n, length()-n); (*this)-=n; return *this; }
+	inline SWBuf &operator >>(unsigned long n) { setSize(length()+n); memmove(buf+n, buf, length()-n); return *this; }
 	inline SWBuf operator +(const SWBuf &other) const {
 		SWBuf retVal = buf;
 		retVal += other;
@@ -209,6 +328,7 @@ public:
 	inline bool operator <=(const SWBuf &other) const { return compare(other) <= 0; }
 	inline bool operator >=(const SWBuf &other) const { return compare(other) >= 0; }
 
+	inline int compare(const char* other) const { return strcmp(c_str(), other); }
 	inline bool operator ==(const char *other) const { return !compare(other); }
 	inline bool operator !=(const char *other) const { return compare(other); }
 	inline bool operator > (const char *other) const { return compare(other) > 0; }
