@@ -2,7 +2,7 @@
  *  swlocale.h   - definition of Class SWLocale used for retrieval
  *				of locale lookups
  *
- * $Id: swlocale.h,v 1.11 2003/06/27 01:41:06 scribe Exp $
+ * $Id: swlocale.h 1769 2005-04-11 00:41:50Z scribe $
  *
  * Copyright 2000 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,19 +24,18 @@
 #define SWLOCALE_H
 
 #include <map>
-
 #include <swconfig.h>
 #include <versekey.h>
-
 #include <defs.h>
 
 SWORD_NAMESPACE_START
 
+static const int ENDOFABBREVS = -2;
 typedef std::map < SWBuf, SWBuf, std::less < SWBuf > >LookupMap;
 
 /** SWLocale is used for the localisation of the booknames
 * The SWLocale is a class which holds the information of one language.
-* Every language supported by Sword has one SWLocale object, 
+* Every language supported by SWORD has one SWLocale object, 
 * get the name of the Language using @see getname of this class.
 * Another functions useful for frontend developers is @see getDescription.
 */
@@ -45,6 +44,7 @@ class SWDLLEXPORT SWLocale {
 	SWConfig *localeSource;
 	char *name;
 	char *description;
+	char *encoding;
 	struct abbrev *bookAbbrevs;
 	char *BMAX;
 	struct sbook **books;
@@ -62,6 +62,7 @@ public:
 	* @return The description. A possible example is "German".
 	*/
 	virtual const char *getDescription();
+	virtual const char *getEncoding();
 	virtual const char *translate(const char *text);
 	virtual void augment(SWLocale &addFrom);
 	virtual SWLocale & operator +=(SWLocale &addFrom) { augment(addFrom); return *this; }
