@@ -1,7 +1,7 @@
 /******************************************************************************
  *	versekey.h - code for class 'versekey'- a standard Biblical verse key
  *
- * $Id: versekey.h,v 1.30 2003/08/13 05:27:02 scribe Exp $
+ * $Id: versekey.h 1804 2005-05-07 06:26:10Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -40,6 +40,7 @@ SWORD_NAMESPACE_START
 #define MAXCHAPTER SW_POSITION(POS_MAXCHAPTER)
 #define MAXBOOK SW_POSITION(POS_MAXBOOK)
 
+
 struct sbook
 {
 	/**Name of book
@@ -97,10 +98,15 @@ class SWDLLEXPORT VerseKey:public SWKey {
 	static int instance;
 	static struct sbook otbooks[];
 	static struct sbook ntbooks[];
+	static char *osisotbooks[];
+	static char *osisntbooks[];
+	static char **osisbooks[];
+#if 1
 	static long otbks[];
 	static long otcps[];
 	static long ntbks[];
 	static long ntcps[];
+#endif
 	static int vm[];
 	static LocaleCache localeCache;
 	ListKey internalListKey;
@@ -150,6 +156,12 @@ class SWDLLEXPORT VerseKey:public SWKey {
 	mutable VerseKey *lowerBound, *upperBound;
 
 public:
+#if 0
+	static long otbks[];
+	static long otcps[];
+	static long ntbks[];
+	static long ntcps[];
+#endif
 	static const char builtin_BMAX[2];
 	static struct sbook *builtin_books[2];
 	static const struct abbrev builtin_abbrevs[];
@@ -258,7 +270,7 @@ public:
 	* @return *this
 	*/
 	virtual void increment(int steps);
-	virtual char Traversable() { return 1; }
+	virtual bool isTraversable() { return true; }
 
 	virtual const char *getBookName() const;
 	virtual const char *getBookAbbrev() const;
@@ -366,6 +378,13 @@ public:
 	virtual long Index(long iindex);
 
 	virtual const char *getOSISRef() const;
+	static const int getOSISBookNum(const char *bookab);
+
+	/** Tries to parse a string and convert it into an OSIS reference
+	 * @param inRef reference string to try to parse
+	 * @param defaultKey @see ParseVerseList(..., defaultKey, ...)
+	 */
+	static const char *convertToOSIS(const char *inRef, const SWKey *defaultKey);
 
 	virtual ListKey ParseVerseList(const char *buf, const char *defaultKey = "Genesis 1:1", bool expandRange = false);
 	virtual const char *getRangeText() const;
@@ -403,4 +422,5 @@ public:
 };
 
 SWORD_NAMESPACE_END
-#endif
+
+#endif //VERSEKEY_H
