@@ -2,7 +2,7 @@
  *  zld.cpp - code for class 'zLD'- a module that reads compressed lexicon and
  *				dictionary files.
  *
- * $Id: zld.h,v 1.8 2003/02/20 07:25:20 scribe Exp $
+ * $Id: zld.h 1790 2005-05-03 03:49:04Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -48,7 +48,7 @@ public:
 
 	// write interface ----------------------------
 	virtual bool isWritable() {
-		return ((idxfd->getFd() > 0) && ((idxfd->mode & O_RDWR) == O_RDWR));
+		return ((idxfd->getFd() > 0) && ((idxfd->mode & FileMgr::RDWR) == FileMgr::RDWR));
 	}
 	static char createModule(const char *path) {
 		return zStr::createModule(path);
