@@ -3,7 +3,9 @@
  *		  types of displays (e.g. raw textout, curses, xwindow, etc.)
  */
 
+#ifndef	_WIN32_WCE
 #include <iostream>
+#endif
 #include <swmodule.h>
 #include <swdisp.h>
 
@@ -24,7 +26,9 @@ SWClass SWDisplay::classdef(classes);
 
 char SWDisplay::Display(SWModule &imodule)
 {
+#ifndef	_WIN32_WCE
 	std::cout << (const char *)imodule;
+#endif
 	return 0;
 }
 
