@@ -3,18 +3,12 @@
  */
 
 #include <swmacs.h>
-#include <utilfuns.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <stdlib.h>
 
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
-
 #include <utilstr.h>
+#include <stringmgr.h>
 #include <swkey.h>
 #include <swlog.h>
 #include <versekey.h>
@@ -60,7 +54,7 @@ void VerseKey::init() {
 	verse = 0;
 	locale = 0;
 
-	setLocale(LocaleMgr::systemLocaleMgr.getDefaultLocaleName());
+	setLocale(LocaleMgr::getSystemLocaleMgr()->getDefaultLocaleName());
 }
 
 /******************************************************************************
@@ -144,7 +138,7 @@ VerseKey::~VerseKey() {
 
 void VerseKey::setLocale(const char *name) {
 	char *BMAX;
-	struct sbook **books;
+	struct sbook **lbooks;
 	bool useCache = false;
 
 	if (localeCache.name)
@@ -155,12 +149,12 @@ void VerseKey::setLocale(const char *name) {
 		localeCache.abbrevsCnt = 0;
 	}
 
-	SWLocale *locale = (useCache) ? localeCache.locale : LocaleMgr::systemLocaleMgr.getLocale(name);
+	SWLocale *locale = (useCache) ? localeCache.locale : LocaleMgr::getSystemLocaleMgr()->getLocale(name);
 	localeCache.locale = locale;
 
 	if (locale) {
-		locale->getBooks(&BMAX, &books);
-		setBooks(BMAX, books);
+		locale->getBooks(&BMAX, &lbooks);
+		setBooks(BMAX, lbooks);
 		setBookAbbrevs(locale->getBookAbbrevs(), localeCache.abbrevsCnt);
 		localeCache.abbrevsCnt = abbrevsCnt;
 	}
@@ -194,15 +188,19 @@ void VerseKey::setBookAbbrevs(const struct abbrev *bookAbbrevs, unsigned int siz
 			}
 			*/
 		}
-        for (int t = 0; t < 2; t++) {
-            for (int i = 0; i < BMAX[t]; i++) {
-                int bn = getBookAbbrev(books[t][i].name);
-                if ((bn-1)%39 != i) {
-				SWLog::systemlog->LogError("Book: %s does not have a matching toupper abbrevs entry! book number returned was: %d", books[t][i].name, bn);
-                }
-            }
-        }
-    }
+        
+		if (SWLog::getSystemLog()->getLogLevel() > 0) { //make sure log is wanted, this loop stuff costs a lot of time
+			for (int t = 0; t < 2; t++) {
+				for (int i = 0; i < BMAX[t]; i++) {
+					const int bn = getBookAbbrev(books[t][i].name);
+					if ((bn-1)%39 != i) {
+						SWLog::getSystemLog()->logError("VerseKey::Book: %s does not have a matching toupper abbrevs entry! book number returned was: %d(%d)", 
+							books[t][i].name, bn, i);
+					}
+				}
+			}
+		}
+    	}
 	else abbrevsCnt = size;
 }
 
@@ -320,17 +318,25 @@ int VerseKey::getBookAbbrev(const char *iabbr)
 
 	char *abbr = 0;
 
+	StringMgr* stringMgr = StringMgr::getSystemStringMgr();
+	const bool hasUTF8Support = StringMgr::hasUTF8Support();
+	
 	for (int i = 0; i < 2; i++) {
 		stdstr(&abbr, iabbr);
 		strstrip(abbr);
-		if (!i)
-			toupperstr(abbr);
+		if (!i && hasUTF8Support) { //we have support for UTF-8 handling; we expect UTF-8 encoded locales
+			abbr = stringMgr->upperUTF8(abbr);
+		}
+		else if (!i) {
+			abbr = stringMgr->upperLatin1(abbr);
+		}
+			
 		abLen = strlen(abbr);
 
 		if (abLen) {
 			min = 0;
-//			max = abbrevsCnt - 1;
 			max 	= abbrevsCnt;
+			
 			while(1) {
 				target = min + ((max - min) / 2);
 				diff = strncmp(abbr, abbrevs[target].ab, abLen);
@@ -340,6 +346,7 @@ int VerseKey::getBookAbbrev(const char *iabbr)
 					min = target;
 				else	max = target;
 			}
+			
 			for (; target > 0; target--) {
 				if (strncmp(abbr, abbrevs[target-1].ab, abLen))
 					break;
@@ -401,13 +408,16 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 	while (*buf) {
 		switch (*buf) {
 		case ':':
-			number[tonumber] = 0;
-			tonumber = 0;
-			if (*number)
-				chap = atoi(number);
-			*number = 0;
-			break;
-
+			if (buf[1] != ' ') {		// for silly Mat 1:1: this verse....
+				number[tonumber] = 0;
+				tonumber = 0;
+				if (*number)
+					chap = atoi(number);
+				*number = 0;
+				comma = 0;
+				break;
+			}
+			// otherwise drop down to next case
 		case ' ':
 			inTerm = true;
 			while (true) {
@@ -423,6 +433,7 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 				book[tobook++] = ' ';
 				break;
 			}
+
 		case '-': 
 		case ',': // on number new verse
 		case ';': // on number new chapter
@@ -454,29 +465,29 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 					break;
 				}
 
-                                for (loop = strlen(book) - 1; loop+1; loop--) {
+				for (loop = strlen(book) - 1; loop+1; loop--) {
 					if (book[loop] == ' ') {
 						if (isroman(&book[loop+1])) {
 							if (verse == -1) {
 								verse = chap;
 								chap = from_rom(&book[loop+1]);
 								book[loop] = 0;
-					       	        }
-                                                }
+							}
+						}
 	        				break;
-                                        }
-                                }
+					}
+				}
 
-                                if ((!stricmp(book, "V")) || (!stricmp(book, "VER"))) {	// Verse abbrev
-                                        if (verse == -1) {
-                                                verse = chap;
-		                		chap = VerseKey(tmpListKey).Chapter();
-                                                *book = 0;
-                                        }
-                                }
-                                if ((!stricmp(book, "ch")) || (!stricmp(book, "chap"))) {	// Verse abbrev
+				if ((!stricmp(book, "V")) || (!stricmp(book, "VER"))) {	// Verse abbrev
+					if (verse == -1) {
+						verse = chap;
+						chap = VerseKey(tmpListKey).Chapter();
+						*book = 0;
+					}
+				}
+				if ((!stricmp(book, "ch")) || (!stricmp(book, "chap"))) {	// Verse abbrev
 					strcpy(book, VerseKey(tmpListKey).getBookName());
-                                }
+				}
 				bookno = getBookAbbrev(book);
 			}
 			if (((bookno > -1) || (!*book)) && ((*book) || (chap >= 0) || (verse >= 0))) {
@@ -516,7 +527,10 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 					}
 				}
 
-				if ((*buf == '-') && (expandRange)) {	// if this is a dash save lowerBound and wait for upper
+				// check for '-'
+				for (q = 0; ((buf[q]) && (buf[q] == ' ')); q++);
+				if ((buf[q] == '-') && (expandRange)) {	// if this is a dash save lowerBound and wait for upper
+					buf+=q;
 					VerseKey newElement;
 					newElement.LowerBound(curkey);
 					newElement.setPosition(TOP);
@@ -573,6 +587,8 @@ ListKey VerseKey::ParseVerseList(const char *buf, const char *defaultKey, bool e
 		case ']': 
 		case '(': 
 		case ')': 
+		case '{': 
+		case '}': 
 			break;
 		case '.':
 			if (buf > orig)			// ignore (break) if preceeding char is not a digit
@@ -1473,6 +1489,21 @@ int VerseKey::_compare(const VerseKey &ivkey)
 	return keyval1;
 }
 
+char *VerseKey::osisotbooks[] = {
+		"Gen","Exod","Lev","Num","Deut","Josh","Judg","Ruth","1Sam","2Sam",
+		"1Kgs","2Kgs","1Chr","2Chr","Ezra","Neh","Esth","Job","Ps",
+		"Prov",		// added this.  Was not in OSIS spec
+		"Eccl",
+		"Song","Isa","Jer","Lam","Ezek","Dan","Hos","Joel","Amos","Obad",
+		"Jonah","Mic","Nah","Hab","Zeph","Hag","Zech","Mal","Bar","PrAzar",
+		"Bel","Sus","1Esd","2Esd","AddEsth","EpJer","Jdt","1Macc","2Macc","3Macc",
+		"4Macc","PrMan","Ps151","Sir","Tob","Wis"};
+char *VerseKey::osisntbooks[] = {
+		"Matt","Mark","Luke","John","Acts","Rom","1Cor","2Cor","Gal","Eph",
+		"Phil","Col","1Thess","2Thess","1Tim","2Tim","Titus","Phlm","Heb","Jas",
+		"1Pet","2Pet","1John","2John","3John","Jude","Rev"};
+char **VerseKey::osisbooks[] = { osisotbooks, osisntbooks };
+
 
 const char *VerseKey::getOSISRef() const {
 	static char buf[5][254];
@@ -1481,20 +1512,6 @@ const char *VerseKey::getOSISRef() const {
 	if (loop > 4)
 		loop = 0;
 
-	static char *osisotbooks[] = {
-			"Gen","Exod","Lev","Num","Deut","Josh","Judg","Ruth","1Sam","2Sam",
-			"1Kgs","2Kgs","1Chr","2Chr","Ezra","Neh","Esth","Job","Ps",
-			"Prov",		// added this.  Was not in OSIS spec
-			"Eccl",
-			"Song","Isa","Jer","Lam","Ezek","Dan","Hos","Joel","Amos","Obad",
-			"Jonah","Mic","Nah","Hab","Zeph","Hag","Zech","Mal","Bar","PrAzar",
-			"Bel","Sus","1Esd","2Esd","AddEsth","EpJer","Jdt","1Macc","2Macc","3Macc",
-			"4Macc","PrMan","Ps151","Sir","Tob","Wis"};
-	static char *osisntbooks[] = {
-			"Matt","Mark","Luke","John","Acts","Rom","1Cor","2Cor","Gal","Eph",
-			"Phil","Col","1Thess","2Thess","1Tim","2Tim","Titus","Phlm","Heb","Jas",
-			"1Pet","2Pet","1John","2John","3John","Jude","Rev"};
-	static char **osisbooks[] = { osisotbooks, osisntbooks };
 	if (Verse())
 		sprintf(buf[loop], "%s.%d.%d", osisbooks[Testament()-1][Book()-1], (int)Chapter(), (int)Verse());
 	else if (Chapter())
@@ -1505,6 +1522,28 @@ const char *VerseKey::getOSISRef() const {
 	return buf[loop++];
 }
 
+const int VerseKey::getOSISBookNum(const char *bookab) {
+	int i;
+	for (i=0; i < 39; i++)
+	{
+		if (!strncmp(bookab, osisotbooks[i], strlen(osisotbooks[i])))
+		{
+			//printf("VerseKey::getOSISBookNum %s is OT %d\n", bookab, i+1);
+			return i+1;
+		}
+	}
+	for (i=0; i < 27; i++)
+	{
+		if (!strncmp(bookab, osisntbooks[i], strlen(osisotbooks[i])))
+		{
+			//printf("VerseKey::getOSISBookNum %s is NT %d\n", bookab, i+1);
+			return i+1;
+		}
+	}
+	return -1;
+}
+
+
 
 /******************************************************************************
  * VerseKey::getRangeText - returns parsable range text for this key
@@ -1520,4 +1559,55 @@ const char *VerseKey::getRangeText() const {
 	return rangeText;
 }
 
+
+const char *VerseKey::convertToOSIS(const char *inRef, const SWKey *lastKnownKey) {
+	static SWBuf outRef;
+
+	outRef = "";
+
+	VerseKey defLanguage;
+	ListKey verses = defLanguage.ParseVerseList(inRef, (*lastKnownKey), true);
+	const char *startFrag = inRef;
+	for (int i = 0; i < verses.Count(); i++) {
+		VerseKey *element = SWDYNAMIC_CAST(VerseKey, verses.GetElement(i));
+		char buf[5120];
+		char frag[800];
+		char preJunk[800];
+		char postJunk[800];
+		memset(buf, 0, 5120);
+		memset(frag, 0, 800);
+		memset(preJunk, 0, 800);
+		memset(postJunk, 0, 800);
+		while ((*startFrag) && (strchr(" {};,()[].", *startFrag))) {
+			outRef += *startFrag;
+			startFrag++;
+		}
+		if (element) {
+			memmove(frag, startFrag, ((const char *)element->userData - startFrag) + 1);
+			frag[((const char *)element->userData - startFrag) + 1] = 0;
+			int j;
+			for (j = strlen(frag)-1; j && (strchr(" {};,()[].", frag[j])); j--);
+			if (frag[j+1])
+				strcpy(postJunk, frag+j+1);
+			frag[j+1]=0;
+			startFrag += ((const char *)element->userData - startFrag) + 1;
+			sprintf(buf, "<reference osisRef=\"%s-%s\">%s</reference>%s", element->LowerBound().getOSISRef(), element->UpperBound().getOSISRef(), frag, postJunk);
+		}
+		else {
+			memmove(frag, startFrag, ((const char *)verses.GetElement(i)->userData - startFrag) + 1);
+			frag[((const char *)verses.GetElement(i)->userData - startFrag) + 1] = 0;
+			int j;
+			for (j = strlen(frag)-1; j && (strchr(" {};,()[].", frag[j])); j--);
+			if (frag[j+1])
+				strcpy(postJunk, frag+j+1);
+			frag[j+1]=0;
+			startFrag += ((const char *)verses.GetElement(i)->userData - startFrag) + 1;
+			sprintf(buf, "<reference osisRef=\"%s\">%s</reference>%s", VerseKey(*verses.GetElement(i)).getOSISRef(), frag, postJunk);
+		}
+		outRef+=buf;
+	}
+	if (startFrag < (inRef + strlen(inRef)))
+		outRef+=startFrag;
+	return outRef.c_str();
+}
 SWORD_NAMESPACE_END
