@@ -2,7 +2,7 @@
  *  localemgr.cpp - implementation of class LocaleMgr used to interact with
  *				registered locales for a sword installation
  *
- * $Id: localemgr.cpp,v 1.16 2003/07/05 04:58:42 scribe Exp $
+ * $Id: localemgr.cpp 1790 2005-05-03 03:49:04Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,25 +24,41 @@
 #include <stdlib.h>
 #include <fcntl.h>
 
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#include <unixstr.h>
-#endif
 #include <sys/stat.h>
 #include <dirent.h>
 
 #include <swmgr.h>
-#include <utilfuns.h>
+#include <utilstr.h>
 
-#include <localemgr.h>
+#include <stringmgr.h>
 #include <filemgr.h>
+#include <localemgr.h>
 
 SWORD_NAMESPACE_START
 
 
-LocaleMgr LocaleMgr::systemLocaleMgr;
+LocaleMgr *LocaleMgr::systemLocaleMgr = 0;
+
+class __staticsystemLocaleMgr {
+public:
+	__staticsystemLocaleMgr() { }
+	~__staticsystemLocaleMgr() { delete LocaleMgr::systemLocaleMgr; }
+} _staticsystemLocaleMgr;
+
+
+LocaleMgr *LocaleMgr::getSystemLocaleMgr() {
+	if (!systemLocaleMgr)
+		systemLocaleMgr = new LocaleMgr();
+
+	return systemLocaleMgr;
+}
+
+
+void LocaleMgr::setSystemLocaleMgr(LocaleMgr *newLocaleMgr) {
+	if (systemLocaleMgr)
+		delete systemLocaleMgr;
+	systemLocaleMgr = newLocaleMgr;
+}
 
 
 LocaleMgr::LocaleMgr(const char *iConfigPath) {
@@ -51,21 +67,14 @@ LocaleMgr::LocaleMgr(const char *iConfigPath) {
 	char *configPath = 0;
 	char configType = 0;
 	SWBuf path;
+	std::list<SWBuf> augPaths;
 	
 	defaultLocaleName = 0;
 	
-	char *lang = getenv ("LANG");
-	if (lang) {
-		if (strlen(lang) > 0)
-			setDefaultLocaleName(lang);
-		else setDefaultLocaleName("en_us");
-	}
-	else setDefaultLocaleName("en_us");
-
 	if (!iConfigPath)
-		SWMgr::findConfig(&configType, &prefixPath, &configPath);
+		SWMgr::findConfig(&configType, &prefixPath, &configPath, &augPaths);
 	else configPath = (char *)iConfigPath;
-
+	
 	if (prefixPath) {
 		switch (configType) {
 		case 2:
@@ -87,6 +96,23 @@ LocaleMgr::LocaleMgr(const char *iConfigPath) {
 			loadConfigDir(path.c_str());
 		}
 	}
+	
+	if (augPaths.size()) { //load locale files from all augmented paths
+		std::list<SWBuf>::iterator it = augPaths.begin();
+		std::list<SWBuf>::iterator end = augPaths.end();
+		
+		for (;it != end; ++it) {
+			if (FileMgr::existsDir((*it).c_str(), "locales.d")) {
+				SWBuf path = (*it) + "locales.d";
+				loadConfigDir(path.c_str());
+			}
+		}
+	}
+
+	// Locales will be invalidated if you change the StringMgr
+	// So only use the default hardcoded locale and let the
+	// frontends change the locale if they want
+	stdstr(&defaultLocaleName, "en_US");
 
 	if (prefixPath)
 		delete [] prefixPath;
@@ -99,7 +125,7 @@ LocaleMgr::LocaleMgr(const char *iConfigPath) {
 LocaleMgr::~LocaleMgr() {
 	if (defaultLocaleName)
 		delete [] defaultLocaleName;
-     deleteLocales();
+     	deleteLocales();
 	delete locales;
 }
 
@@ -109,6 +135,7 @@ void LocaleMgr::loadConfigDir(const char *ipath) {
 	struct dirent *ent;
 	SWBuf newmodfile;
 	LocaleMap::iterator it;
+	SWLog::getSystemLog()->logInformation("LocaleMgr::loadConfigDir loading %s", ipath);
  
 	if ((dir = opendir(ipath))) {
 		rewinddir(dir);
@@ -119,15 +146,29 @@ void LocaleMgr::loadConfigDir(const char *ipath) {
 					newmodfile += "/";
 				newmodfile += ent->d_name;
 				SWLocale *locale = new SWLocale(newmodfile.c_str());
-				if (locale->getName()) {
+				
+				if (locale->getName()) {					
+					bool supported = false;
+					if (StringMgr::hasUTF8Support()) {
+						supported = (locale->getEncoding() && (!strcmp(locale->getEncoding(), "UTF-8") || !strcmp(locale->getEncoding(), "ASCII")) );
+					}
+					else {
+						supported = !locale->getEncoding() || (locale->getEncoding() && (strcmp(locale->getEncoding(), "UTF-8") != 0)); //exclude UTF-8 locales
+					}
+					
+					if (!supported) { //not supported
+						delete locale;
+						continue;
+					}
+				
 					it = locales->find(locale->getName());
-					if (it != locales->end()) {
+					if (it != locales->end()) { // already present
 						*((*it).second) += *locale;
 						delete locale;
 					}
 					else locales->insert(LocaleMap::value_type(locale->getName(), locale));
 				}
-                    else	delete locale;
+				else	delete locale;
 			}
 		}
 		closedir(dir);
@@ -153,6 +194,7 @@ SWLocale *LocaleMgr::getLocale(const char *name) {
 	if (it != locales->end())
 		return (*it).second;
 
+	SWLog::getSystemLog()->logWarning("LocaleMgr::getLocale failed to find %s\n", name);
 	return 0;
 }
 
@@ -184,7 +226,36 @@ const char *LocaleMgr::getDefaultLocaleName() {
 
 
 void LocaleMgr::setDefaultLocaleName(const char *name) {
-	stdstr(&defaultLocaleName, name);
+	char *tmplang=0;
+	stdstr(&tmplang, name);
+	// discard everything after '.' usually encoding e.g. .UTF-8
+	strtok(tmplang, ".");
+	// also discard after '@' so e.g. @euro locales are found
+	strtok(tmplang, "@");
+	// Before we set it we want to verify that it is an existing locale
+	// First check for what we ask for
+	if (getLocale(tmplang)) {
+		stdstr(&defaultLocaleName, tmplang);
+	}
+	else {
+		// check for locale without country
+		char *nocntry=0;
+		stdstr(&nocntry, tmplang);
+		strtok(nocntry, "_");
+		if (getLocale(nocntry)) {
+			stdstr(&defaultLocaleName, nocntry);
+		}
+		else {
+			if (!defaultLocaleName) {
+				// make sure we have a default locale name
+				// even though the one asked for doesn't exist
+				stdstr(&defaultLocaleName, "en_US");
+			}
+
+		}
+		delete [] nocntry;
+	}
+	delete [] tmplang;
 }
 
 SWORD_NAMESPACE_END
