@@ -2,7 +2,7 @@
  *  swconfig.cpp   - implementation of Class SWConfig used for saving and
  *			retrieval of configuration information
  *
- * $Id: swconfig.cpp,v 1.13 2003/06/27 01:41:07 scribe Exp $
+ * $Id: swconfig.cpp 1793 2005-05-03 09:47:40Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -21,7 +21,10 @@
  */
 
 #include <swconfig.h>
-#include <utilfuns.h>
+#include <utilstr.h>
+#include <filemgr.h>
+#include <fcntl.h>
+
 
 SWORD_NAMESPACE_START
 
@@ -35,6 +38,7 @@ SWConfig::~SWConfig() {
 }
 
 
+/*
 char SWConfig::getline(FILE *fp, SWBuf &line)
 {
 	char retval = 0;
@@ -64,10 +68,13 @@ char SWConfig::getline(FILE *fp, SWBuf &line)
 	}
 	return retval;
 }
+*/
+
+
 
 
 void SWConfig::Load() {
-	FILE *cfile;
+	FileDesc *cfile;
 	char *buf, *data;
 	SWBuf line;
 	ConfigEntMap cursect;
@@ -76,8 +83,9 @@ void SWConfig::Load() {
 	
 	Sections.erase(Sections.begin(), Sections.end());
 	
-	if ((cfile = fopen(filename.c_str(), "r"))) {
-		while (getline(cfile, line)) {
+	cfile = FileMgr::getSystemFileMgr()->open(filename.c_str(), FileMgr::RDONLY);
+	if (cfile->getFd() > 0) {
+		while (FileMgr::getLine(cfile, line)) {
 			buf = new char [ line.length() + 1 ];
 			strcpy(buf, line.c_str());
 			if (*strstrip(buf) == '[') {
@@ -103,35 +111,37 @@ void SWConfig::Load() {
 		if (!first)
 			Sections.insert(SectionMap::value_type(sectname, cursect));
 
-		fclose(cfile);
+		FileMgr::getSystemFileMgr()->close(cfile);
 	}
 }
 
 
 void SWConfig::Save() {
-	FILE *cfile;
+	FileDesc *cfile;
 	SWBuf buf;
 	SectionMap::iterator sit;
 	ConfigEntMap::iterator entry;
 	SWBuf sectname;
 	
-	if ((cfile = fopen(filename.c_str(), "w"))) {
+	cfile = FileMgr::getSystemFileMgr()->open(filename.c_str(), FileMgr::RDWR|FileMgr::CREAT|FileMgr::TRUNC);
+	if (cfile->getFd() > 0) {
 		
 		for (sit = Sections.begin(); sit != Sections.end(); sit++) {
 			buf =  "\n[";
 			buf += (*sit).first.c_str();
 			buf += "]\n";
-			fputs(buf.c_str(), cfile);
+			cfile->write(buf.c_str(), buf.length());
 			for (entry = (*sit).second.begin(); entry != (*sit).second.end(); entry++) {
 				buf = (*entry).first.c_str();
 				buf += "=";
 				buf += (*entry).second.c_str();
 				buf += "\n";
-				fputs(buf.c_str(), cfile);
+				cfile->write(buf.c_str(), buf.length());
 			}
 		}
-		fputs("\n", cfile);	// so getline will find last line
-		fclose(cfile);
+		buf = "\n";
+		cfile->write(buf.c_str(), buf.length());
+		FileMgr::getSystemFileMgr()->close(cfile);
 	}
 }
 
