@@ -2,7 +2,7 @@
  *  swlocale.cpp   - implementation of Class SWLocale used for retrieval
  *				of locale lookups
  *
- * $Id: swlocale.cpp,v 1.5 2002/10/01 19:52:40 dglassey Exp $
+ * $Id: swlocale.cpp 1790 2005-05-03 03:49:04Z scribe $
  *
  * Copyright 2000 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -21,7 +21,7 @@
  */
 
 #include <swlocale.h>
-#include <utilfuns.h>
+#include <utilstr.h>
 
 SWORD_NAMESPACE_START
 
@@ -30,6 +30,7 @@ SWLocale::SWLocale(const char * ifilename) {
 
 	name         = 0;
 	description  = 0;
+	encoding     = 0;
 	bookAbbrevs  = 0;
 	BMAX         = 0;
 	books        = 0;
@@ -42,6 +43,10 @@ SWLocale::SWLocale(const char * ifilename) {
 	confEntry = localeSource->Sections["Meta"].find("Description");
 	if (confEntry != localeSource->Sections["Meta"].end())
 		stdstr(&description, (*confEntry).second.c_str());
+
+	confEntry = localeSource->Sections["Meta"].find("Encoding"); //Either empty (==Latin1) or UTF-8
+	if (confEntry != localeSource->Sections["Meta"].end())
+		stdstr(&encoding, (*confEntry).second.c_str());
 }
 
 
@@ -49,6 +54,9 @@ SWLocale::~SWLocale() {
 
 	delete localeSource;
 
+	if (encoding)
+		delete [] encoding;
+	
 	if (description)
 		delete [] description;
 
@@ -77,7 +85,29 @@ const char *SWLocale::translate(const char *text) {
 		confEntry = localeSource->Sections["Text"].find(text);
 		if (confEntry == localeSource->Sections["Text"].end())
 			lookupTable.insert(LookupMap::value_type(text, text));
-		else	lookupTable.insert(LookupMap::value_type(text, (*confEntry).second.c_str()));
+		else {//valid value found
+			/*
+			- If Encoding==Latin1 and we have a StringHelper, convert to UTF-8
+			- If StringHelper present and Encoding is UTF-8, use UTF8
+			- If StringHelper not present and Latin1, use Latin1
+			- If StringHelper not present and UTF-8, no idea what to do. Should't happen
+			*/
+/*			if (StringHelper::getSystemStringHelper()) {
+				if (!strcmp(encoding, "UTF-8")) {
+					lookupTable.insert(LookupMap::value_type(text, (*confEntry).second.c_str()));
+				}
+				else { //latin1 expected, convert to UTF-8
+					SWBuf t((*confEntry).second.c_str());
+					t = StringHelper::getSystemStringHelper()->latin2unicode( t );
+					
+					lookupTable.insert(LookupMap::value_type(text, t.c_str()));
+				}
+			}
+			else { //no stringhelper, just insert. Nothing we can do*/
+				lookupTable.insert(LookupMap::value_type(text, (*confEntry).second.c_str()));
+// 			}
+			
+		}
 		entry = lookupTable.find(text);
 	}
 	return (*entry).second.c_str();
@@ -93,25 +123,41 @@ const char *SWLocale::getDescription() {
 	return description;
 }
 
+const char *SWLocale::getEncoding() {
+	return encoding;
+}
 
 void SWLocale::augment(SWLocale &addFrom) {
 	*localeSource += *addFrom.localeSource;
 }
 
+//#define NONNUMERICLOCALETHING 1
 
 const struct abbrev *SWLocale::getBookAbbrevs() {
 	static const char *nullstr = "";
 	if (!bookAbbrevs) {
 		ConfigEntMap::iterator it;
-		int i;
+		int i, j;
 		int size = localeSource->Sections["Book Abbrevs"].size();
 		bookAbbrevs = new struct abbrev[size + 1];
-		for (i = 0, it = localeSource->Sections["Book Abbrevs"].begin(); it != localeSource->Sections["Book Abbrevs"].end(); it++, i++) {
+		for (i = 0, j = 0, it = localeSource->Sections["Book Abbrevs"].begin(); it != localeSource->Sections["Book Abbrevs"].end(); it++, i++) {
+			#ifdef NONNUMERICLOCALETHING
+			int booknum = VerseKey::getOSISBookNum((*it).second.c_str());
+			if (booknum != -1) {
+				bookAbbrevs[j].ab = (*it).first.c_str();
+				bookAbbrevs[j].book = booknum;
+				j++;
+			}
+			#else
 			bookAbbrevs[i].ab = (*it).first.c_str();
 			bookAbbrevs[i].book = atoi((*it).second.c_str());
+			j++;
+			#endif
+			//printf("SWLocale::getBookAbbrevs %s:%s %d\n",bookAbbrevs[i].ab,
+			//	(*it).second.c_str(), bookAbbrevs[i].book); 
 		}
-		bookAbbrevs[i].ab = nullstr;
-		bookAbbrevs[i].book = -1;
+		bookAbbrevs[j].ab = nullstr;
+		bookAbbrevs[j].book = -1;
 	}
 		
 	return bookAbbrevs;
@@ -140,4 +186,5 @@ void SWLocale::getBooks(char **iBMAX, struct sbook ***ibooks) {
 	*ibooks = books;
 }
 
+
 SWORD_NAMESPACE_END
