@@ -2,7 +2,7 @@
  *  swmgr.cpp   - implementaion of class SWMgr used to interact with an install
  *				base of sword modules.
  *
- * $Id: swmgr.cpp,v 1.96 2003/12/05 21:44:33 scribe Exp $
+ * $Id: swmgr.cpp 1808 2005-05-13 01:04:48Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,12 +24,6 @@
 #include <stdlib.h>
 #include <fcntl.h>
 
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#include <unixstr.h>
-#endif
 #include <sys/stat.h>
 #ifndef _MSC_VER
 #include <iostream>
@@ -43,7 +37,7 @@
 #include <hrefcom.h>
 #include <rawld.h>
 #include <rawld4.h>
-#include <utilfuns.h>
+#include <utilstr.h>
 #include <gbfplain.h>
 #include <thmlplain.h>
 #include <osisplain.h>
@@ -77,6 +71,11 @@
 #include <utf8hebrewpoints.h>
 #include <greeklexattribs.h>
 #include <swfiltermgr.h>
+
+#include <swlog.h>
+
+#include <iterator>
+
 #ifndef EXCLUDEZLIB
 #include "zipcomprs.h"
 #endif
@@ -103,6 +102,12 @@ const char *SWMgr::globalConfPath = GLOBCONFPATH;
 const char *SWMgr::globalConfPath = "/etc/sword.conf:/usr/local/etc/sword.conf";
 #endif
 
+#ifdef _MSC_VER
+#define DEBUGSTR(x)
+#else
+#define DEBUGSTR(x) if (SWMgr::debug) std::cerr << x;
+#endif  
+
 void SWMgr::init() {
 	SWFilter *tmpFilter = 0;
 	configPath  = 0;
@@ -110,13 +115,12 @@ void SWMgr::init() {
 	configType  = 0;
 	myconfig    = 0;
 	mysysconfig = 0;
-	homeConfig = 0;
-
+	homeConfig  = 0;
+	augmentHome = true;
 
 	cipherFilters.clear();
 	optionFilters.clear();
 	cleanupFilters.clear();
-
 	tmpFilter = new ThMLVariants();
 	optionFilters.insert(FilterMap::value_type("ThMLVariants", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
@@ -225,25 +229,18 @@ void SWMgr::init() {
 
 	osisplain = new OSISPlain();
 	cleanupFilters.push_back(osisplain);
+//#endif
 }
 
 
-SWMgr::SWMgr(SWFilterMgr *filterMgr) {
-	commonInit(0, 0, true, filterMgr);
-}
+void SWMgr::commonInit(SWConfig * iconfig, SWConfig * isysconfig, bool autoload, SWFilterMgr *filterMgr, bool multiMod) {
 
+	init();
 
-SWMgr::SWMgr(SWConfig *iconfig, SWConfig *isysconfig, bool autoload, SWFilterMgr *filterMgr) {
-	commonInit(iconfig, isysconfig, autoload, filterMgr);
-}
-
-
-void SWMgr::commonInit(SWConfig * iconfig, SWConfig * isysconfig, bool autoload, SWFilterMgr *filterMgr) {
+	mgrModeMultiMod = multiMod;
 	this->filterMgr = filterMgr;
 	if (filterMgr)
 		filterMgr->setParentMgr(this);
-
-	init();
 	
 	if (iconfig) {
 		config   = iconfig;
@@ -261,16 +258,29 @@ void SWMgr::commonInit(SWConfig * iconfig, SWConfig * isysconfig, bool autoload,
 }
 
 
-SWMgr::SWMgr(const char *iConfigPath, bool autoload, SWFilterMgr *filterMgr) {
+SWMgr::SWMgr(SWFilterMgr *filterMgr, bool multiMod) {
+	commonInit(0, 0, true, filterMgr, multiMod);
+}
 
+
+SWMgr::SWMgr(SWConfig *iconfig, SWConfig *isysconfig, bool autoload, SWFilterMgr *filterMgr, bool multiMod) {
+	commonInit(iconfig, isysconfig, autoload, filterMgr, multiMod);
+}
+
+
+SWMgr::SWMgr(const char *iConfigPath, bool autoload, SWFilterMgr *filterMgr, bool multiMod, bool augmentHome) {
+
+	init();
+
+	mgrModeMultiMod = multiMod;
 	SWBuf path;
 	
 	this->filterMgr = filterMgr;
 	if (filterMgr)
 		filterMgr->setParentMgr(this);
-
-	init();
 	
+	this->augmentHome = augmentHome;
+
 	path = iConfigPath;
 	int len = path.length();
 	if ((len < 1) || (iConfigPath[len-1] != '\\') && (iConfigPath[len-1] != '/'))
@@ -330,37 +340,21 @@ void SWMgr::findConfig(char *configType, char **prefixPath, char **configPath, s
 	char *envhomedir  = getenv ("HOME");
 
 	*configType = 0;
+	//debug=1;
 
-#ifndef _MSC_VER
 	// check working directory
-if (debug)
-	std::cerr << "Checking working directory for mods.conf...";
-#endif
+	DEBUGSTR("Checking working directory for mods.conf...");
 
 	if (FileMgr::existsFile(".", "mods.conf")) {
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "found\n";
-#endif
-
+		DEBUGSTR("found\n");
 		stdstr(prefixPath, "./");
 		stdstr(configPath, "./mods.conf");
 		return;
 	}
 
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nChecking working directory for mods.d...";
-#endif
-
+	DEBUGSTR("\nChecking working directory for mods.d...");
 	if (FileMgr::existsDir(".", "mods.d")) {
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "found\n";
-#endif
-
+		DEBUGSTR("found\n");
 		stdstr(prefixPath, "./");
 		stdstr(configPath, "./mods.d");
 		*configType = 1;
@@ -369,52 +363,27 @@ if (debug)
 
 
 	// check environment variable SWORD_PATH
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nChecking SWORD_PATH...";
-#endif
+	DEBUGSTR("\nChecking SWORD_PATH...");
 
 	if (envsworddir != NULL) {
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "found (" << envsworddir << ")\n";
-#endif
-
+		
+		DEBUGSTR("found (" << envsworddir << ")\n");
 		path = envsworddir;
 		if ((envsworddir[strlen(envsworddir)-1] != '\\') && (envsworddir[strlen(envsworddir)-1] != '/'))
 			path += "/";
 
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nChecking $SWORD_PATH for mods.conf...";
-#endif
-
+		DEBUGSTR("\nChecking $SWORD_PATH for mods.conf...");
 		if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "found\n";
-#endif
-
+			DEBUGSTR("found\n");
 			stdstr(prefixPath, path.c_str());
 			path += "mods.conf";
 			stdstr(configPath, path.c_str());
 			return;
 		}
 
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nChecking $SWORD_PATH for mods.d...";
-#endif
-
+		DEBUGSTR("\nChecking $SWORD_PATH for mods.d...");
 		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "found\n";
-#endif
-
+			DEBUGSTR("found\n");
 			stdstr(prefixPath, path.c_str());
 			path += "mods.d";
 			stdstr(configPath, path.c_str());
@@ -426,21 +395,13 @@ if (debug)
 
 	// check for systemwide globalConfPath
 
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nParsing " << globalConfPath << "...";
-#endif
-
+	DEBUGSTR("\nParsing " << globalConfPath << "...");
 	char *globPaths = 0;
 	char *gfp;
 	stdstr(&globPaths, globalConfPath);
 	for (gfp = strtok(globPaths, ":"); gfp; gfp = strtok(0, ":")) {
 
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nChecking for " << gfp << "...";
-#endif
-
+	DEBUGSTR("\nChecking for " << gfp << "...");
 		if (FileMgr::existsFile(gfp))
 			break;
 	}
@@ -454,62 +415,35 @@ if (debug)
 			homeDir += "/";
 		homeDir += ".sword/sword.conf";
 		if (FileMgr::existsFile(homeDir)) {
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nOverriding any systemwide sword.conf with one found in users home directory." << gfp << "...";
-#endif
+			DEBUGSTR("\nOverriding any systemwide sword.conf with one found in users home directory." << gfp << "...");
 			sysConfPath = homeDir;
 		}
 	}
 
 
 	if (sysConfPath.size()) {
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "found\n";
-#endif
-
+		DEBUGSTR("found\n");
 		SWConfig etcconf(sysConfPath);
 		if ((entry = etcconf.Sections["Install"].find("DataPath")) != etcconf.Sections["Install"].end()) {
 			path = (*entry).second;
 			if (((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '\\') && ((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '/'))
 				path += "/";
 
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "DataPath in " << sysConfPath << " is set to: " << path;
-#endif
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nChecking for mods.conf in DataPath ";
-#endif
+			DEBUGSTR("DataPath in " << sysConfPath << " is set to: " << path);
+			DEBUGSTR("\nChecking for mods.conf in DataPath ");
+			
 			if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "found\n";
-#endif
-
+				DEBUGSTR("found\n");
 				stdstr(prefixPath, path.c_str());
 				path += "mods.conf";
 				stdstr(configPath, path.c_str());
 				*configType = 1;
 			}
 
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nChecking for mods.d in DataPath ";
-#endif
+			DEBUGSTR("\nChecking for mods.d in DataPath ");
 
 			if (FileMgr::existsDir(path.c_str(), "mods.d")) {
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "found\n";
-#endif
-
+				DEBUGSTR("found\n");
 				stdstr(prefixPath, path.c_str());
 				path += "mods.d";
 				stdstr(configPath, path.c_str());
@@ -535,10 +469,7 @@ if (debug)
 
 	// check ~/.sword/
 
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nChecking home directory for ~/.sword/mods.conf" << path;
-#endif
+	DEBUGSTR("\nChecking home directory for ~/.sword/mods.conf" << path);
 
 	if (envhomedir != NULL) {
 		path = envhomedir;
@@ -546,30 +477,17 @@ if (debug)
 			path += "/";
 		path += ".sword/";
 		if (FileMgr::existsFile(path.c_str(), "mods.conf")) {
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << " found\n";
-#endif
-
+			DEBUGSTR("found\n");
 			stdstr(prefixPath, path.c_str());
 			path += "mods.conf";
 			stdstr(configPath, path.c_str());
 			return;
 		}
 
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "\nChecking home directory for ~/.sword/mods.d" << path;
-#endif
+		DEBUGSTR("\nChecking home directory for ~/.sword/mods.d" << path);
 
 		if (FileMgr::existsDir(path.c_str(), "mods.d")) {
-
-#ifndef _MSC_VER
-if (debug)
-	std::cerr << "found\n";
-#endif
-
+			DEBUGSTR("found\n");
 			stdstr(prefixPath, path.c_str());
 			path += "mods.d";
 			stdstr(configPath, path.c_str());
@@ -582,13 +500,18 @@ if (debug)
 
 void SWMgr::loadConfigDir(const char *ipath)
 {
-   DIR *dir;
-   struct dirent *ent;
-   SWBuf newmodfile;
+	DIR *dir;
+	struct dirent *ent;
+	SWBuf newmodfile;
  
 	if ((dir = opendir(ipath))) {
 		rewinddir(dir);
 		while ((ent = readdir(dir))) {
+			//check whether it ends with .conf, if it doesn't skip it!
+			if (ent->d_name && (strlen(ent->d_name) > 5) && strncmp(".conf", (ent->d_name + strlen(ent->d_name) - 5), 5 )) {
+				continue;
+			}
+			
 			if ((strcmp(ent->d_name, ".")) && (strcmp(ent->d_name, ".."))) {
 				newmodfile = ipath;
 				if ((ipath[strlen(ipath)-1] != '\\') && (ipath[strlen(ipath)-1] != '/'))
@@ -602,6 +525,7 @@ void SWMgr::loadConfigDir(const char *ipath)
 			}
 		}
 		closedir(dir);
+		
 		if (!config) {	// if no .conf file exist yet, create a default
 			newmodfile = ipath;
 			if ((ipath[strlen(ipath)-1] != '\\') && (ipath[strlen(ipath)-1] != '/'))
@@ -613,7 +537,7 @@ void SWMgr::loadConfigDir(const char *ipath)
 }
 
 
-void SWMgr::augmentModules(const char *ipath) {
+void SWMgr::augmentModules(const char *ipath, bool multiMod) {
 	SWBuf path = ipath;
 	if ((ipath[strlen(ipath)-1] != '\\') && (ipath[strlen(ipath)-1] != '/'))
 		path += "/";
@@ -630,13 +554,36 @@ void SWMgr::augmentModules(const char *ipath) {
 		config = myconfig = 0;
 		loadConfigDir(configPath);
 
-		CreateMods();
+		if (multiMod) {
+			// fix config's Section names to rename modules which are available more than once
+			// find out which sections are in both config objects
+			// inserting all configs first is not good because that overwrites old keys and new modules would share the same config
+			for (SectionMap::iterator it = config->Sections.begin(); it != config->Sections.end(); ++it) {
+				if (saveConfig->Sections.find( (*it).first ) != saveConfig->Sections.end()) { //if the new section is already present rename it
+					ConfigEntMap entMap((*it).second);
+					
+					SWBuf name;
+					int i = 1;
+					do { //module name already used?
+						name.setFormatted("%s_%d", (*it).first.c_str(), i);
+						i++;
+					} while (config->Sections.find(name) != config->Sections.end());
+					
+					config->Sections.insert(SectionMap::value_type(name, entMap) );
+					config->Sections.erase(it);
+				}
+			}
+		}
+		
+		CreateMods(multiMod);
 
 		stdstr(&prefixPath, savePrefixPath);
 		delete []savePrefixPath;
 		stdstr(&configPath, saveConfigPath);
 		delete []saveConfigPath;
+
 		(*saveConfig) += *config;
+		
 		homeConfig = myconfig;
 		config = myconfig = saveConfig;
 	}
@@ -680,19 +627,21 @@ signed char SWMgr::Load() {
 		}
 		else	config->Load();
 
-		CreateMods();
+		CreateMods(mgrModeMultiMod);
 
 		for (std::list<SWBuf>::iterator pathIt = augPaths.begin(); pathIt != augPaths.end(); pathIt++) {
-			augmentModules(pathIt->c_str());
+			augmentModules(pathIt->c_str(), mgrModeMultiMod);
 		}
-//	augment config with ~/.sword/mods.d if it exists ---------------------
-		char *envhomedir  = getenv ("HOME");
-		if (envhomedir != NULL && configType != 2) { // 2 = user only
-			SWBuf path = envhomedir;
-			if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
-				path += "/";
-			path += ".sword/";
-			augmentModules(path.c_str());
+		if (augmentHome) {
+			// augment config with ~/.sword/mods.d if it exists ---------------------
+			char *envhomedir  = getenv ("HOME");
+			if (envhomedir != NULL && configType != 2) { // 2 = user only
+				SWBuf path = envhomedir;
+				if ((envhomedir[strlen(envhomedir)-1] != '\\') && (envhomedir[strlen(envhomedir)-1] != '/'))
+					path += "/";
+				path += ".sword/";
+				augmentModules(path.c_str(), mgrModeMultiMod);
+			}
 		}
 // -------------------------------------------------------------------------
 		if ( !Modules.size() ) // config exists, but no modules
@@ -700,7 +649,7 @@ signed char SWMgr::Load() {
 
 	}
 	else {
-		SWLog::systemlog->LogError("SWMgr: Can't find 'mods.conf' or 'mods.d'.  Try setting:\n\tSWORD_PATH=<directory containing mods.conf>\n\tOr see the README file for a full description of setup options (%s)", (configPath) ? configPath : "<configPath is null>");
+		SWLog::getSystemLog()->logError("SWMgr: Can't find 'mods.conf' or 'mods.d'.  Try setting:\n\tSWORD_PATH=<directory containing mods.conf>\n\tOr see the README file for a full description of setup options (%s)", (configPath) ? configPath : "<configPath is null>");
 		ret = -1;
 	}
 
@@ -769,6 +718,7 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 	if ((!stricmp(driver, "zText")) || (!stricmp(driver, "zCom"))) {
 		SWCompress *compress = 0;
 		int blockType = CHAPTERBLOCKS;
+		int blockNum = 1;
 		misc1 = ((entry = section.find("BlockType")) != section.end()) ? (*entry).second : (SWBuf)"CHAPTER";
 		if (!stricmp(misc1.c_str(), "VERSE"))
 			blockType = VERSEBLOCKS;
@@ -776,6 +726,9 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 			blockType = CHAPTERBLOCKS;
 		else if (!stricmp(misc1.c_str(), "BOOK"))
 			blockType = BOOKBLOCKS;
+		
+		misc1 = ((entry = section.find("BlockNumber")) != section.end()) ? (*entry).second : (SWBuf)"1";
+		blockNum = atoi(misc1.c_str());
 
 		misc1 = ((entry = section.find("CompressType")) != section.end()) ? (*entry).second : (SWBuf)"LZSS";
 #ifndef EXCLUDEZLIB
@@ -815,7 +768,7 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 		newmod = new HREFCom(datapath.c_str(), misc1.c_str(), name, description.c_str());
 	}
 
-        int pos;  //used for position of final / in AbsoluteDataPath, but also set to 1 for modules types that need to strip module name
+        int pos = 0;  //used for position of final / in AbsoluteDataPath, but also set to 1 for modules types that need to strip module name
 	if (!stricmp(driver, "RawLD")) {
 		newmod = new RawLD(datapath.c_str(), name, description.c_str(), 0, enc, direction, markup, lang.c_str());
                 pos = 1;
@@ -867,7 +820,10 @@ SWModule *SWMgr::CreateMod(const char *name, const char *driver, ConfigEntMap &s
 	if ((entry = section.find("Type")) != section.end())
 		newmod->Type(entry->second.c_str());
 
-	newmod->setConfig(&section);
+	if (newmod){
+		newmod->setConfig(&section);
+	}
+	
 	return newmod;
 }
 
@@ -989,7 +945,7 @@ void SWMgr::AddStripFilters(SWModule *module, ConfigEntMap &section)
 }
 
 
-void SWMgr::CreateMods() {
+void SWMgr::CreateMods(bool multiMod) {
 	SectionMap::iterator it;
 	ConfigEntMap::iterator start;
 	ConfigEntMap::iterator end;
@@ -1017,7 +973,12 @@ void SWMgr::CreateMods() {
 				AddRenderFilters(newmod, section);
 				AddEncodingFilters(newmod, section);
 				
-				Modules.insert(ModMap::value_type(newmod->Name(), newmod));
+				SWModule *oldmod = Modules[newmod->Name()];
+				if (oldmod) {
+					delete oldmod;
+				}
+				
+				Modules[newmod->Name()] = newmod;
 			}
 		}
 	}
@@ -1035,65 +996,82 @@ void SWMgr::DeleteMods() {
 }
 
 
+void SWMgr::deleteModule(const char *modName) {
+	ModMap::iterator it = Modules.find(modName);
+	if (it != Modules.end()) {
+		delete (*it).second;
+		Modules.erase(it);
+	}
+}
+
+
 void SWMgr::InstallScan(const char *dirname)
 {
    DIR *dir;
    struct dirent *ent;
-   int conffd = 0;
+   FileDesc *conffd = 0;
    SWBuf newmodfile;
    SWBuf targetName;
  
-	if (!access(dirname, 04)) {
-          if ((dir = opendir(dirname))) {
-               rewinddir(dir);
-               while ((ent = readdir(dir))) {
-                    if ((strcmp(ent->d_name, ".")) && (strcmp(ent->d_name, ".."))) {
-                         newmodfile = dirname;
-                         if ((dirname[strlen(dirname)-1] != '\\') && (dirname[strlen(dirname)-1] != '/'))
-                              newmodfile += "/";
-                         newmodfile += ent->d_name;
-                         if (configType) {
-                              if (config > 0)
-                                   close(conffd);
-                              targetName = configPath;
-                              if ((configPath[strlen(configPath)-1] != '\\') && (configPath[strlen(configPath)-1] != '/'))
-                                   targetName += "/";
-                              targetName += ent->d_name;
-                              conffd = open(targetName.c_str(), O_WRONLY|O_CREAT, S_IREAD|S_IWRITE);
-                         }
-                         else {
-                              if (conffd < 1) {
-                                   conffd = open(config->filename.c_str(), O_WRONLY|O_APPEND);
-                                   if (conffd > 0)
-                                        lseek(conffd, 0L, SEEK_END);
-                              }
-                         }
-                         AddModToConfig(conffd, newmodfile.c_str());
-                         unlink(newmodfile.c_str());
-                    }
-               }
-               if (conffd > 0)
-                    close(conffd);
-               closedir(dir);
-          }
-     }
+	if (FileMgr::existsDir(dirname)) {
+		if ((dir = opendir(dirname))) {
+			rewinddir(dir);
+			while ((ent = readdir(dir))) {
+				if ((strcmp(ent->d_name, ".")) && (strcmp(ent->d_name, ".."))) {
+					newmodfile = dirname;
+					if ((dirname[strlen(dirname)-1] != '\\') && (dirname[strlen(dirname)-1] != '/'))
+						newmodfile += "/";
+					newmodfile += ent->d_name;
+
+					// mods.d
+					if (configType) {
+						if (conffd)
+							FileMgr::getSystemFileMgr()->close(conffd);
+						targetName = configPath;
+						if ((configPath[strlen(configPath)-1] != '\\') && (configPath[strlen(configPath)-1] != '/'))
+							targetName += "/";
+						targetName += ent->d_name;
+						conffd = FileMgr::getSystemFileMgr()->open(targetName.c_str(), FileMgr::WRONLY|FileMgr::CREAT, FileMgr::IREAD|FileMgr::IWRITE);
+					}
+
+					// mods.conf
+					else {
+						if (!conffd) {
+							conffd = FileMgr::getSystemFileMgr()->open(config->filename.c_str(), FileMgr::WRONLY|FileMgr::APPEND);
+							if (conffd > 0)
+								conffd->seek(0L, SEEK_END);
+							else {
+								FileMgr::getSystemFileMgr()->close(conffd);
+								conffd = 0;
+							}
+						}
+					}
+					AddModToConfig(conffd, newmodfile.c_str());
+					FileMgr::removeFile(newmodfile.c_str());
+				}
+			}
+			if (conffd)
+				FileMgr::getSystemFileMgr()->close(conffd);
+			closedir(dir);
+		}
+	}
 }
 
 
-char SWMgr::AddModToConfig(int conffd, const char *fname)
+char SWMgr::AddModToConfig(FileDesc *conffd, const char *fname)
 {
-	int modfd;
+	FileDesc *modfd;
 	char ch;
 
-	SWLog::systemlog->LogTimedInformation("Found new module [%s]. Installing...", fname);
-	modfd = open(fname, O_RDONLY);
+	SWLog::getSystemLog()->logTimedInformation("Found new module [%s]. Installing...", fname);
+	modfd = FileMgr::getSystemFileMgr()->open(fname, FileMgr::RDONLY);
 	ch = '\n';
-	write(conffd, &ch, 1);
-	while (read(modfd, &ch, 1) == 1)
-		write(conffd, &ch, 1);
+	conffd->write(&ch, 1);
+	while (modfd->read(&ch, 1) == 1)
+		conffd->write(&ch, 1);
 	ch = '\n';
-	write(conffd, &ch, 1);
-	close(modfd);
+	conffd->write(&ch, 1);
+	FileMgr::getSystemFileMgr()->close(modfd);
 	return 0;
 }
 
