@@ -2,7 +2,7 @@
  *  swsearchable.h	- definition of class SWSearchable used to provide an
  *	interface for objects that be searched.
  *
- * $Id: swsearchable.cpp,v 1.1 2003/08/29 06:00:16 scribe Exp $
+ * $Id: swsearchable.cpp 1715 2005-02-08 10:06:35Z scribe $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -34,9 +34,11 @@ SWSearchable::~SWSearchable() {
 }
 
 	// special search framework
-signed char SWSearchable::createSearchFramework() {
+signed char SWSearchable::createSearchFramework(void (*percent)(char, void *), void *percentUserData) {
 	return 0;
 }
 
+void SWSearchable::deleteSearchFramework() {
+}
 
 SWORD_NAMESPACE_END
