@@ -9,21 +9,10 @@
 #include <stdio.h>
 #include <fcntl.h>
 
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
-
-#include <utilfuns.h>
 #include <rawverse.h>
 #include <rawfiles.h>
 #include <filemgr.h>
 
-#ifndef O_BINARY                // O_BINARY is needed in Borland C++ 4.53
-#define O_BINARY 0              // If it hasn't been defined than we probably
-#endif                          // don't need it.
-
 SWORD_NAMESPACE_START
 
  /******************************************************************************
@@ -34,7 +23,7 @@ SWORD_NAMESPACE_START
  *	idisp	 - Display object to use for displaying
  */
 
-RawFiles::RawFiles(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp, SWTextEncoding enc, SWTextDirection dir, SWTextMarkup mark, const char* ilang) : RawVerse(ipath, O_RDWR), SWCom(iname, idesc, idisp, enc, dir, mark, ilang)
+RawFiles::RawFiles(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp, SWTextEncoding enc, SWTextDirection dir, SWTextMarkup mark, const char* ilang) : RawVerse(ipath, FileMgr::RDWR), SWCom(iname, idesc, idisp, enc, dir, mark, ilang)
 {
 }
 
@@ -62,14 +51,10 @@ SWBuf &RawFiles::getRawEntryBuf() {
 	char *tmpbuf;
 	VerseKey *key = 0;
 
-#ifndef _WIN32_WCE
-	try {
-#endif
+	SWTRY {
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
-	catch ( ... ) {}
-#endif
+	SWCATCH ( ... ) {}
 	if (!key)
 		key = new VerseKey(this->key);
 
@@ -82,18 +67,18 @@ SWBuf &RawFiles::getRawEntryBuf() {
 		readText(key->Testament(), start, size, entryBuf);
 		tmpbuf += entryBuf;
 		entryBuf = "";
-		datafile = FileMgr::systemFileMgr.open(tmpbuf.c_str(), O_RDONLY|O_BINARY);
+		datafile = FileMgr::getSystemFileMgr()->open(tmpbuf.c_str(), FileMgr::RDONLY);
 		if (datafile->getFd() > 0) {
-			size = lseek(datafile->getFd(), 0, SEEK_END);
+			size = datafile->seek(0, SEEK_END);
 			char *tmpBuf = new char [ size + 1 ];
 			memset(tmpBuf, 0, size + 1);
-			lseek(datafile->getFd(), 0, SEEK_SET);
-			read(datafile->getFd(), tmpBuf, size);
+			datafile->seek(0, SEEK_SET);
+			datafile->read(tmpBuf, size);
 			entryBuf = tmpBuf;
 			delete [] tmpBuf;
 //			preptext(entrybuf);
 		}
-		FileMgr::systemFileMgr.close(datafile);
+		FileMgr::getSystemFileMgr()->close(datafile);
 	}
 
 	if (key != this->key)
@@ -115,10 +100,10 @@ void RawFiles::setEntry(const char *inbuf, long len) {
 	VerseKey *key = 0;
 
 	len = (len<0)?strlen(inbuf):len;
-	try {
+	SWTRY {
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
 	}
-	catch ( ... ) {}
+	SWCATCH ( ... ) {}
 	if (!key)
 		key = new VerseKey(this->key);
 
@@ -139,11 +124,11 @@ void RawFiles::setEntry(const char *inbuf, long len) {
 		doSetText(key->Testament(), key->Index(), tmpbuf);
 		entryBuf += tmpbuf;
 	}
-	datafile = FileMgr::systemFileMgr.open(entryBuf, O_CREAT|O_WRONLY|O_BINARY|O_TRUNC);
+	datafile = FileMgr::getSystemFileMgr()->open(entryBuf, FileMgr::CREAT|FileMgr::WRONLY|FileMgr::TRUNC);
 	if (datafile->getFd() > 0) {
-		write(datafile->getFd(), inbuf, len);
+		datafile->write(inbuf, len);
 	}
-	FileMgr::systemFileMgr.close(datafile);
+	FileMgr::getSystemFileMgr()->close(datafile);
 	
 	if (key != this->key)
 		delete key;
@@ -164,10 +149,10 @@ void RawFiles::linkEntry(const SWKey *inkey) {
 	char *tmpbuf;
 	const VerseKey *key = 0;
 
-	try {
+	SWTRY {
 		key = SWDYNAMIC_CAST(VerseKey, inkey);
 	}
-	catch ( ... ) {}
+	SWCATCH ( ... ) {}
 	if (!key)
 		key = new VerseKey(this->key);
 
@@ -181,10 +166,10 @@ void RawFiles::linkEntry(const SWKey *inkey) {
 			delete key;
 		key = 0;
 
-		try {
+		SWTRY {
 			key = SWDYNAMIC_CAST(VerseKey, inkey);
 		}
-		catch ( ... ) {}
+		SWCATCH ( ... ) {}
 		if (!key)
 			key = new VerseKey(this->key);
 		doSetText(key->Testament(), key->Index(), tmpbuf.c_str());
@@ -205,14 +190,10 @@ void RawFiles::deleteEntry() {
 
 	VerseKey *key = 0;
 
-#ifndef _WIN32_WCE
-	try {
-#endif
+	SWTRY {
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
-#ifndef _WIN32_WCE
 	}
-	catch ( ... ) {}
-#endif
+	SWCATCH ( ... ) {}
 	if (!key)
 		key = new VerseKey(this->key);
 
@@ -236,15 +217,15 @@ char *RawFiles::getNextFilename() {
 	FileDesc *datafile;
 
 	sprintf(incfile, "%s/incfile", path);
-	datafile = FileMgr::systemFileMgr.open(incfile, O_RDONLY|O_BINARY);
-	if (read(datafile->getFd(), &number, 4) != 4)
+	datafile = FileMgr::getSystemFileMgr()->open(incfile, FileMgr::RDONLY);
+	if (datafile->read(&number, 4) != 4)
 		number = 0;
 	number++;
-	FileMgr::systemFileMgr.close(datafile);
+	FileMgr::getSystemFileMgr()->close(datafile);
 	
-	datafile = FileMgr::systemFileMgr.open(incfile, O_CREAT|O_WRONLY|O_BINARY|O_TRUNC);
-	write(datafile->getFd(), &number, 4);
-	FileMgr::systemFileMgr.close(datafile);
+	datafile = FileMgr::getSystemFileMgr()->open(incfile, FileMgr::CREAT|FileMgr::WRONLY|FileMgr::TRUNC);
+	datafile->write(&number, 4);
+	FileMgr::getSystemFileMgr()->close(datafile);
 	sprintf(incfile, "%.7ld", number-1);
 	return incfile;
 }
@@ -256,10 +237,10 @@ char RawFiles::createModule (const char *path) {
 	FileDesc *datafile;
 
 	sprintf(incfile, "%s/incfile", path);
-	datafile = FileMgr::systemFileMgr.open(incfile, O_CREAT|O_WRONLY|O_BINARY|O_TRUNC);
+	datafile = FileMgr::getSystemFileMgr()->open(incfile, FileMgr::CREAT|FileMgr::WRONLY|FileMgr::TRUNC);
     delete [] incfile;
-	write(datafile->getFd(), &zero, 4);
-	FileMgr::systemFileMgr.close(datafile);
+	datafile->write(&zero, 4);
+	FileMgr::getSystemFileMgr()->close(datafile);
 
     return RawVerse::createModule (path);
 }
