@@ -10,16 +10,11 @@
 #include <fcntl.h>
 #include <errno.h>
 
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
-
 #include <stdlib.h>
-#include <utilfuns.h>
+#include <utilstr.h>
 #include <rawstr.h>
 #include <sysdata.h>
+#include <swlog.h>
 
 SWORD_NAMESPACE_START
 
@@ -41,29 +36,24 @@ char RawStr::nl = '\n';
 
 RawStr::RawStr(const char *ipath, int fileMode)
 {
-	char buf[127];
+	SWBuf buf;
 
 	lastoff = -1;
 	path = 0;
 	stdstr(&path, ipath);
 
-#ifndef O_BINARY		// O_BINARY is needed in Borland C++ 4.53
-#define O_BINARY 0		// If it hasn't been defined than we probably
-#endif				// don't need it.
-
 	if (fileMode == -1) { // try read/write if possible
-		fileMode = O_RDWR;
+		fileMode = FileMgr::RDWR;
 	}
 		
-	sprintf(buf, "%s.idx", path);
-	idxfd = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
+	buf.setFormatted("%s.idx", path);
+	idxfd = FileMgr::getSystemFileMgr()->open(buf, fileMode, true);
 
-	sprintf(buf, "%s.dat", path);
-	datfd = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
+	buf.setFormatted("%s.dat", path);
+	datfd = FileMgr::getSystemFileMgr()->open(buf, fileMode, true);
 
 	if (datfd < 0) {
-		sprintf(buf, "Error: %d", errno);
-		perror(buf);
+		SWLog::getSystemLog()->logError("%d", errno);
 	}
 
 	instance++;
@@ -81,8 +71,8 @@ RawStr::~RawStr()
 
 	--instance;
 
-	FileMgr::systemFileMgr.close(idxfd);
-	FileMgr::systemFileMgr.close(datfd);
+	FileMgr::getSystemFileMgr()->close(idxfd);
+	FileMgr::getSystemFileMgr()->close(datfd);
 }
 
 
@@ -100,15 +90,15 @@ void RawStr::getIDXBufDat(long ioffset, char **buf)
 	int size;
 	char ch;
 	if (datfd > 0) {
-		lseek(datfd->getFd(), ioffset, SEEK_SET);
-		for (size = 0; read(datfd->getFd(), &ch, 1) == 1; size++) {
+		datfd->seek(ioffset, SEEK_SET);
+		for (size = 0; datfd->read(&ch, 1) == 1; size++) {
 			if ((ch == '\\') || (ch == 10) || (ch == 13))
 				break;
 		}
 		*buf = (*buf) ? (char *)realloc(*buf, size*2 + 1) : (char *)malloc(size*2 + 1);
 		if (size) {
-			lseek(datfd->getFd(), ioffset, SEEK_SET);
-			read(datfd->getFd(), *buf, size);
+			datfd->seek(ioffset, SEEK_SET);
+			datfd->read(*buf, size);
 		}
 		(*buf)[size] = 0;
 		toupperstr_utf8(*buf, size*2);
@@ -135,8 +125,8 @@ void RawStr::getIDXBuf(long ioffset, char **buf)
 	long offset;
 	
 	if (idxfd > 0) {
-		lseek(idxfd->getFd(), ioffset, SEEK_SET);
-		read(idxfd->getFd(), &offset, 4);
+		idxfd->seek(ioffset, SEEK_SET);
+		idxfd->read(&offset, 4);
 
 		offset = swordtoarch32(offset);
 
@@ -164,7 +154,7 @@ signed char RawStr::findOffset(const char *ikey, long *start, unsigned short *si
 	long headoff, tailoff, tryoff = 0, maxoff = 0;
 
 	if (idxfd->getFd() >=0) {
-		tailoff = maxoff = lseek(idxfd->getFd(), 0, SEEK_END) - 6;
+		tailoff = maxoff = idxfd->seek(0, SEEK_END) - 6;
 		retval = (tailoff >= 0) ? 0 : -2;	// if NOT new file
 		if (*ikey) {
 			headoff = 0;
@@ -205,11 +195,11 @@ signed char RawStr::findOffset(const char *ikey, long *start, unsigned short *si
 		}
 		else	tryoff = 0;
 
-		lseek(idxfd->getFd(), tryoff, SEEK_SET);
+		idxfd->seek(tryoff, SEEK_SET);
 
 		*start = *size = 0;
-		read(idxfd->getFd(), start, 4);
-		read(idxfd->getFd(), size, 2);
+		idxfd->read(start, 4);
+		idxfd->read(size, 2);
 		if (idxoff)
 			*idxoff = tryoff;
 
@@ -225,7 +215,7 @@ signed char RawStr::findOffset(const char *ikey, long *start, unsigned short *si
 			bool bad = false;
 			if (((tryoff + (away*6)) < -6) || (tryoff + (away*6) > (maxoff+6)))
 				bad = true;
-			else if (lseek(idxfd->getFd(), tryoff, SEEK_SET) < 0)
+			else if (idxfd->seek(tryoff, SEEK_SET) < 0)
 				bad = true;
 			if (bad) {
 				retval = -1;
@@ -236,8 +226,8 @@ signed char RawStr::findOffset(const char *ikey, long *start, unsigned short *si
 					*idxoff = tryoff;
 				break;
 			}
-			read(idxfd->getFd(), start, 4);
-			read(idxfd->getFd(), size, 2);
+			idxfd->read(start, 4);
+			idxfd->read(size, 2);
 			if (idxoff)
 				*idxoff = tryoff;
 
@@ -346,8 +336,8 @@ void RawStr::readText(long istart, unsigned short *isize, char **idxbuf, SWBuf &
 
 		*idxbuf = new char [ (*isize) ];
 
-		lseek(datfd->getFd(), start, SEEK_SET);
-		read(datfd->getFd(), buf.getRawData(), (int)((*isize) - 1));
+		datfd->seek(start, SEEK_SET);
+		datfd->read(buf.getRawData(), (int)((*isize) - 1));
 
 		for (ch = 0; buf[ch]; ch++) {		// skip over index string
 			if (buf[ch] == 10) {
@@ -416,7 +406,7 @@ void RawStr::doSetText(const char *ikey, const char *buf, long len)
 	if (strcmp(key, dbKey) < 0) {
 	}
 	else if (strcmp(key, dbKey) > 0) {
-		if (errorStatus != -2)	// not a new file
+		if (errorStatus != (char)-2)	// not a new file
 			idxoff += 6;
 		else idxoff = 0;
 	}
@@ -424,8 +414,8 @@ void RawStr::doSetText(const char *ikey, const char *buf, long len)
 		do {
 			tmpbuf = new char [ size + 2 ];
 			memset(tmpbuf, 0, size + 2);
-			lseek(datfd->getFd(), start, SEEK_SET);
-			read(datfd->getFd(), tmpbuf, (int)(size - 1));
+			datfd->seek(start, SEEK_SET);
+			datfd->read(tmpbuf, (int)(size - 1));
 
 			for (ch = tmpbuf; *ch; ch++) {		// skip over index string
 				if (*ch == 10) {
@@ -450,14 +440,14 @@ void RawStr::doSetText(const char *ikey, const char *buf, long len)
 		while (true);	// while we're resolving links
 	}
 
-	endoff = lseek(idxfd->getFd(), 0, SEEK_END);
+	endoff = idxfd->seek(0, SEEK_END);
 
 	shiftSize = endoff - idxoff;
 
 	if (shiftSize > 0) {
 		idxBytes = new char [ shiftSize ];
-		lseek(idxfd->getFd(), idxoff, SEEK_SET);
-		read(idxfd->getFd(), idxBytes, shiftSize);
+		idxfd->seek(idxoff, SEEK_SET);
+		idxfd->read(idxBytes, shiftSize);
 	}
 
 	outbuf = new char [ len + strlen(key) + 5 ];
@@ -466,31 +456,31 @@ void RawStr::doSetText(const char *ikey, const char *buf, long len)
 	memcpy(outbuf + size, buf, len);
 	size = outsize = size + (len);
 
-	start = outstart = lseek(datfd->getFd(), 0, SEEK_END);
+	start = outstart = datfd->seek(0, SEEK_END);
 
 	outstart = archtosword32(start);
 	outsize  = archtosword16(size);
 
-	lseek(idxfd->getFd(), idxoff, SEEK_SET);
+	idxfd->seek(idxoff, SEEK_SET);
 	if (len > 0) {
-		lseek(datfd->getFd(), start, SEEK_SET);
-		write(datfd->getFd(), outbuf, (int)size);
+		datfd->seek(start, SEEK_SET);
+		datfd->write(outbuf, (int)size);
 
 		// add a new line to make data file easier to read in an editor
-		write(datfd->getFd(), &nl, 2);
+		datfd->write(&nl, 2);
 		
-		write(idxfd->getFd(), &outstart, 4);
-		write(idxfd->getFd(), &outsize, 2);
+		idxfd->write(&outstart, 4);
+		idxfd->write(&outsize, 2);
 		if (idxBytes) {
-			write(idxfd->getFd(), idxBytes, shiftSize);
+			idxfd->write(idxBytes, shiftSize);
 			delete [] idxBytes;
 		}
 	}
 	else {	// delete entry
 		if (idxBytes) {
-			write(idxfd->getFd(), idxBytes+6, shiftSize-6);
-			lseek(idxfd->getFd(), -1, SEEK_CUR);	// last valid byte
-			FileMgr::systemFileMgr.trunc(idxfd);	// truncate index
+			idxfd->write(idxBytes+6, shiftSize-6);
+			idxfd->seek(-1, SEEK_CUR);	// last valid byte
+			FileMgr::getSystemFileMgr()->trunc(idxfd);	// truncate index
 			delete [] idxBytes;
 		}
 	}
@@ -536,16 +526,16 @@ signed char RawStr::createModule(const char *ipath)
 		path[strlen(path)-1] = 0;
 
 	sprintf(buf, "%s.dat", path);
-	unlink(buf);
-	fd = FileMgr::systemFileMgr.open(buf, O_CREAT|O_WRONLY|O_BINARY, S_IREAD|S_IWRITE);
+	FileMgr::removeFile(buf);
+	fd = FileMgr::getSystemFileMgr()->open(buf, FileMgr::CREAT|FileMgr::WRONLY, FileMgr::IREAD|FileMgr::IWRITE);
 	fd->getFd();
-	FileMgr::systemFileMgr.close(fd);
+	FileMgr::getSystemFileMgr()->close(fd);
 
 	sprintf(buf, "%s.idx", path);
-	unlink(buf);
-	fd2 = FileMgr::systemFileMgr.open(buf, O_CREAT|O_WRONLY|O_BINARY, S_IREAD|S_IWRITE);
+	FileMgr::removeFile(buf);
+	fd2 = FileMgr::getSystemFileMgr()->open(buf, FileMgr::CREAT|FileMgr::WRONLY, FileMgr::IREAD|FileMgr::IWRITE);
 	fd2->getFd();
-	FileMgr::systemFileMgr.close(fd2);
+	FileMgr::getSystemFileMgr()->close(fd2);
 
 	delete [] path;
 	
