@@ -11,17 +11,13 @@
 #include <swbuf.h>
 #include <versekey.h>
 #include <utilxml.h>
-#ifndef __GNUC__
-#else
-#include <unixstr.h>
-#endif
 
 SWORD_NAMESPACE_START
 
 const char oName[] = "Footnotes";
 const char oTip[] = "Toggles Footnotes On and Off if they exist";
 
-const SWBuf choices[3] = {"On", "Off", ""};
+const SWBuf choices[3] = {"Off", "On", ""};
 const StringList oValues(&choices[0], &choices[2]);
 
 
@@ -49,6 +45,8 @@ char GBFFootnotes::processText (SWBuf &text, const SWKey *key, const SWModule *m
 
 	SWBuf orig = text;
 	const char *from = orig.c_str();
+	
+	//XMLTag tag;
 
 	for (text = ""; *from; from++) {
 		if (*from == '<') {
@@ -59,21 +57,25 @@ char GBFFootnotes::processText (SWBuf &text, const SWKey *key, const SWModule *m
 		if (*from == '>') {	// process tokens
 			intoken = false;
 
-			XMLTag tag(token);
-			if (!strcmp(tag.getName(), "RF")) {
+			//XMLTag tag(token);
+			if (!strncmp(token, "RF",2)) {
+// 				tag = token;
+				
 				refs = "";
-				startTag = tag;
+				startTag = token;
 				hide = true;
 				tagText = "";
 				continue;
 			}
-			else if (!strcmp(tag.getName(), "Rf")) {
+			else if (!strncmp(token, "Rf",2)) {
 				if (module->isProcessEntryAttributes()) {
-					if(tagText.length() == 1 || !strcmp(module->Name(), "IGNT")) {
+					//tag = token;
+				
+					if((tagText.length() == 1) || !strcmp(module->Name(), "IGNT")) {
 						if (option) { // for ASV marks text in verse then put explanation at end of verse
-							text += " <FA>(";
+							text.append(" <FS>(");
 							text.append(tagText);
-							text += ")<Fr>";
+							text.append(")<Fs>");
 							hide = false;
 							continue;
 						}
@@ -83,7 +85,7 @@ char GBFFootnotes::processText (SWBuf &text, const SWKey *key, const SWModule *m
 					sprintf(buf, "%i", ++footnoteNum);
 					module->getEntryAttributes()["Footnote"]["count"]["value"] = buf;
 					StringList attributes = startTag.getAttributeNames();
-					for (StringList::iterator it = attributes.begin(); it != attributes.end(); it++) {
+					for (StringList::const_iterator it = attributes.begin(); it != attributes.end(); it++) {
 						module->getEntryAttributes()["Footnote"][buf][it->c_str()] = startTag.getAttribute(it->c_str());
 					}
 					module->getEntryAttributes()["Footnote"][buf]["body"] = tagText;
@@ -91,40 +93,33 @@ char GBFFootnotes::processText (SWBuf &text, const SWKey *key, const SWModule *m
 				}
 				hide = false;
 				if (option) {	
-					text += startTag;
+					text.append(startTag);
 					text.append(tagText);
 				}
 				else	continue;
 			}
 			if (!hide) {
-				text += '<';
+				text.append('<');
 				text.append(token);
-				text += '>';
+				text.append('>');
 			}
 			else {
-				tagText += '<';
+				tagText.append('<');
 				tagText.append(token);
-				tagText += '>';
+				tagText.append('>');
 			}
 			continue;
 		}
 		if (intoken) { //copy token
-			token += *from;
+			token.append(*from);
 		}
 		else if (!hide) { //copy text which is not inside a token
-			text += *from;
+			text.append(*from);
 		}
-		else tagText += *from;
+		else tagText.append(*from);
 	}
 	return 0;
 	
-	
-	
-	
-	
-	
-	
-	
 	/*
 	if (!option) {	// if we don't want footnotes
 		char token[4096]; // cheese.  Fix.
