@@ -7,17 +7,13 @@
 
 #include <stdlib.h>
 #include <gbfmorph.h>
-#ifndef __GNUC__
-#else
-#include <unixstr.h>
-#endif
 
 SWORD_NAMESPACE_START
 
 const char oName[] = "Morphological Tags";
 const char oTip[] = "Toggles Morphological Tags On and Off if they exist";
 
-const SWBuf choices[3] = {"On", "Off", ""};
+const SWBuf choices[3] = {"Off", "On", ""};
 const StringList oValues(&choices[0], &choices[2]);
 
 GBFMorph::GBFMorph() : SWOptionFilter(oName, oTip, &oValues) {
