@@ -11,12 +11,9 @@
 #include <gbfosis.h>
 #include <swmodule.h>
 #include <versekey.h>
+#include <utilxml.h>
 #include <swlog.h>
 #include <stdarg.h>
-#ifndef __GNUC__
-#else
-#include <unixstr.h>
-#endif
 
 SWORD_NAMESPACE_START
 
@@ -29,54 +26,51 @@ GBFOSIS::~GBFOSIS() {
 
 
 char GBFOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module) { 
-/*
-	char *to, *from, token[2048]; // cheese.  Fix.
+	char token[2048]; //cheesy, we seem to like cheese :)
 	int tokpos = 0;
 	bool intoken = false;
-	int len;
-	bool lastspace = false;
-	int word = 1;
-	char val[128];
-	char buf[128];
-	char wordstr[5];
-	char *valto;
-	char *ch;
-	char *textStart, *textEnd;
-	char *wordStart, *wordEnd;
-	char *fromStart;
-	bool newText = false;
-	bool newWord = false;
-	SWBuf tmp;
-	bool suspendTextPassThru = false;
 	bool keepToken = false;
-	bool handled = false;
-
-	len = strlen(text) + 1;	// shift string to right of buffer
-	if (len < maxlen) {
-		memmove(&text[maxlen - len], text, len);
-		from = &text[maxlen - len];
-	}
-	else	from = text;
 	
-	textStart = from;
-	fromStart = from;
-	wordStart = text;
+//	static QuoteStack quoteStack;
 
-	static QuoteStack quoteStack;
+	SWBuf orig = text;
+	SWBuf tmp;
+	SWBuf value;
+	
+	bool newtext = false;
+	
+	bool suspendTextPassThru = false;
+	bool handled = false;
+	bool newWord = false;
+	bool newText = false;
+	bool lastspace = false;
+	
+	const char *wordStart = text.c_str();
+	const char *wordEnd;
+	
+	const char *textStart;
+	const char *textEnd;
+	
+	SWBuf textNode = "";
 
-	// -------------------------------
-
-	for (to = text; *from; from++) {
-		if (*from == '<') {
+	char wordstr[5];
+	
+	SWBuf buf;
+		
+	text = "";
+	for (const char* from = orig.c_str(); *from; ++from) {
+		if (*from == '<') { //start of new token detected
 			intoken = true;
 			tokpos = 0;
 			token[0] = 0;
 			token[1] = 0;
 			token[2] = 0;
-			textEnd = from-1;
-			wordEnd = to;
+			textEnd = from-1; //end of last text node found
+			wordEnd = text.c_str() + text.length();//not good, instead of wordEnd = to!
+			
 			continue;
 		}
+		
 		if (*from == '>') {	// process tokens
 			intoken = false;
 			keepToken = false;
@@ -84,74 +78,87 @@ char GBFOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 			newWord = true;
 			handled = false;
 
-			while (wordStart < (text+maxlen)) {
-//				if (strchr(" ,;.?!()'\"", *wordStart))
-				if (strchr(";, .:?!()'\"", *wordStart) && wordStart[0] && wordStart[1])
+			while (wordStart < (text.c_str() + text.length())) { //hack
+				if (strchr(";,. :?!()'\"", *wordStart) && wordStart[0] && wordStart[1])
 					wordStart++;
 				else break;
-			}
+			}			
 			while (wordEnd > wordStart) {
-				if (strchr(" ,;.:?!()'\"", *wordEnd))
+				if (strchr(" ,;:.?!()'\"", *wordEnd))
 					wordEnd--;
 				else break;
 			}
 
 			// Scripture Reference
 			if (!strncmp(token, "scripRef", 8)) {
-	//			pushString(buf, "<reference work=\"Bible.KJV\" reference=\"");
 				suspendTextPassThru = true;
 				newText = true;
 				handled = true;
 			}
-			else	if (!strncmp(token, "/scripRef", 9)) {
+			else if (!strncmp(token, "/scripRef", 9)) {
 				tmp = "";
 				tmp.append(textStart, (int)(textEnd - textStart)+1);
-				pushString(&to, convertToOSIS(tmp.c_str(), key));
+				text += VerseKey::convertToOSIS(tmp.c_str(), key);
+				
 				lastspace = false;
 				suspendTextPassThru = false;
 				handled = true;
 			}
 
 			// Footnote
-			if (!strcmp(token, "RF")) {
+			if (!strcmp(token, "RF") || !strncmp(token, "RF ", 3)) { //the GBFFootnotes filter adds the attribute "swordFootnote", we want to catch that, too
 	//			pushString(buf, "<reference work=\"Bible.KJV\" reference=\"");
-				pushString(&to, "<note type=\"x-StudyNote\">");
+				text += "<note type=\"x-StudyNote\">";
 				newText = true;
 				lastspace = false;
 				handled = true;
 			}
 			else	if (!strcmp(token, "Rf")) {
-				pushString(&to, "</note>");
+				text += "</note>";
 				lastspace = false;
 				handled = true;
 			}
 			// hebrew titles
 			if (!strcmp(token, "TH")) {
-				pushString(&to, "<title type=\"psalm\">");
+				text += "<title type=\"psalm\">";
 				newText = true;
 				lastspace = false;
 				handled = true;
 			}
 			else	if (!strcmp(token, "Th")) {
-				pushString(&to, "</title>");
+				text += "</title>";
 				lastspace = false;
 				handled = true;
 			}
 			// Italics assume transchange
 			if (!strcmp(token, "FI")) {
-				pushString(&to, "<transChange type=\"added\">");
+				text += "<transChange type=\"added\">";
 				newText = true;
 				lastspace = false;
 				handled = true;
 			}
 			else	if (!strcmp(token, "Fi")) {
-				pushString(&to, "</transChange>");
+				text += "</transChange>";
+				lastspace = false;
+				handled = true;
+			}
+			// less than
+			if (!strcmp(token, "CT")) {
+				text += "&lt;";
+				newText = true;
+				lastspace = false;
+				handled = true;
+			}
+			// greater than
+			if (!strcmp(token, "CG")) {
+				text += "&gt;";
+				newText = true;
 				lastspace = false;
 				handled = true;
 			}
 			// Paragraph break.  For now use empty paragraph element
 			if (!strcmp(token, "CM")) {
-				pushString(&to, "<milestone type=\"x-p\" />");
+				text += "<milestone type=\"x-p\" />";
 				newText = true;
 				lastspace = false;
 				handled = true;
@@ -164,7 +171,7 @@ char GBFOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 					continue;
 //					return false;
 
-				pushString(&to, "<figure src=\"");
+				text += "<figure src=\"";
 				const char *c;
 				for (c = src;((*c) && (*c != '"')); c++);
 
@@ -177,10 +184,11 @@ char GBFOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 //				}
 // end of uncomment for asolute path logic 
 
-				for (c++;((*c) && (*c != '"')); c++)
-					*to++ = *c;
-
-				pushString(&to, "\" />");
+				for (c++;((*c) && (*c != '"')); c++) {
+					text += *c;
+				}
+				text += "\" />";
+				
 				lastspace = false;
 				handled = true;
 			}
@@ -188,107 +196,109 @@ char GBFOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 			// Strongs numbers
 			else if (*token == 'W' && (token[1] == 'G' || token[1] == 'H')) {	// Strongs
 				bool divineName = false;
-				if (module->isProcessEntryAttributes()) {
-					valto = val;
-					for (unsigned int i = 1; ((token[i]) && (i < 150)); i++)
-						*valto++ = token[i];
-					*valto = 0;
-					// normal strongs number
-					strstrip(val);
-					if (!strncmp(wordStart, "<w ", 3)) {
-						strtok(wordStart, ">");
-						char *attStart = strstr(wordStart, "lemma");
-						if (attStart) {
-							attStart += 7;
-							sprintf(buf, "x-Strongs:%s|", val);
-						}
-						else {
-							attStart = wordStart + 3;
-							sprintf(buf, "lemma=\"x-Strongs:%s\" ", val);
-						}
-						wordStart[strlen(wordStart)] = '>';
-						memmove(attStart+strlen(buf), attStart, (to-attStart)+1);
-						memcpy(attStart, buf, strlen(buf));
-						to+=strlen(buf);
+				value = token+1;
+			
+				// normal strongs number
+				//strstrip(val);
+				if (!strncmp(wordStart, "<w ", 3)) {
+					const char *attStart = strstr(wordStart, "lemma");
+					if (attStart) {
+						attStart += 7;
+						
+						buf = "";
+						buf.appendFormatted("strong:%s ", value.c_str());
+					}
+					else { // no lemma attribute
+						attStart = wordStart + 3;
+						
+						buf = "";
+						buf.appendFormatted(buf, "lemma=\"strong:%s\" ", value.c_str());
+					}
+
+					text.insert(attStart - text.c_str(), buf);
+				}
+				else { //wordStart doesn't point to an existing <w> attribute!
+					if (!strcmp(value.c_str(), "H03068")) {	//divineName
+						buf = "";
+						buf.appendFormatted("<divineName><w lemma=\"strong:%s\">", value.c_str());
+						
+						divineName = true;
 					}
 					else {
-						if (!strcmp(val, "H03068")) {	//divineName
-							sprintf(buf, "<divineName><w lemma=\"x-Strongs:%s\">", val);
-							divineName = true;
-						}
-						else sprintf(buf, "<w lemma=\"x-Strongs:%s\">", val);
-
-						memmove(wordStart+strlen(buf), wordStart, (to-wordStart)+1);
-						memcpy(wordStart, buf, strlen(buf));
-						to+=strlen(buf);
-
-						if (divineName) {
-							wordStart += 12;
-							pushString(&to, "</w></divineName>");
-						}
-						else	pushString(&to, "</w>");
-
-						module->getEntryAttributes()["Word"][wordstr]["Strongs"] = val;
-						lastspace = false;
+						buf = "";
+						buf.appendFormatted("<w lemma=\"strong:%s\">", value.c_str());
 					}
+
+					text.insert(wordStart - text.c_str(), buf);
+
+					if (divineName) {
+						wordStart += 12;
+						text += "</w></divineName>";
+					}
+					else	text += "</w>";
+
+					lastspace = false;
 				}
 				handled = true;
 			}
 
 			// Morphology
-			else if (*token == 'W' && token[1] == 'T' && (token[2] == 'G' || token[2] == 'H')) {	// Strongs
-				valto = val;
-				for (unsigned int i = 1; ((token[i]) && (i < 150)); i++)
-					*valto++ = token[i];
-				*valto = 0;
-				strstrip(val);
-				if (!strncmp(wordStart, "<w ", 3)) {
-					strtok(wordStart, ">");
-					char *attStart = strstr(wordStart, "morph");
-					if (attStart) {
-						attStart += 7;
-						sprintf(buf, "x-%s:%s|", "StrongsMorph", val);
-					}
-					else {
-						attStart = wordStart + 3;
-						sprintf(buf, "morph=\"x-%s:%s\" ", "StrongsMorph", val);
-					}
-					wordStart[strlen(wordStart)] = '>';
-					memmove(attStart+strlen(buf), attStart, (to-attStart)+1);
-					memcpy(attStart, buf, strlen(buf));
-					to+=strlen(buf);
+			else if (*token == 'W' && token[1] == 'T') {
+				if (token[2] == 'G' || token[2] == 'H') {	// Strongs
+					value = token+2;
 				}
-				else {
-					sprintf(buf, "<w morph=\"x-%s:%s\">", "StrongsMorph", val);
-					memmove(wordStart+strlen(buf), wordStart, (to-wordStart)+1);
-					memcpy(wordStart, buf, strlen(buf));
-					to+=strlen(buf);
-					pushString(&to, "</w>");
+				else value = token+1;
+				
+				if (!strncmp(wordStart, "<w ", 3)) {
+					const char *attStart = strstr(wordStart, "morph");
+					if (attStart) { //existing morph attribute, append this one to it
+						attStart += 7;
+						buf = "";
+						buf.appendFormatted("%s:%s ", "robinson", value.c_str());
+					}
+					else { // no lemma attribute
+						attStart = wordStart + 3;
+						buf = "";
+						buf.appendFormatted("morph=\"%s:%s\" ", "robinson", value.c_str());
+					}
+					
+					text.insert(attStart - text.c_str(), buf); //hack, we have to
+				}
+				else { //no existing <w> attribute fond
+					buf = "";
+					buf.appendFormatted("<w morph=\"%s:%s\">", "robinson", value.c_str());
+					text.insert(wordStart - text.c_str(), buf);
+					text += "</w>";
 					lastspace = false;
+
 				}
 				handled = true;
 			}
 
 			if (!keepToken) {	
 				if (!handled) {
-					SWLog::systemlog->LogError("Unprocessed Token: <%s>", token);
+					SWLog::getSystemLog()->logError("Unprocessed Token: <%s> in key %s", token, key ? (const char*)*key : "<unknown>");
 //					exit(-1);
 				}
 				if (from[1] && strchr(" ,;.:?!()'\"", from[1])) {
-					if (lastspace)
-						to--;
+					if (lastspace) {
+						text--;
+					}
+				}
+				if (newText) {
+					textStart = from+1;
+					newText = false; 
 				}
-				if (newText) {textStart = from+1; newText = false; }
-//				if (newWord) {wordStart = to; newWord = false; }
 				continue;
 			}
+
 			// if not a strongs token, keep token in text
-			*to++ = '<';
-			for (char *tok = token; *tok; tok++)
-				*to++ = *tok;
-			*to++ = '>';
-			if (newText) {textStart = to; newWord = false; }
-//			if (newWord) {wordStart = to; newWord = false; }
+			text.appendFormatted("<%s>", token);
+			
+			if (newText) {
+				textStart = text.c_str() + text.length();
+				newWord = false; 
+			}
 			continue;
 		}
 		if (intoken) {
@@ -303,13 +313,21 @@ char GBFOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 			case '\"':
 			case '`':
 //				quoteStack.handleQuote(fromStart, from, &to);
-				*to++ = *from;
-				from++;
+				text += *from;
+				//from++; //this line removes chars after an apostrophe! Needs fixing.
 				break;
 			default:
-				if (newWord && (*from != ' ')) {wordStart = to; newWord = false; memset(to, 0, 10); }
+				if (newWord && (*from != ' ')) {
+					wordStart = text.c_str() + text.length();
+					newWord = false;
+					
+					//fix this if required?
+					//memset(to, 0, 10); 
+					
+				}
+				
 				if (!suspendTextPassThru) {
-					*to++ = *from;
+					text += (*from);
 					lastspace = (*from == ' ');
 				}
 			}
@@ -318,21 +336,23 @@ char GBFOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 
 	VerseKey *vkey = SWDYNAMIC_CAST(VerseKey, key);
 	if (vkey) {
-		char ref[254];
-		if (vkey->Verse())
-			sprintf(ref, "\t\t<verse osisID=\"%s\">", vkey->getOSISRef());
-		else *ref = 0;
-		if (*ref) {
-			memmove(text+strlen(ref), text, maxlen-strlen(ref)-1);
-			memcpy(text, ref, strlen(ref));
-			to+=strlen(ref);
+		SWBuf ref = "";
+		if (vkey->Verse()) {
+			ref.appendFormatted("\t\t<verse osisID=\"%s\">", vkey->getOSISRef());
+		}
+		
+		if (ref.length() > 0) {
+			
+			text = ref + text;
+			
 			if (vkey->Verse()) {
 				VerseKey tmp;
 				tmp = *vkey;
 				tmp.AutoNormalize(0);
 				tmp.Headings(1);
-				sprintf(ref, "</verse>");
-				pushString(&to, ref);
+				
+				text += "</verse>";
+				
 				tmp = MAXVERSE;
 				if (*vkey == tmp) {
 					tmp.Verse(0);
@@ -345,59 +365,25 @@ char GBFOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 						tmp.Verse(0);
 //						sprintf(ref, "\t</div>");
 //						pushString(&to, ref);
+/*
 						if (!quoteStack.empty()) {
-							SWLog::systemlog->LogError("popping unclosed quote at end of book");
+							SWLog::getSystemLog()->logError("popping unclosed quote at end of book");
 							quoteStack.clear();
 						}
+*/
 					}
 				}
 			}
-
-//
 //			else if (vkey->Chapter()) {
 //				sprintf(ref, "\t<div type=\"chapter\" osisID=\"%s\">", vkey->getOSISRef());
 //			}
 //			else sprintf(ref, "\t<div type=\"book\" osisID=\"%s\">", vkey->getOSISRef());
-//
 		}
 	}
-	*to++ = 0;
-	*to = 0;
-*/
 	return 0;
 }
 
 
-const char *GBFOSIS::convertToOSIS(const char *inRef, const SWKey *key) {
-	static SWBuf outRef;
-
-	outRef = "";
-
-	VerseKey defLanguage;
-	ListKey verses = defLanguage.ParseVerseList(inRef, (*key), true);
-	const char *startFrag = inRef;
-	for (int i = 0; i < verses.Count(); i++) {
-		VerseKey *element = SWDYNAMIC_CAST(VerseKey, verses.GetElement(i));
-		char buf[5120];
-		char frag[800];
-		if (element) {
-			memmove(frag, startFrag, ((const char *)element->userData - startFrag) + 1);
-			frag[((const char *)element->userData - startFrag) + 1] = 0;
-			startFrag = (const char *)element->userData + 1;
-			sprintf(buf, "<reference osisRef=\"%s-%s\">%s</reference>", element->LowerBound().getOSISRef(), element->UpperBound().getOSISRef(), frag);
-		}
-		else {
-			memmove(frag, startFrag, ((const char *)verses.GetElement(i)->userData - startFrag) + 1);
-			frag[((const char *)verses.GetElement(i)->userData - startFrag) + 1] = 0;
-			startFrag = (const char *)verses.GetElement(i)->userData + 1;
-			sprintf(buf, "<reference osisRef=\"%s\">%s</reference>", VerseKey(*verses.GetElement(i)).getOSISRef(), frag);
-		}
-		outRef+=buf;
-	}
-	return outRef.c_str();
-}
-
-
 QuoteStack::QuoteStack() {
 	clear();
 }
