@@ -8,10 +8,6 @@
 #include <stdlib.h>
 #include <gbfstrongs.h>
 #include <swmodule.h>
-#ifndef __GNUC__
-#else
-#include <unixstr.h>
-#endif
 #include <ctype.h>
 
 SWORD_NAMESPACE_START
@@ -19,7 +15,7 @@ SWORD_NAMESPACE_START
 const char oName[] = "Strong's Numbers";
 const char oTip[] = "Toggles Strong's Numbers On and Off if they exist";
 
-const SWBuf choices[3] = {"On", "Off", ""};
+const SWBuf choices[3] = {"Off", "On", ""};
 const StringList oValues(&choices[0], &choices[2]);
 
 GBFStrongs::GBFStrongs() : SWOptionFilter(oName, oTip, &oValues) {
@@ -62,17 +58,17 @@ char GBFStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 		}
 		if (*from == '>') {	// process tokens
 			intoken = false;
-
 			if (*token == 'W' && (token[1] == 'G' || token[1] == 'H')) {	// Strongs
 				if (module->isProcessEntryAttributes()) {
 					valto = val;
-					for (unsigned int i = 2; ((token[i]) && (i < 150)); i++)
+					for (unsigned int i = 1; ((token[i]) && (i < 150)); i++)
 						*valto++ = token[i];
 					*valto = 0;
 					if (atoi((!isdigit(*val))?val+1:val) < 5627) {
 						// normal strongs number
 						sprintf(wordstr, "%03d", word++);
-						module->getEntryAttributes()["Word"][wordstr]["Strongs"] = val;
+						module->getEntryAttributes()["Word"][wordstr]["Lemma"] = val;
+						module->getEntryAttributes()["Word"][wordstr]["LemmaClass"] = "strong";
 						tmp = "";
 						tmp.append(text.c_str()+textStart, (int)(textEnd - textStart));
 						module->getEntryAttributes()["Word"][wordstr]["Text"] = tmp;
@@ -82,8 +78,10 @@ char GBFStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 						// verb morph
 						sprintf(wordstr, "%03d", word-1);
 						module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
+						module->getEntryAttributes()["Word"][wordstr]["MorphClass"] = "OLBMorph";
 					}
 				}
+
 				if (!option) {
 					if ((from[1] == ' ') || (from[1] == ',') || (from[1] == ';') || (from[1] == '.') || (from[1] == '?') || (from[1] == '!') || (from[1] == ')') || (from[1] == '\'') || (from[1] == '\"')) {
 						if (lastspace)
@@ -93,6 +91,18 @@ char GBFStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 					continue;
 				}
 			}
+			if (module->isProcessEntryAttributes()) {
+				if ((*token == 'W') && (token[1] == 'T')) {	// Strongs
+					valto = val;
+					for (unsigned int i = 2; ((token[i]) && (i < 150)); i++)
+						*valto++ = token[i];
+					*valto = 0;
+					sprintf(wordstr, "%03d", word-1);
+					module->getEntryAttributes()["Word"][wordstr]["MorphClass"] = "GBFMorph";
+					module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
+					newText = true;
+				}
+			}
 			// if not a strongs token, keep token in text
 			text += '<';
 			text += token;
