@@ -17,7 +17,7 @@
 
 #include <gbfwebif.h>
 #include <ctype.h>
-#include <utilweb.h>
+#include <url.h>
 
 SWORD_NAMESPACE_START
 
@@ -39,7 +39,6 @@ bool GBFWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *u
 			// OSIS Word (temporary until OSISRTF is done)
 			valto = val;
 			num = strstr(token, "lemma=\"x-Strongs:");
-
 			if (num) {
 				for (num+=17; ((*num) && (*num != '\"')); num++)
 					*valto++ = *num;
@@ -55,7 +54,7 @@ bool GBFWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *u
 						if (isdigit(url[1]))
 							url = url.c_str()+1;
 					}
-					buf.appendFormatted("<a href=\"%s?showStrong=%s#cv\">", passageStudyURL.c_str(), encodeURL(url).c_str());
+					buf.appendFormatted("<a href=\"%s?showStrong=%s#cv\">", passageStudyURL.c_str(), URL::encode(url).c_str());
 
 					for (tok = (!isdigit(*val))?val+1:val; *tok; tok++) {
 						buf += *tok;
@@ -63,6 +62,32 @@ bool GBFWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *u
 					buf += "</a>&gt;</em></small> ";
 				}
 			}
+			else {
+				num = strstr(token, "lemma=\"strong:");
+				if (num) {
+					for (num+=14; ((*num) && (*num != '\"')); num++)
+						*valto++ = *num;
+					*valto = 0;
+
+					if (atoi((!isdigit(*val))?val+1:val) < 5627) {
+						buf += " <small><em>&lt;";
+						url = "";
+						for (tok = val; *tok; tok++) {
+							url += *tok;
+						}
+						if ((url.length() > 1) && strchr("GH", url[0])) {
+							if (isdigit(url[1]))
+								url = url.c_str()+1;
+						}
+						buf.appendFormatted("<a href=\"%s?showStrong=%s#cv\">", passageStudyURL.c_str(), URL::encode(url).c_str());
+
+						for (tok = (!isdigit(*val))?val+1:val; *tok; tok++) {
+							buf += *tok;
+						}
+						buf += "</a>&gt;</em></small> ";
+					}
+				}
+			}
 			valto = val;
 			num = strstr(token, "morph=\"x-Robinson:");
 			if (num) {
@@ -75,7 +100,7 @@ bool GBFWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *u
 				// normal robinsons tense
 					buf += *tok;
 				}
-				buf.appendFormatted("<a href=\"%s?showMorph=%s#cv\">", passageStudyURL.c_str(), encodeURL(url).c_str());
+				buf.appendFormatted("<a href=\"%s?showMorph=%s#cv\">", passageStudyURL.c_str(), URL::encode(url).c_str());
 
 				for (tok = val; *tok; tok++) {
 					buf += *tok;
@@ -95,7 +120,7 @@ bool GBFWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *u
 				if (isdigit(url[1]))
 					url = url.c_str()+1;
 			}
-			buf.appendFormatted("<a href=\"%s?showStrong=%s#cv\">", passageStudyURL.c_str(), encodeURL(url).c_str());
+			buf.appendFormatted("<a href=\"%s?showStrong=%s#cv\">", passageStudyURL.c_str(), URL::encode(url).c_str());
 
 			for (tok = token + 2; *tok; tok++) {
 				buf += *tok;
@@ -114,7 +139,7 @@ bool GBFWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *u
 				if (isdigit(url[1]))
 					url = url.c_str()+1;
 			}
-			buf.appendFormatted("<a href=\"%s?showStrong=%s#cv\">", passageStudyURL.c_str(), encodeURL(url).c_str());
+			buf.appendFormatted("<a href=\"%s?showStrong=%s#cv\">", passageStudyURL.c_str(), URL::encode(url).c_str());
 
 			for (tok = token + 3; *tok; tok++)
 				if(*tok != '\"')
@@ -128,7 +153,7 @@ bool GBFWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *u
 				if(*tok != '\"')
 					buf += *tok;
 			}
-			buf.appendFormatted("<a href=\"%s?showMorph=%s#cv\">", passageStudyURL.c_str(), encodeURL(url).c_str());
+			buf.appendFormatted("<a href=\"%s?showMorph=%s#cv\">", passageStudyURL.c_str(), URL::encode(url).c_str());
 
 			for (tok = token + 2; *tok; tok++) {
 				if(*tok != '\"')
@@ -148,7 +173,7 @@ bool GBFWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *u
 			  }
 			}
 
-			buf.appendFormatted("a href=\"%s?key=%s#cv\">", passageStudyURL.c_str(), encodeURL(url).c_str());
+			buf.appendFormatted("a href=\"%s?key=%s#cv\">", passageStudyURL.c_str(), URL::encode(url).c_str());
 		}
 
 		else {
