@@ -19,12 +19,20 @@
 #include <utilxml.h>
 #include <versekey.h>
 #include <swmodule.h>
+#include <url.h>
 
 SWORD_NAMESPACE_START
 
 
 OSISHTMLHREF::MyUserData::MyUserData(const SWModule *module, const SWKey *key) : BasicFilterUserData(module, key) {
-	osisQToTick = ((!module->getConfigEntry("OSISqToTick")) || (strcmp(module->getConfigEntry("OSISqToTick"), "false")));
+	if (module) {
+		osisQToTick = ((!module->getConfigEntry("OSISqToTick")) || (strcmp(module->getConfigEntry("OSISqToTick"), "false")));
+		version = module->Name();
+	}
+	else {
+		osisQToTick = true;	// default
+		version = "";
+	}
 }
 
 
@@ -37,15 +45,16 @@ OSISHTMLHREF::OSISHTMLHREF() {
 
 	setEscapeStringCaseSensitive(true);
 
-	addEscapeStringSubstitute("amp", "&");
+	addEscapeStringSubstitute("amp",  "&");
 	addEscapeStringSubstitute("apos", "'");
-	addEscapeStringSubstitute("lt", "<");
-	addEscapeStringSubstitute("gt", ">");
+	addEscapeStringSubstitute("lt",   "<");
+	addEscapeStringSubstitute("gt",   ">");
 	addEscapeStringSubstitute("quot", "\"");
-	addTokenSubstitute("lg", "<br />");
-	addTokenSubstitute("/lg", "<br />");
-
+	
 	setTokenCaseSensitive(true);
+	
+	addTokenSubstitute("lg",  "<br />");
+	addTokenSubstitute("/lg", "<br />");
 }
 
 
@@ -54,10 +63,10 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 	if (!substituteToken(buf, token)) {
 		MyUserData *u = (MyUserData *)userData;
 		XMLTag tag(token);
-
+		
 		// <w> tag
 		if (!strcmp(tag.getName(), "w")) {
-
+ 
 			// start <w> tag
 			if ((!tag.isEmpty()) && (!tag.isEndTag())) {
 				u->w = token;
@@ -80,12 +89,14 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 				if (attrib = tag.getAttribute("xlit")) {
 					val = strchr(attrib, ':');
 					val = (val) ? (val + 1) : attrib;
-					buf.appendFormatted(" %s", val);
+					if (!u->suspendTextPassThru)
+						buf.appendFormatted(" %s", val);
 				}
 				if (attrib = tag.getAttribute("gloss")) {
 					val = strchr(attrib, ':');
 					val = (val) ? (val + 1) : attrib;
-					buf.appendFormatted(" %s", val);
+					if (!u->suspendTextPassThru)
+						buf.appendFormatted(" %s", val);
 				}
 				if (attrib = tag.getAttribute("lemma")) {
 					int count = tag.getAttributePartCount("lemma");
@@ -95,12 +106,24 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 						if (i < 0) i = 0;	// to handle our -1 condition
 						val = strchr(attrib, ':');
 						val = (val) ? (val + 1) : attrib;
+						SWBuf gh;
+						if(*val == 'G')
+							gh = "Greek";
+						if(*val == 'H')
+							gh = "Hebrew";
 						const char *val2 = val;
 						if ((strchr("GH", *val)) && (isdigit(val[1])))
 							val2++;
 						if ((!strcmp(val2, "3588")) && (lastText.length() < 1))
 							show = false;
-						else	buf.appendFormatted(" <small><em>&lt;<a href=\"type=Strongs value=%s\">%s</a>&gt;</em></small> ", val, val2);
+						else {
+							if (!u->suspendTextPassThru)
+								buf.appendFormatted(" <small><em>&lt;<a href=\"passagestudy.jsp?action=showStrongs&type=%s&value=%s\">%s</a>&gt;</em></small> ", 
+										(gh.length()) ? gh.c_str() : "", 
+										URL::encode(val2).c_str(), 
+										val2);
+						}
+						
 					} while (++i < count);
 				}
 				if ((attrib = tag.getAttribute("morph")) && (show)) {
@@ -118,14 +141,19 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 							const char *val2 = val;
 							if ((*val == 'T') && (strchr("GH", val[1])) && (isdigit(val[2])))
 								val2+=2;
-							buf.appendFormatted(" <small><em>(<a href=\"type=morph class=%s value=%s\">%s</a>)</em></small> ", tag.getAttribute("morph"), val, val2);
+							if (!u->suspendTextPassThru)
+								buf.appendFormatted(" <small><em>(<a href=\"passagestudy.jsp?action=showMorph&type=%s&value=%s\">%s</a>)</em></small> ", 
+										URL::encode(tag.getAttribute("morph")).c_str(),
+										URL::encode(val).c_str(), 
+										val2);
 						} while (++i < count);
 					}
 				}
 				if (attrib = tag.getAttribute("POS")) {
 					val = strchr(attrib, ':');
 					val = (val) ? (val + 1) : attrib;
-					buf.appendFormatted(" %s", val);
+					if (!u->suspendTextPassThru)
+						buf.appendFormatted(" %s", val);
 				}
 
 				/*if (endTag)
@@ -143,17 +171,23 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 						SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 						VerseKey *vkey;
 						// see if we have a VerseKey * or descendant
-						try {
+						SWTRY {
 							vkey = SWDYNAMIC_CAST(VerseKey, u->key);
 						}
-						catch ( ... ) {	}
+						SWCATCH ( ... ) {	}
 						if (vkey) {
+							//printf("URL = %s\n",URL::encode(vkey->getText()).c_str());
 							char ch = ((tag.getAttribute("type") && ((!strcmp(tag.getAttribute("type"), "crossReference")) || (!strcmp(tag.getAttribute("type"), "x-cross-ref")))) ? 'x':'n');
-							buf.appendFormatted("<a href=\"noteID=%s.%c.%s\"><small><sup>*%c</sup></small></a> ", vkey->getText(), ch, footnoteNumber.c_str(), ch);
+							buf.appendFormatted("<a href=\"passagestudy.jsp?action=showNote&type=%c&value=%s&module=%s&passage=%s\"><small><sup>*%c</sup></small></a> ", 
+								ch, 
+								URL::encode(footnoteNumber.c_str()).c_str(), 
+								URL::encode(u->version.c_str()).c_str(), 
+								URL::encode(vkey->getText()).c_str(), 
+								ch);
 						}
 					}
-					u->suspendTextPassThru = true;
 				}
+				u->suspendTextPassThru = true;
 			}
 			if (tag.isEndTag()) {
 				u->suspendTextPassThru = false;
@@ -163,80 +197,104 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 		// <p> paragraph tag
 		else if (!strcmp(tag.getName(), "p")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {	// non-empty start tag
-				buf += "<!P><br />";
+				if (!u->suspendTextPassThru)
+					buf += "<!P><br />";
 			}
 			else if (tag.isEndTag()) {	// end tag
-				buf += "<!/P><br />";
+				if (!u->suspendTextPassThru)
+					buf += "<!/P><br />";
 				userData->supressAdjacentWhitespace = true;
 			}
 			else {					// empty paragraph break marker
-				buf += "<!P><br />";
+				if (!u->suspendTextPassThru)
+					buf += "<!P><br />";
 				userData->supressAdjacentWhitespace = true;
 			}
 		}
 
 		// <reference> tag
-		else if (!strcmp(tag.getName(), "reference")) {
+		else if (!strcmp(tag.getName(), "reference")) {			
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				buf += "<a href=\"\">";
+				if (!u->suspendTextPassThru)
+					buf += "<a href=\"\">";
 			}
 			else if (tag.isEndTag()) {
-				buf += "</a>";
+				if (!u->suspendTextPassThru)
+					buf += "</a>";
 			}
 		}
 
 		// <l> poetry, etc
 		else if (!strcmp(tag.getName(), "l")) {
 			if (tag.isEmpty()) {
-				buf += "<br />";
+				if (!u->suspendTextPassThru)
+					buf += "<br />";
 			}
 			else if (tag.isEndTag()) {
-				buf += "<br />";
+				if (!u->suspendTextPassThru)
+					buf += "<br />";
 			}
 			else if (tag.getAttribute("sID")) {	// empty line marker
-				buf += "<br />";
+				if (!u->suspendTextPassThru)
+					buf += "<br />";
 			}
 		}
 
 		// <milestone type="line"/>
 		else if ((!strcmp(tag.getName(), "milestone")) && (tag.getAttribute("type")) && (!strcmp(tag.getAttribute("type"), "line"))) {
-			buf += "<br />";
+			if (!u->suspendTextPassThru)
+				buf += "<br />";
 			userData->supressAdjacentWhitespace = true;
 		}
 
 		// <title>
 		else if (!strcmp(tag.getName(), "title")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				buf += "<b>";
+				if (!u->suspendTextPassThru)
+					buf += "<b>";
 			}
 			else if (tag.isEndTag()) {
-				buf += "</b><br />";
+				if (!u->suspendTextPassThru)
+					buf += "</b><br />";
 			}
 		}
 
-		// <hi> hi?  hi contrast?
+		// <catchWord> & <rdg> tags (italicize)
+		else if (!strcmp(tag.getName(), "rdg") || !strcmp(tag.getName(), "catchWord")) {
+			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
+				if (!u->suspendTextPassThru)
+					buf += "<i>";
+			}
+			else if (tag.isEndTag()) {
+				if (!u->suspendTextPassThru)
+					buf += "</i>";
+			}
+		}
+
+		// <hi> text highlighting
 		else if (!strcmp(tag.getName(), "hi")) {
 			SWBuf type = tag.getAttribute("type");
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
 				if (type == "b" || type == "x-b") {
-					buf += "<b> ";
+					if (!u->suspendTextPassThru)
+						buf += "<b>";
 					u->inBold = true;
 				}
 				else {	// all other types
-					buf += "<i> ";
+					if (!u->suspendTextPassThru)
+						buf += "<i>";
 					u->inBold = false;
 				}
 			}
 			else if (tag.isEndTag()) {
 				if(u->inBold) {
-					buf += "</b>";
+					if (!u->suspendTextPassThru)
+						buf += "</b>";
 					u->inBold = false;
 				}
 				else
-				      buf += "</i>";
-			}
-			else {	// empty hi marker
-				// what to do?  is this even valid?
+					if (!u->suspendTextPassThru)
+						 buf += "</i>";
 			}
 		}
 
@@ -246,43 +304,49 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 			SWBuf who = tag.getAttribute("who");
 			const char *lev = tag.getAttribute("level");
 			int level = (lev) ? atoi(lev) : 1;
-			
+
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
 				/*buf += "{";*/
 
 				//alternate " and '
 				if (u->osisQToTick)
-					buf += (level % 2) ? '\"' : '\'';
+					if (!u->suspendTextPassThru)
+						buf += (level % 2) ? '\"' : '\'';
 				
 				if (who == "Jesus") {
-					buf += "<font color=\"red\"> ";
+					if (!u->suspendTextPassThru)
+						buf += "<font color=\"red\">";
 				}
 			}
 			else if (tag.isEndTag()) {
 				//alternate " and '
 				if (u->osisQToTick)
-					buf += (level % 2) ? '\"' : '\'';
+					if (!u->suspendTextPassThru)
+						buf += (level % 2) ? '\"' : '\'';
 				//buf += "</font>";
 			}
 			else {	// empty quote marker
 				//alternate " and '
 				if (u->osisQToTick)
-					buf += (level % 2) ? '\"' : '\'';
+					if (!u->suspendTextPassThru)
+						buf += (level % 2) ? '\"' : '\'';
 			}
 		}
 
 		// <transChange>
 		else if (!strcmp(tag.getName(), "transChange")) {
 			SWBuf type = tag.getAttribute("type");
-			
+
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
 
 // just do all transChange tags this way for now
 //				if (type == "supplied")
-					buf += "<i>";
+					if (!u->suspendTextPassThru)
+						buf += "<i>";
 			}
 			else if (tag.isEndTag()) {
-				buf += "</i>";
+				if (!u->suspendTextPassThru)
+					buf += "</i>";
 			}
 			else {	// empty transChange marker?
 			}
@@ -294,40 +358,22 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 			if (!src)		// assert we have a src attribute
 				return false;
 
-			char* filepath = new char[strlen(u->module->getConfigEntry("AbsoluteDataPath")) + strlen(token)];
-			*filepath = 0;
-			strcpy(filepath, userData->module->getConfigEntry("AbsoluteDataPath"));
-			strcat(filepath, src);
+			SWBuf filepath;
+			if (userData->module) {
+				filepath = userData->module->getConfigEntry("AbsoluteDataPath");
+				if ((filepath.size()) && (filepath[filepath.size()-1] != '/') && (src[0] != '/'))
+					filepath += '/';
+			}
+			filepath += src;
 
 // we do this because BibleCS looks for this EXACT format for an image tag
-			buf+="<image src=\"";
-			buf+=filepath;
-			buf+="\" />";
-/*
-			char imgc;
-			for (c = filepath + strlen(filepath); c > filepath && *c != '.'; c--);
-			c++;
-			FILE* imgfile;
-				    if (stricmp(c, "jpg") || stricmp(c, "jpeg")) {
-						  imgfile = fopen(filepath, "r");
-						  if (imgfile != NULL) {
-								buf += "{\\nonshppict {\\pict\\jpegblip ";
-								while (feof(imgfile) != EOF) {
-									   buf.appendFormatted("%2x", fgetc(imgfile));
-								}
-								fclose(imgfile);
-								buf += "}}";
-						  }
-				    }
-				    else if (stricmp(c, "png")) {
-						  buf += "{\\*\\shppict {\\pict\\pngblip ";
-
-						  buf += "}}";
-				    }
-*/
-			delete [] filepath;
+				if (!u->suspendTextPassThru) {
+					buf+="<image src=\"";
+					buf+=filepath;
+					buf+="\" />";
+				}
 		}
-		
+
 		else {
 		      return false;  // we still didn't handle token
 		}
