@@ -36,14 +36,12 @@ OSISPlain::OSISPlain() {
 	addEscapeStringSubstitute("gt", ">");
 	addEscapeStringSubstitute("quot", "\"");
 
-
+        setTokenCaseSensitive(true);
         addTokenSubstitute("title", "\n");
         addTokenSubstitute("/title", "\n");
         addTokenSubstitute("/l", "\n");
         addTokenSubstitute("lg", "\n");
         addTokenSubstitute("/lg", "\n");
-
-        setTokenCaseSensitive(true);
 }
 
 
@@ -51,9 +49,10 @@ bool OSISPlain::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
         // manually process if it wasn't a simple substitution
 	if (!substituteToken(buf, token)) {
 		MyUserData *u = (MyUserData *)userData;
-                XMLTag tag(token);
 		if (((*token == 'w') && (token[1] == ' ')) ||
-		((*token == '/') && (token[1] == 'w') && (!token[2]))) {
+		    ((*token == '/') && (token[1] == 'w') && (!token[2]))) {
+	                u->tag = token;
+			
 			bool start = false;
 			if (*token == 'w') {
 				if (token[strlen(token)-1] != '/') {
@@ -62,28 +61,32 @@ bool OSISPlain::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 				}
 				start = true;
 			}
-			tag = (start) ? token : u->w.c_str();
+			u->tag = (start) ? token : u->w.c_str();
 			bool show = true;	// to handle unplaced article in kjv2003-- temporary till combined
 
 			SWBuf lastText = (start) ? "stuff" : u->lastTextNode.c_str();
 
 			const char *attrib;
 			const char *val;
-			if (attrib = tag.getAttribute("xlit")) {
+			if ((attrib = u->tag.getAttribute("xlit"))) {
 				val = strchr(attrib, ':');
 				val = (val) ? (val + 1) : attrib;
-				buf.appendFormatted(" <%s>", val);
+				buf.append(" <");
+				buf.append(val);
+				buf.append('>');
 			}
-			if (attrib = tag.getAttribute("gloss")) {
+			if ((attrib = u->tag.getAttribute("gloss"))) {
 				val = strchr(attrib, ':');
 				val = (val) ? (val + 1) : attrib;
-				buf.appendFormatted(" <%s>", val);
+				buf.append(" <");
+				buf.append(val);
+				buf.append('>');
 			}
-			if (attrib = tag.getAttribute("lemma")) {
-				int count = tag.getAttributePartCount("lemma");
+			if ((attrib = u->tag.getAttribute("lemma"))) {
+				int count = u->tag.getAttributePartCount("lemma");
 				int i = (count > 1) ? 0 : -1;		// -1 for whole value cuz it's faster, but does the same thing as 0
 				do {
-					attrib = tag.getAttribute("lemma", i);
+					attrib = u->tag.getAttribute("lemma", i);
 					if (i < 0) i = 0;	// to handle our -1 condition
 					val = strchr(attrib, ':');
 					val = (val) ? (val + 1) : attrib;
@@ -91,39 +94,48 @@ bool OSISPlain::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 						val++;
 					if ((!strcmp(val, "3588")) && (lastText.length() < 1))
 						show = false;
-					else	buf.appendFormatted(" <%s>}", val);
+					else	{
+						buf.append(" {<");
+						buf.append(val);
+						buf.append(">}");
+					}
 				} while (++i < count);
 			}
-			if ((attrib = tag.getAttribute("morph")) && (show)) {
-				int count = tag.getAttributePartCount("morph");
+			if ((attrib = u->tag.getAttribute("morph")) && (show)) {
+				int count = u->tag.getAttributePartCount("morph");
 				int i = (count > 1) ? 0 : -1;		// -1 for whole value cuz it's faster, but does the same thing as 0
 				do {
-					attrib = tag.getAttribute("morph", i);
+					attrib = u->tag.getAttribute("morph", i);
 					if (i < 0) i = 0;	// to handle our -1 condition
 					val = strchr(attrib, ':');
 					val = (val) ? (val + 1) : attrib;
 					if ((*val == 'T') && (strchr("GH", val[1])) && (isdigit(val[2])))
 						val+=2;
-					buf.appendFormatted(" (%s)", val);
+					buf.append(" (");
+					buf.append(val);
+					buf.append(')');
 				} while (++i < count);
 			}
-			if (attrib = tag.getAttribute("POS")) {
+			if ((attrib = u->tag.getAttribute("POS"))) {
 				val = strchr(attrib, ':');
 				val = (val) ? (val + 1) : attrib;
-				buf.appendFormatted(" <%s>", val);
+				
+				buf.append(" <");
+				buf.append(val);
+				buf.append('>');
 			}
 		}
 
 		// <note> tag
 		else if (!strncmp(token, "note", 4)) {
 				if (!strstr(token, "strongsMarkup")) {	// leave strong's markup notes out, in the future we'll probably have different option filters to turn different note types on or off
-					buf += " (";
+					buf.append(" (");
 				}
 				else	u->suspendTextPassThru = true;
 			}
 		else if (!strncmp(token, "/note", 5)) {
 			if (!u->suspendTextPassThru)
-				buf += ")";
+				buf.append(')');
 			else	u->suspendTextPassThru = false;
 		}
 
@@ -131,13 +143,16 @@ bool OSISPlain::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 		else if (((*token == 'p') && ((token[1] == ' ') || (!token[1]))) ||
 			((*token == '/') && (token[1] == 'p') && (!token[2]))) {
 				userData->supressAdjacentWhitespace = true;
-				buf += "\n";
+				buf.append('\n');
 		}
 
                 // <milestone type="line"/>
-                else if ((!strcmp(tag.getName(), "milestone")) && (tag.getAttribute("type")) && (!strcmp(tag.getAttribute("type"), "line"))) {
-			userData->supressAdjacentWhitespace = true;
-        		buf += "\n";
+                else if (!strncmp(token, "milestone", 9)) {
+			const char* type = strstr(token+10, "type=\"");
+			if (type && strncmp(type+6, "line", 4)) { //we check for type != line
+				userData->supressAdjacentWhitespace = true;
+        			buf.append('\n');
+			}
                 }
 
 		else {
