@@ -148,10 +148,10 @@ bool OSISRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 						SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 						VerseKey *vkey;
 						// see if we have a VerseKey * or descendant
-						try {
+						SWTRY {
 							vkey = SWDYNAMIC_CAST(VerseKey, u->key);
 						}
-						catch ( ... ) {	}
+						SWCATCH ( ... ) {	}
 						if (vkey) {
 							char ch = ((!strcmp(type.c_str(), "crossReference")) || (!strcmp(type.c_str(), "x-cross-ref"))) ? 'x':'n';
 							buf.appendFormatted("{\\super <a href=\"\">*%c%i.%s</a>} ", ch, vkey->Verse(), footnoteNumber.c_str());
@@ -170,10 +170,10 @@ bool OSISRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 		// <p> paragraph tag
 		else if (!strcmp(tag.getName(), "p")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {	// non-empty start tag
-				buf += "{\\par ";
+				buf += "{\\par}";
 			}
 			else if (tag.isEndTag()) {	// end tag
-				buf += "\\par}";
+				buf += "{\\par}";
 				userData->supressAdjacentWhitespace = true;
 			}
 			else {					// empty paragraph break marker
@@ -197,10 +197,10 @@ bool OSISRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 		// <l> poetry
 		else if (!strcmp(tag.getName(), "l")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				buf += "{";
+				buf += "";
 			}
 			else if (tag.isEndTag()) {
-				buf += "\\par}";
+				buf += "{\\par}";
 			}
 			else if (tag.getAttribute("sID")) {	// empty line marker
 				buf += "{\\par}";
@@ -223,6 +223,16 @@ bool OSISRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 			}
 		}
 
+		// <catchWord> & <rdg> tags (italicize)
+		else if (!strcmp(tag.getName(), "rdg") || !strcmp(tag.getName(), "catchWord")) {
+			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
+				buf += "{\\i1 ";
+			}
+			else if (tag.isEndTag()) {
+				buf += "}";
+			}
+		}
+
 		// <hi>
 		else if (!strcmp(tag.getName(), "hi")) {
 			SWBuf type = tag.getAttribute("type");
