@@ -18,6 +18,7 @@
 #include <stdlib.h>
 #include <osiswebif.h>
 #include <utilxml.h>
+#include <url.h>
 #include <versekey.h>
 #include <swmodule.h>
 #include <ctype.h>
@@ -26,7 +27,7 @@
 SWORD_NAMESPACE_START
 
 
-OSISWEBIF::OSISWEBIF() : baseURL(""), passageStudyURL(baseURL + "passagestudy.jsp") {
+OSISWEBIF::OSISWEBIF() : baseURL(""), passageStudyURL(baseURL + "passagestudy.jsp"), javascript(false) {
 }
 
 bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData) {
@@ -80,7 +81,7 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 							val2++;
 						if ((!strcmp(val2, "3588")) && (lastText.length() < 1))
 							show = false;
-						else	buf.appendFormatted(" <small><em>&lt;<a href=\"%s?showStrong=%s#cv\">%s</a>&gt;</em></small> ", passageStudyURL.c_str(), encodeURL(val2).c_str(), val2);
+						else	buf.appendFormatted(" <small><em>&lt;<a href=\"%s?showStrong=%s#cv\">%s</a>&gt;</em></small> ", passageStudyURL.c_str(), URL::encode(val2).c_str(), val2);
 					} while (++i < count);
 				}
 				if ((attrib = tag.getAttribute("morph")) && (show)) {
@@ -98,7 +99,7 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 							const char *val2 = val;
 							if ((*val == 'T') && (strchr("GH", val[1])) && (isdigit(val[2])))
 								val2+=2;
-							buf.appendFormatted(" <small><em>(<a href=\"%s?showMorph=%s#cv\">%s</a>)</em></small> ", passageStudyURL.c_str(), encodeURL(val2).c_str(), val2);
+							buf.appendFormatted(" <small><em>(<a href=\"%s?showMorph=%s#cv\">%s</a>)</em></small> ", passageStudyURL.c_str(), URL::encode(val2).c_str(), val2);
 						} while (++i < count);
 					}
 				}
@@ -123,10 +124,10 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 						SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 						VerseKey *vkey;
 						// see if we have a VerseKey * or descendant
-						try {
+						SWTRY {
 							vkey = SWDYNAMIC_CAST(VerseKey, u->key);
 						}
-						catch ( ... ) {	}
+						SWCATCH ( ... ) {	}
 						if (vkey) {
 							char ch = ((tag.getAttribute("type") && ((!strcmp(tag.getAttribute("type"), "crossReference")) || (!strcmp(tag.getAttribute("type"), "x-cross-ref")))) ? 'x':'n');
 //							buf.appendFormatted("<a href=\"noteID=%s.%c.%s\"><small><sup>*%c</sup></small></a> ", vkey->getText(), ch, footnoteNumber.c_str(), ch);
@@ -139,6 +140,7 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 				u->suspendTextPassThru = false;
 			}
 		}
+
 		// <title>
 		else if (!strcmp(tag.getName(), "title")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
@@ -149,6 +151,44 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 			}
 		}
 
+		// <catchWord> & <rdg> tags (italicize)
+		else if (!strcmp(tag.getName(), "rdg") || !strcmp(tag.getName(), "catchWord")) {
+			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
+				if (!u->suspendTextPassThru)
+					buf += "<i>";
+			}
+			else if (tag.isEndTag()) {
+				if (!u->suspendTextPassThru)
+					buf += "</i>";
+			}
+		}
+
+                // <hi> text highlighting
+		else if (!strcmp(tag.getName(), "hi")) {
+			SWBuf type = tag.getAttribute("type");
+			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
+				if (type == "b" || type == "x-b") {
+					if (!u->suspendTextPassThru)
+						buf += "<b>";
+					u->inBold = true;
+				}
+				else {	// all other types
+					if (!u->suspendTextPassThru)
+						buf += "<i>";
+				}
+			}
+			else if (tag.isEndTag()) {
+				if(u->inBold) {
+					if (!u->suspendTextPassThru)
+						buf += "</b>";
+					u->inBold = false;
+				}
+				else
+					if (!u->suspendTextPassThru)
+						 buf += "</i>";
+			}
+		}
+
 		// <q> quote
 		else if (!strcmp(tag.getName(), "q")) {
 			SWBuf type = tag.getAttribute("type");
@@ -186,7 +226,7 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 				SWBuf type = tag.getAttribute("type");
 				u->lastTransChange = type;
 
-// just do all transChange tags this way for now
+				// just do all transChange tags this way for now
 				if ((type == "added") || (type == "supplied"))
 					buf += "<i>";
 				else if (type == "tenseChange")
@@ -200,6 +240,16 @@ bool OSISWEBIF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 			else {	// empty transChange marker?
 			}
 		}
+		// ok to leave these in
+		else if (!strcmp(tag.getName(), "div")) {
+			buf += tag;
+		}
+		else if (!strcmp(tag.getName(), "span")) {
+			buf += tag;
+		}
+		else if (!strcmp(tag.getName(), "br")) {
+			buf += tag;
+		}
 		else {
 			return OSISHTMLHREF::handleToken(buf, token, userData);
 		}
