@@ -11,17 +11,13 @@
 #include <swbuf.h>
 #include <versekey.h>
 #include <utilxml.h>
-#ifndef __GNUC__
-#else
-#include <unixstr.h>
-#endif
 
 SWORD_NAMESPACE_START
 
 const char oName[] = "Footnotes";
 const char oTip[] = "Toggles Footnotes On and Off if they exist";
 
-const SWBuf choices[3] = {"On", "Off", ""};
+const SWBuf choices[3] = {"Off", "On", ""};
 const StringList oValues(&choices[0], &choices[2]);
 
 ThMLFootnotes::ThMLFootnotes() : SWOptionFilter(oName, oTip, &oValues) {
