@@ -13,10 +13,9 @@
 #include <swlog.h>
 #include <versekey.h>
 #include <stdarg.h>
-#ifndef __GNUC__
-#else
-#include <unixstr.h>
-#endif
+#include <utilstr.h>
+#include <utilxml.h>
+
 
 SWORD_NAMESPACE_START
 
@@ -29,48 +28,65 @@ ThMLOSIS::~ThMLOSIS() {
 
 
 char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module) {
-	/*
-
-	const char *from;
 	char token[2048]; // cheese.  Fix.
 	int tokpos = 0;
 	bool intoken = false;
-	int len;
+	bool keepToken = false;
+
+//	static QuoteStack quoteStack;
+	
 	bool lastspace = false;
 	int word = 1;
 	char val[128];
-	char buf[128];
-	char wordstr[5];
+	SWBuf buf;
 	char *valto;
 	char *ch;
-	char *textStart, *textEnd;
-	char *wordStart, *wordEnd;
+	
+	const char *wordStart = text.c_str();
+	const char *wordEnd;
+	
+	const char *textStart;
+	const char *textEnd;
+		
+	bool suspendTextPassThru = false;
+	bool handled = false;
 	bool newText = false;
 	bool newWord = false;
-	SWBuf tmp;
-	bool suspendTextPassThru = false;
-	bool keepToken = false;
-	bool handled = false;
+	
+// 	SWBuf tmp;
 	SWBuf divEnd = "";
 
-
-	wordStart = text;
-
 	SWBuf orig = text;
-	from = orig.c_str();
+	const char* from = orig.c_str();
 
-	for (text = ""; *from; from++) {
+	text = "";
+	for (from = orig.c_str(); *from; ++from) {
 
-		if (*from == '<') {
+		// handle silly <variant word> items in greek whnu, remove when module is fixed
+		if ((*from == '<') && (*(from+1) < 0)) {
+			text += "&lt;";
+			continue;
+		}
+
+		if (*from == '<') { //start of new token detected
 			intoken = true;
 			tokpos = 0;
 			token[0] = 0;
 			token[1] = 0;
 			token[2] = 0;
 			textEnd = from-1;
-			wordEnd = to;
+			wordEnd = text.c_str() + text.length();//not good, instead of wordEnd = to!
+
+// 			wordEnd = to;
 			continue;
 		}
+		
+		// handle silly <variant word> items in greek whnu, remove when module is fixed
+		if ((*from == '>') && (*(from-1) < 0)) {
+			text += "&gt;";
+			continue;
+		}
+
 		if (*from == '>') {	// process tokens
 			intoken = false;
 			keepToken = false;
@@ -78,9 +94,8 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 			newWord = true;
 			handled = false;
 
-			while (wordStart < (text+maxlen)) {
-//				if (strchr(" ,;.?!()'\"", *wordStart))
-				if (strchr(";,: .?!()'\"", *wordStart))
+			while (wordStart < (text.c_str() + text.length())) { //hack
+				if (strchr(";,. :?!()'\"", *wordStart) && wordStart[0] && wordStart[1])
 					wordStart++;
 				else break;
 			}
@@ -90,16 +105,33 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 				else break;
 			}
 
+			// variants
+			if (!strncmp(token, "div type=\"variant\"", 18)) {
+				XMLTag tag = token;
+				text.append("<seg type=\"x-variant\"");
+				SWBuf cls = "x-class:";
+				cls += tag.getAttribute("class");
+				if (cls.length()>8)
+					text.appendFormatted(" subType=\"%s\"", cls.c_str());
+
+				text += ">";
+				divEnd = "</seg>";
+				newText = true;
+				lastspace = false;
+				handled = true;
+			}
 			// section titles
 			if (!strcmp(token, "div class=\"sechead\"")) {
-				pushString(&to, "<title>");
+// 				pushString(&to, "<title>");
+				text.append("<title>");
 				divEnd = "</title>";
 				newText = true;
 				lastspace = false;
 				handled = true;
 			}
 			else	if (!strcmp(token, "/div")) {
-				pushString(&to, divEnd.c_str());
+				//pushString(&to, divEnd.c_str());
+				text.append(divEnd);
 				lastspace = false;
 				handled = true;
 			}
@@ -111,9 +143,11 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 				handled = true;
 			}
 			else	if (!strncmp(token, "/scripRef", 9)) {
+				SWBuf tmp;
 				tmp = "";
 				tmp.append(textStart, (int)(textEnd - textStart)+1);
-				pushString(&to, convertToOSIS(tmp.c_str(), key));
+				//pushString(&to, convertToOSIS(tmp.c_str(), key));
+				text.append(VerseKey::convertToOSIS(tmp.c_str(), key));
 				suspendTextPassThru = false;
 				handled = true;
 			}
@@ -138,40 +172,46 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 //                        	// otherwise, italics are just italics
 //-- end italics for transchange
 	        		if (!stricmp(token, "i")) {
-		        		pushString(&to, "<hi type=\"i\">");
+// 		        		pushString(&to, "<hi type=\"i\">");
+					text.append("<hi type=\"i\">");
 			        	newText = true;
-				        lastspace = false;
+				     lastspace = false;
         				handled = true;
 	        		}
 		        	else	if (!stricmp(token, "/i")) {
-			        	pushString(&to, "</hi>");
+// 			        	pushString(&to, "</hi>");
+					text.append("</hi>");
         				lastspace = false;
 	        			handled = true;
 		        	}
 //                        }
 
 	        	if (!strcmp(token, "b")) {
-		        	pushString(&to, "<hi type=\"b\">");
-			       	newText = true;
-			        lastspace = false;
+// 		        	pushString(&to, "<hi type=\"b\">");
+				text.append("<hi type=\"b\">");
+				newText = true;
+				lastspace = false;
         			handled = true;
 	        	}
-		        else	if (!strcmp(token, "/b")) {
-			       	pushString(&to, "</hi>");
+			else if (!strcmp(token, "/b")) {
+// 			     pushString(&to, "</hi>");
+				text.append("</hi>");
         			lastspace = false;
 	        		handled = true;
-                        }
+			}
 
 			// Footnote
 			if (!strcmp(token, "note")) {
-		        	pushString(&to, "<note>");
+		        	//pushString(&to, "<note>");
+				text.append("<note>");
 				newText = true;
-                                lastspace = false;
+				lastspace = false;
 				handled = true;
 			}
 			else	if (!strcmp(token, "/note")) {
-				pushString(&to, "</note>");
-                                lastspace = false;
+				// pushString(&to, "</note>");
+				text.append("</note>");
+				lastspace = false;
 				handled = true;
 			}
 
@@ -182,9 +222,17 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 					continue;
 //					return false;
 
-				pushString(&to, "<figure src=\"");
-				const char *c;
-				for (c = src;((*c) && (*c != '"')); c++);
+				//pushString(&to, "<figure src=\"");
+				text.append("<figure src=\"");
+
+				const char* end = strchr(src+2, '"'); //start search behind src="
+				
+				if (end) { //append the path
+					text.append(src+2, end - (src+2));
+				}
+								
+// 				const char *c;
+// 				for (c = src;((*c) && (*c != '"')); c++);
 
 // uncomment for SWORD absolute path logic
 //				if (*(c+1) == '/') {
@@ -195,102 +243,125 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 //				}
 //				end of uncomment for asolute path logic 
 
-				for (c++;((*c) && (*c != '"')); c++)
-					*to++ = *c;
+// 				for (c++;((*c) && (*c != '"')); c++)
+// 					*to++ = *c;
 
-				pushString(&to, "\" />");
+				//pushString(&to, "\" />");
+				text.append("\" />");
 				handled = true;
 			}
 
 			// Strongs numbers
 			else	if (!strnicmp(token, "sync type=\"Strongs\" ", 20)) {	// Strongs
-				if (module->isProcessEntryAttributes()) {
-					valto = val;
-					for (unsigned int i = 27; token[i] != '\"' && i < 150; i++)
-						*valto++ = token[i];
-					*valto = 0;
-					if (atoi((!isdigit(*val))?val+1:val) < 5627) {
-						// normal strongs number
-						strstrip(val);
-						sprintf(buf, "<w lemma=\"x-Strong:%s\">", val);
-						memmove(wordStart+strlen(buf), wordStart, (to-wordStart)+1);
-						memcpy(wordStart, buf, strlen(buf));
-						to+=strlen(buf);
-						pushString(&to, "</w>");
-						module->getEntryAttributes()["Word"][wordstr]["Strongs"] = val;
-//						tmp = "";
-//						tmp.append(textStart, (int)(wordEnd - wordStart));
-//						module->getEntryAttributes()["Word"][wordstr]["Text"] = tmp;
+				valto = val;
+				for (unsigned int i = 27; token[i] != '\"' && i < 150; i++)
+					*valto++ = token[i];
+				*valto = 0;
+				if (atoi((!isdigit(*val))?val+1:val) < 5627) {
+					// normal strongs number
+					strstrip(val);
+
+					if (!strncmp(wordStart, "<w ", 3)) {
+						const char *attStart = strstr(wordStart, "lemma");
+						if (attStart) { //existing morph attribute, append this one to it
+							attStart += 7;
+							buf = "";
+							buf.appendFormatted("strong:%s ", val);
+						}
+						else { // no lemma attribute
+							attStart = wordStart + 3;
+							buf = "";
+							buf.appendFormatted(buf, "lemma=\"strong:%s\" ", val);
+						}
+
+						text.insert(attStart - text.c_str(), buf);
 					}
-					else {
-						// verb morph
-						sprintf(wordstr, "%03d", word-1);
-						module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
+					else { //wordStart doesn't point to an existing <w> attribute!
+						buf = "";
+						buf.appendFormatted("<w lemma=\"strong:%s\">", val);
+						text.insert(wordStart - text.c_str(), buf);
+						text += "</w>";
+						lastspace = false;
 					}
 				}
+				// OLB verb morph, leave it out of OSIS tag
+				else {
+				}
 				handled = true;
 			}
 
 			// Morphology
 			else	if (!strncmp(token, "sync type=\"morph\"", 17)) {
+				SWBuf cls = "";
+				SWBuf morph = "";
 				for (ch = token+17; *ch; ch++) {
 					if (!strncmp(ch, "class=\"", 7)) {
 						valto = val;
 						for (unsigned int i = 7; ch[i] != '\"' && i < 127; i++)
 							*valto++ = ch[i];
 						*valto = 0;
-						sprintf(wordstr, "%03d", word-1);
 						strstrip(val);
-						module->getEntryAttributes()["Word"][wordstr]["MorphClass"] = val;
+						cls = val;
 					}
 					if (!strncmp(ch, "value=\"", 7)) {
 						valto = val;
 						for (unsigned int i = 7; ch[i] != '\"' && i < 127; i++)
 							*valto++ = ch[i];
 						*valto = 0;
-						sprintf(wordstr, "%03d", word-1);
 						strstrip(val);
-						module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
+						morph = val;
 					}
 				}
 				if (!strncmp(wordStart, "<w ", 3)) {
-
-					const char *cls = "Unknown", *morph;
-
-					if (module->getEntryAttributes()["Word"][wordstr]["Morph"].size() > 0) {
-						if (module->getEntryAttributes()["Word"][wordstr]["MorphClass"].size() > 0)
-							cls = module->getEntryAttributes()["Word"][wordstr]["MorphClass"].c_str();
-						morph = module->getEntryAttributes()["Word"][wordstr]["Morph"].c_str();
-					
-						sprintf(buf, "morph=\"x-%s:%s\" ", cls, morph);
-						memmove(wordStart+3+strlen(buf), wordStart+3, (to-wordStart)+1);
-						memcpy(wordStart+3, buf, strlen(buf));
-						to+=strlen(buf);
+					const char *attStart = strstr(wordStart, "morph");
+					if (attStart) { //existing morph attribute, append this one to it
+						attStart += 7;
+						buf = "";
+						buf.appendFormatted("%s:%s ", ((cls.length())?cls.c_str():"robinson"), morph.c_str());
 					}
+					else { // no lemma attribute
+						attStart = wordStart + 3;
+						buf = "";
+						buf.appendFormatted("morph=\"%s:%s\" ", ((cls.length())?cls.c_str():"robinson"), morph.c_str());
+					}
+					
+					text.insert(attStart - text.c_str(), buf); //hack, we have to
+				}
+				else { //no existing <w> attribute fond
+					buf = "";
+					buf.appendFormatted("<w morph=\"%s:%s\">", ((cls.length())?cls.c_str():"robinson"), morph.c_str());
+					text.insert(wordStart - text.c_str(), buf);
+					text += "</w>";
+					lastspace = false;
+
 				}
 				handled = true;
 			}
 
-			if (!keepToken) {	// if we don't want strongs
+			if (!keepToken) {
 				if (!handled) {
-					SWLog::systemlog->LogError("Unprocessed Token: <%s>", token);
+					SWLog::getSystemLog()->logError("Unprocessed Token: <%s> in key %s", token, key ? (const char*)*key : "<unknown>");
 //					exit(-1);
 				}
-				if (strchr(" ,:;.?!()'\"", from[1])) {
-					if (lastspace)
-						to--;
+				if (from[1] && strchr(" ,;.:?!()'\"", from[1])) {
+					if (lastspace) {
+						text--;
+					}
+				}
+				if (newText) {
+					textStart = from+1; 
+					newText = false; 
 				}
-				if (newText) {textStart = from+1; newText = false; }
-//				if (newWord) {wordStart = to; newWord = false; }
 				continue;
 			}
+			
 			// if not a strongs token, keep token in text
-			*to++ = '<';
-			for (char *tok = token; *tok; tok++)
-				*to++ = *tok;
-			*to++ = '>';
-			if (newText) {textStart = to; newWord = false; }
-//			if (newWord) {wordStart = to; newWord = false; }
+			text.appendFormatted("<%s>", token);
+			
+			if (newText) {
+				textStart = text.c_str() + text.length(); 
+				newWord = false; 
+			}
 			continue;
 		}
 		if (intoken) {
@@ -300,31 +371,51 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 			}
 		}
 		else	{
-			if (newWord && (*from != ' ')) {wordStart = to; newWord = false; memset(to, 0, 10); }
-			if (!suspendTextPassThru) {
-				*to++ = *from;
-				lastspace = (*from == ' ');
+			switch (*from) {
+			case '\'':
+			case '\"':
+			case '`':
+//				quoteStack.handleQuote(fromStart, from, &to);
+				text += *from;
+				//from++; //this line removes chars after an apostrophe! Needs fixing.
+				break;
+			default:
+				if (newWord && (*from != ' ')) {
+					wordStart = text.c_str() + text.length();
+					newWord = false;
+					
+					//fix this if required?
+					//memset(to, 0, 10); 
+					
+				}
+				
+				if (!suspendTextPassThru) {
+					text += (*from);
+					lastspace = (*from == ' ');
+				}
 			}
 		}
 	}
 
 	VerseKey *vkey = SWDYNAMIC_CAST(VerseKey, key);
 	if (vkey) {
-		char ref[254];
-		if (vkey->Verse())
-			sprintf(ref, "<verse osisID=\"%s\">", vkey->getOSISRef());
-		else *ref = 0;
-		if (*ref) {
-			memmove(text+strlen(ref), text, maxlen-strlen(ref)-1);
-			memcpy(text, ref, strlen(ref));
-			to+=strlen(ref);
+		SWBuf ref = "";
+		if (vkey->Verse()) {
+			ref.appendFormatted("\t\t<verse osisID=\"%s\">", vkey->getOSISRef());
+		}
+			
+		if (ref.length() > 0) {
+			
+			text = ref + text;
+			
 			if (vkey->Verse()) {
 				VerseKey tmp;
 				tmp = *vkey;
 				tmp.AutoNormalize(0);
 				tmp.Headings(1);
-				sprintf(ref, "</verse>");
-				pushString(&to, ref);
+				
+				text += "</verse>";
+				
 				tmp = MAXVERSE;
 				if (*vkey == tmp) {
 					tmp.Verse(0);
@@ -337,49 +428,23 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 						tmp.Verse(0);
 //						sprintf(ref, "\t</div>");
 //						pushString(&to, ref);
+/*
+						if (!quoteStack.empty()) {
+							SWLog::getSystemLog()->logError("popping unclosed quote at end of book");
+							quoteStack.clear();
+						}
+*/
 					}
 				}
 			}
-
-//			else if (vkey->Chapter())
+//			else if (vkey->Chapter()) {
 //				sprintf(ref, "\t<div type=\"chapter\" osisID=\"%s\">", vkey->getOSISRef());
+//			}
 //			else sprintf(ref, "\t<div type=\"book\" osisID=\"%s\">", vkey->getOSISRef());
 		}
 	}
-	*to++ = 0;
-	*to = 0;
-*/
 	return 0;
 }
 
 
-const char *ThMLOSIS::convertToOSIS(const char *inRef, const SWKey *key) {
-	static SWBuf outRef;
-
-	outRef = "";
-
-	VerseKey defLanguage;
-	ListKey verses = defLanguage.ParseVerseList(inRef, (*key), true);
-	const char *startFrag = inRef;
-	for (int i = 0; i < verses.Count(); i++) {
-		VerseKey *element = SWDYNAMIC_CAST(VerseKey, verses.GetElement(i));
-		char buf[5120];
-		char frag[5120];
-		if (element) {
-			memmove(frag, startFrag, ((const char *)element->userData - startFrag) + 1);
-			frag[((const char *)element->userData - startFrag) + 1] = 0;
-			startFrag = (const char *)element->userData + 1;
-			sprintf(buf, "<reference osisRef=\"%s-%s\">%s</reference>", element->LowerBound().getOSISRef(), element->UpperBound().getOSISRef(), frag);
-		}
-		else {
-			memmove(frag, startFrag, ((const char *)verses.GetElement(i)->userData - startFrag) + 1);
-			frag[((const char *)verses.GetElement(i)->userData - startFrag) + 1] = 0;
-			startFrag = (const char *)verses.GetElement(i)->userData + 1;
-			sprintf(buf, "<reference osisRef=\"%s\">%s</reference>", VerseKey(*verses.GetElement(i)).getOSISRef(), frag);
-		}
-		outRef+=buf;
-	}
-	return outRef.c_str();
-}
-
 SWORD_NAMESPACE_END
