@@ -18,6 +18,7 @@
 #include <thmlrtf.h>
 #include <swmodule.h>
 #include <utilxml.h>
+#include <utilstr.h>
 #include <versekey.h>
 
 SWORD_NAMESPACE_START
@@ -174,6 +175,8 @@ char ThMLRTF::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 
 
 ThMLRTF::MyUserData::MyUserData(const SWModule *module, const SWKey *key) : BasicFilterUserData(module, key) {
+	this->SecHead = false;
+	XMLTag startTag = "";
 	if (module) {
 		version = module->Name();
 		BiblicalText = (!strcmp(module->Type(), "Biblical Texts"));
@@ -217,10 +220,10 @@ bool ThMLRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 					SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 					VerseKey *vkey;
 					// see if we have a VerseKey * or descendant
-					try {
+					SWTRY {
 						vkey = SWDYNAMIC_CAST(VerseKey, u->key);
 					}
-					catch ( ... ) {	}
+					SWCATCH ( ... ) {	}
 					if (vkey) {
 						// leave this special osis type in for crossReference notes types?  Might thml use this some day? Doesn't hurt.
 						char ch = ((tag.getAttribute("type") && ((!strcmp(tag.getAttribute("type"), "crossReference")) || (!strcmp(tag.getAttribute("type"), "x-cross-ref")))) ? 'x':'n');
@@ -256,10 +259,10 @@ bool ThMLRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 					SWBuf footnoteNumber = u->startTag.getAttribute("swordFootnote");
 					VerseKey *vkey;
 					// see if we have a VerseKey * or descendant
-					try {
+					SWTRY {
 						vkey = SWDYNAMIC_CAST(VerseKey, u->key);
 					}
-					catch ( ... ) {}
+					SWCATCH ( ... ) {}
 					if (vkey) {
 						// leave this special osis type in for crossReference notes types?  Might thml use this some day? Doesn't hurt.
 						buf.appendFormatted("{\\super <a href=\"\">*x%i.%s</a>} ", vkey->Verse(), footnoteNumber.c_str());
