@@ -10,17 +10,13 @@
 #include <utilxml.h>
 #include <versekey.h>
 #include <swmodule.h>
-#ifndef __GNUC__
-#else
-#include <unixstr.h>
-#endif
 
 SWORD_NAMESPACE_START
 
 const char oName[] = "Cross-references";
 const char oTip[] = "Toggles Scripture Cross-references On and Off if they exist";
 
-const SWBuf choices[3] = {"On", "Off", ""};
+const SWBuf choices[3] = {"Off", "On", ""};
 const StringList oValues(&choices[0], &choices[2]);
 
 ThMLScripref::ThMLScripref() : SWOptionFilter(oName, oTip, &oValues) {
