@@ -9,10 +9,7 @@
 #include <stdio.h>
 #include <thmlstrongs.h>
 #include <swmodule.h>
-#ifndef __GNUC__
-#else
-#include <unixstr.h>
-#endif
+#include <utilstr.h>
 #include <ctype.h>
 
 SWORD_NAMESPACE_START
@@ -20,7 +17,7 @@ SWORD_NAMESPACE_START
 const char oName[] = "Strong's Numbers";
 const char oTip[] = "Toggles Strong's Numbers On and Off if they exist";
 
-const SWBuf choices[3] = {"On", "Off", ""};
+const SWBuf choices[3] = {"Off", "On", ""};
 const StringList oValues(&choices[0], &choices[2]);
 
 ThMLStrongs::ThMLStrongs() : SWOptionFilter(oName, oTip, &oValues) {
@@ -48,10 +45,10 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 	SWBuf tmp;
 	bool newText = false;
 
-		SWBuf orig = text;
-		from = orig.c_str();
+	SWBuf orig = text;
+	from = orig.c_str();
 
-		for (text = ""; *from; from++) {
+	for (text = ""; *from; from++) {
 		if (*from == '<') {
 			intoken = true;
 			tokpos = 0;
@@ -71,8 +68,9 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 					*valto = 0;
 					if (atoi((!isdigit(*val))?val+1:val) < 5627) {
 						// normal strongs number
-						sprintf(wordstr, "%03d", word++);
-						module->getEntryAttributes()["Word"][wordstr]["Strongs"] = val;
+						sprintf(wordstr, "%03d", word);
+						module->getEntryAttributes()["Word"][wordstr]["Lemma"] = val;
+						module->getEntryAttributes()["Word"][wordstr]["LemmaClass"] = "strong";
 						tmp = "";
 						tmp.append(text.c_str()+textStart, (int)(textEnd - textStart));
 						module->getEntryAttributes()["Word"][wordstr]["Text"] = tmp;
@@ -80,9 +78,11 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 					}
 					else {
 						// verb morph
-						sprintf(wordstr, "%03d", word-1);
+						sprintf(wordstr, "%03d", word);
 						module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
+						module->getEntryAttributes()["Word"][wordstr]["MorphClass"] = "OLBMorph";
 					}
+					word++;
 				}
 
 				if (!option) {	// if we don't want strongs
@@ -103,6 +103,9 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 								*valto++ = ch[i];
 							*valto = 0;
 							sprintf(wordstr, "%03d", word-1);
+							if ((!stricmp(val, "Robinsons")) || (!stricmp(val, "Robinson"))) {
+								strcpy(val, "robinson");
+							}
 							module->getEntryAttributes()["Word"][wordstr]["MorphClass"] = val;
 						}
 						if (!strncmp(ch, "value=\"", 7)) {
@@ -114,6 +117,7 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 							module->getEntryAttributes()["Word"][wordstr]["Morph"] = val;
 						}
 					}
+					newText = true;
 				}
 			}
 			// if not a strongs token, keep token in text
