@@ -7,19 +7,9 @@
 #include <stdio.h>
 #include <fcntl.h>
 
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
-
-#include <utilfuns.h>
 #include <rawgenbook.h>
 #include <rawstr.h>
-
-#ifndef O_BINARY
-#define O_BINARY 0
-#endif
+#include <utilstr.h>
 
 SWORD_NAMESPACE_START
 
@@ -33,7 +23,7 @@ SWORD_NAMESPACE_START
 
 RawGenBook::RawGenBook(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp, SWTextEncoding enc, SWTextDirection dir, SWTextMarkup mark, const char* ilang)
 		: SWGenBook(iname, idesc, idisp, enc, dir, mark, ilang) {
-	int fileMode = O_RDWR;
+
 	char *buf = new char [ strlen (ipath) + 20 ];
 
 	path = 0;
@@ -48,7 +38,7 @@ RawGenBook::RawGenBook(const char *ipath, const char *iname, const char *idesc,
 
 
 	sprintf(buf, "%s.bdt", path);
-	bdtfd = FileMgr::systemFileMgr.open(buf, fileMode|O_BINARY, true);
+	bdtfd = FileMgr::getSystemFileMgr()->open(buf, FileMgr::RDWR, true);
 
 	delete [] buf;
 
@@ -61,7 +51,7 @@ RawGenBook::RawGenBook(const char *ipath, const char *iname, const char *idesc,
 
 RawGenBook::~RawGenBook() {
 
-	FileMgr::systemFileMgr.close(bdtfd);
+	FileMgr::getSystemFileMgr()->close(bdtfd);
 
 	if (path)
 		delete [] path;
@@ -82,10 +72,10 @@ SWBuf &RawGenBook::getRawEntryBuf() {
 	__u32 size = 0;
 
 	TreeKeyIdx *key = 0;
-	try {
+	SWTRY {
 		key = SWDYNAMIC_CAST(TreeKeyIdx, (this->key));
 	}
-	catch ( ... ) {}
+	SWCATCH ( ... ) {}
 
 	if (!key) {
 		key = (TreeKeyIdx *)CreateKey();
@@ -106,8 +96,8 @@ SWBuf &RawGenBook::getRawEntryBuf() {
 
 		entryBuf.setFillByte(0);
 		entryBuf.setSize(size);
-		lseek(bdtfd->getFd(), offset, SEEK_SET);
-		read(bdtfd->getFd(), entryBuf.getRawData(), size);
+		bdtfd->seek(offset, SEEK_SET);
+		bdtfd->read(entryBuf.getRawData(), size);
 
 		rawFilter(entryBuf, 0);	// hack, decipher
 		rawFilter(entryBuf, key);
@@ -125,7 +115,7 @@ SWBuf &RawGenBook::getRawEntryBuf() {
 
 void RawGenBook::setEntry(const char *inbuf, long len) {
 
-	__u32 offset = archtosword32(lseek(bdtfd->getFd(), 0, SEEK_END));
+	__u32 offset = archtosword32(bdtfd->seek(0, SEEK_END));
 	__u32 size = 0;
 	TreeKeyIdx *key = ((TreeKeyIdx *)this->key);
 
@@ -134,7 +124,7 @@ void RawGenBook::setEntry(const char *inbuf, long len) {
 	if (!len)
 		len = strlen(inbuf);
 
-	write(bdtfd->getFd(), inbuf, len);
+	bdtfd->write(inbuf, len);
 
 	size = archtosword32(len);
 	memcpy(userData, &offset, 4);
@@ -148,10 +138,10 @@ void RawGenBook::linkEntry(const SWKey *inkey) {
 	TreeKeyIdx *srckey = 0;
 	TreeKeyIdx *key = ((TreeKeyIdx *)this->key);
 	// see if we have a VerseKey * or decendant
-	try {
+	SWTRY {
 		srckey = SWDYNAMIC_CAST(TreeKeyIdx, inkey);
 	}
-	catch ( ... ) {}
+	SWCATCH ( ... ) {}
 	// if we don't have a VerseKey * decendant, create our own
 	if (!srckey) {
 		srckey = (TreeKeyIdx *)CreateKey();
@@ -190,10 +180,10 @@ char RawGenBook::createModule(const char *ipath) {
 		path[strlen(path)-1] = 0;
 
 	sprintf(buf, "%s.bdt", path);
-	unlink(buf);
-	fd = FileMgr::systemFileMgr.open(buf, O_CREAT|O_WRONLY|O_BINARY, S_IREAD|S_IWRITE);
+	FileMgr::removeFile(buf);
+	fd = FileMgr::getSystemFileMgr()->open(buf, FileMgr::CREAT|FileMgr::WRONLY, FileMgr::IREAD|FileMgr::IWRITE);
 	fd->getFd();
-	FileMgr::systemFileMgr.close(fd);
+	FileMgr::getSystemFileMgr()->close(fd);
 
 	retval = TreeKeyIdx::create(path);
 	delete [] path;
