@@ -8,13 +8,7 @@
 #include <stdio.h>
 #include <fcntl.h>
 
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
-
-#include <utilfuns.h>
+#include <utilstr.h>
 #include <zstr.h>
 #include <zld.h>
 
@@ -135,7 +129,7 @@ SWBuf &zLD::getRawEntryBuf() {
 void zLD::increment(int steps) {
 	char tmperror;
 
-	if (key->Traversable()) {
+	if (key->isTraversable()) {
 		*key += steps;
 		error = key->Error();
 		steps = 0;
