@@ -5,14 +5,22 @@
  */
 
 #include <swmodule.h>
-#include <utilfuns.h>
+#include <utilstr.h>
 #include <regex.h>	// GNU
 #include <swfilter.h>
 #include <versekey.h>	// KLUDGE for Search
+#include <filemgr.h>
 #ifndef _MSC_VER
 #include <iostream>
 #endif
 
+#ifdef USELUCENE
+#include <CLucene.h>
+using namespace lucene::search;
+using namespace lucene::queryParser;
+#endif
+
+
 SWORD_NAMESPACE_START
 
 SWDisplay SWModule::rawdisp;
@@ -238,14 +246,14 @@ char *SWModule::Lang(const char *imodlang)
  * RET:	pointer to disp
  */
 
-SWDisplay *SWModule::Disp(SWDisplay *idisp)
-{
-	if (idisp)
-		disp = idisp;
-
+SWDisplay *SWModule::getDisplay() const {
 	return disp;
 }
 
+void SWModule::setDisplay(SWDisplay *idisp) {
+	disp = idisp;
+}
+
 
 /******************************************************************************
  * SWModule::Display - Calls this modules display object and passes itself
@@ -253,8 +261,7 @@ SWDisplay *SWModule::Disp(SWDisplay *idisp)
  * RET:	error status
  */
 
-char SWModule::Display()
-{
+char SWModule::Display() {
 	disp->Display(*this);
 	return 0;
 }
@@ -366,7 +373,8 @@ void SWModule::decrement(int steps) {
  *				>=0 - regex
  *				-1  - phrase
  *				-2  - multiword
- *				-3  - entryAttrib
+ *				-3  - entryAttrib (eg. Word//Lemma/G1234/)
+ *				-4  - clucene
  * 	flags		- options flags for search
  *	justCheckIfSupported	- if set, don't search, only tell if this
  *							function supports requested search.
@@ -375,6 +383,26 @@ void SWModule::decrement(int steps) {
  */
 
 ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *scope, bool *justCheckIfSupported, void (*percent)(char, void *), void *percentUserData) {
+
+	listkey.ClearList();
+
+#ifdef USELUCENE
+	SWBuf target = getConfigEntry("AbsoluteDataPath");
+	char ch = target.c_str()[strlen(target.c_str())-1];
+	if ((ch != '/') && (ch != '\\'))
+		target.append('/');
+	target.append("lucene");
+#endif
+	if (justCheckIfSupported) {
+		*justCheckIfSupported = (searchType >= -3);
+#ifdef USELUCENE
+		if ((searchType == -4) && (IndexReader::indexExists(target.c_str()))) {
+			*justCheckIfSupported = true;
+		}
+#endif
+		return listkey;
+	}
+	
 	SWKey *savekey = 0;
 	SWKey *searchkey = 0;
 	regex_t preg;
@@ -389,7 +417,6 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 
 	processEntryAttributes(searchType == -3);
 	
-	listkey.ClearList();
 
 	if (!key->Persist()) {
 		savekey = CreateKey();
@@ -408,14 +435,10 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 	// 	VerseKey::NewIndex should be moved to Index and Index should be some
 	// 	VerseKey specific name
 	VerseKey *vkcheck = 0;
-#ifndef _WIN32_WCE
-	try {
-#endif
+	SWTRY {
 		vkcheck = SWDYNAMIC_CAST(VerseKey, key);
-#ifndef _WIN32_WCE
 	}
-	catch (...) {}
-#endif
+	SWCATCH (...) {}
 	// end MAJOR KLUDGE
 
 	*this = BOTTOM;
@@ -430,6 +453,73 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 	}
 
 	(*percent)(++perc, percentUserData);
+
+
+#ifdef USELUCENE
+	if (searchType == -4) {	// lucene
+		// test to see if our scope for this search is bounded by a
+		// VerseKey
+		VerseKey *testKeyType = 0, vk;
+		SWTRY {
+			testKeyType = SWDYNAMIC_CAST(VerseKey, ((scope)?scope:key));
+		}
+		SWCATCH ( ... ) {}
+		// if we don't have a VerseKey * decendant we can't handle
+		// because of scope.
+		// In the future, add bool SWKey::isValid(const char *tryString);
+		// For now just drop back to multiword unindexed
+		if (!testKeyType) {
+			searchType = -3;
+		}
+		else {
+			lucene::index::IndexReader *ir;
+			lucene::search::IndexSearcher *is;
+			ir = &IndexReader::open(target);
+			is = new IndexSearcher(*ir);
+			(*percent)(10, percentUserData);
+
+			standard::StandardAnalyzer analyzer;
+			Query &q =  QueryParser::Parse(istr, _T("content"), analyzer);
+			(*percent)(20, percentUserData);
+			Hits &h = is->search(q);
+			(*percent)(80, percentUserData);
+
+
+			// iterate thru each good module position that meets the search
+			for (long i = 0; i < h.Length(); i++) {
+				Document &doc = h.doc(i);
+
+				// set a temporary verse key to this module position
+				vk = doc.get(_T("key"));
+
+				// check scope
+				// Try to set our scope key to this verse key
+				if (scope) {
+					*testKeyType = vk;
+
+					// check to see if it set ok and if so, add to our return list
+					if (*testKeyType == vk) {
+						listkey << (const char *) vk;
+						listkey.GetElement()->userData = reinterpret_cast<void *>((int)(h.score(i)*100));
+					}
+				}
+				else {
+					listkey << (const char*) vk;
+					listkey.GetElement()->userData = reinterpret_cast<void *>((int)(h.score(i)*100));
+				}
+			}
+			(*percent)(98, percentUserData);
+
+			delete &h;
+			delete &q;
+
+			delete is;
+			ir->close();
+		}
+	}
+#endif
+
+
 	if (searchType == -2) {
 		wordBuf = (char *)calloc(sizeof(char), strlen(istr) + 1);
 		strcpy(wordBuf, istr);
@@ -475,9 +565,8 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 	perc = 5;
 	(*percent)(perc, percentUserData);
 
-	while (!Error() && !terminateSearch) {
-
 	
+	while ((searchType > -4) && !Error() && !terminateSearch) {
 		long mindex = 0;
 		if (vkcheck)
 			mindex = vkcheck->NewIndex();
@@ -509,20 +598,30 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 		}
 		else if (searchType == -1) {
 			sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(StripText(), istr) : strstr(StripText(), istr);
-			if (sres) {
-					textkey = KeyText();
-					listkey << textkey;
+			if (sres) { //it's also in the StripText(), so we have a valid search result item now
+				textkey = KeyText();
+				listkey << textkey;
 			}
 		}
 		else if (searchType == -2) {
-			int i;
-			const char *stripBuf = StripText();
-			for (i = 0; i < wordCount; i++) {
-				sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(stripBuf, words[i]) : strstr(stripBuf, words[i]);
-				if (!sres)
-					break;
-			}
-			if (i == wordCount) {
+			int loopCount = 0;
+			int foundWords = 0;
+			do {
+				const char* textBuf = (loopCount == 0) ? getRawEntry() : StripText();
+				foundWords = 0;
+				
+				for (int i = 0; i < wordCount; ++i) {
+					sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(textBuf, words[i]) : strstr(textBuf, words[i]);
+					if (!sres) {
+						break; //for loop
+					}
+					++foundWords;
+				}
+				
+				++loopCount;
+			} while ( (loopCount < 2) && (foundWords == wordCount));
+			
+			if ((loopCount == 2) && (foundWords == wordCount)) { //we found the right words in both raw and stripped text, which means it's a valid result item
 				textkey = KeyText();
 				listkey << textkey;
 			}
@@ -568,7 +667,13 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 						i3End   = i2Start->second.end();
 					}
 					for (;i3Start != i3End; i3Start++) {
-						sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(i3Start->second.c_str(), words[3]) : strstr(i3Start->second.c_str(), words[3]);
+						if (flags & SEARCHFLAG_MATCHWHOLEENTRY) {
+							bool found = !(((flags & REG_ICASE) == REG_ICASE) ? stricmp(i3Start->second.c_str(), words[3]) : strcmp(i3Start->second.c_str(), words[3]));
+							sres = (found) ? i3Start->second.c_str() : 0;
+						}
+						else {
+							sres = ((flags & REG_ICASE) == REG_ICASE) ? stristr(i3Start->second.c_str(), words[3]) : strstr(i3Start->second.c_str(), words[3]);
+						}
 						if (sres) {
 							textkey = KeyText();
 							listkey << textkey;
@@ -584,6 +689,7 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
 		}
 		(*this)++;
 	}
+	
 	if (searchType >= 0)
 		regfree(&preg);
 
@@ -617,8 +723,7 @@ ListKey &SWModule::search(const char *istr, int searchType, int flags, SWKey *sc
  * RET: this module's text at specified key location massaged by Strip filters
  */
 
-const char *SWModule::StripText(const char *buf, int len)
-{
+const char *SWModule::StripText(const char *buf, int len) {
 	return RenderText(buf, len, false);
 }
 
@@ -672,8 +777,7 @@ const char *SWModule::StripText(const char *buf, int len)
  * RET: this module's text at specified key location massaged by RenderFilers
  */
 
- const char *SWModule::RenderText(SWKey *tmpKey)
-{
+ const char *SWModule::RenderText(SWKey *tmpKey) {
 	SWKey *savekey;
 	const char *retVal;
 
@@ -704,8 +808,7 @@ const char *SWModule::StripText(const char *buf, int len)
  * RET: this module's text at specified key location massaged by Strip filters
  */
 
-const char *SWModule::StripText(SWKey *tmpKey)
-{
+const char *SWModule::StripText(SWKey *tmpKey) {
 	SWKey *savekey;
 	const char *retVal;
 
@@ -738,4 +841,195 @@ void SWModule::setConfig(ConfigEntMap *config) {
 	this->config = config;
 }
 
+
+bool SWModule::hasSearchFramework() {
+#ifdef USELUCENE
+	return true;
+#else
+	return SWSearchable::hasSearchFramework();
+#endif
+}
+
+void SWModule::deleteSearchFramework() {
+#ifdef USELUCENE
+	SWBuf target = getConfigEntry("AbsoluteDataPath");
+	char ch = target.c_str()[strlen(target.c_str())-1];
+	if ((ch != '/') && (ch != '\\'))
+		target.append('/');
+	target.append("lucene");
+
+	FileMgr::removeDir(target.c_str());
+#else
+	SWSearchable::deleteSearchFramework();
+#endif
+}
+
+
+signed char SWModule::createSearchFramework(void (*percent)(char, void *), void *percentUserData) {
+#ifdef USELUCENE
+	SWKey *savekey = 0;
+	SWKey *searchkey = 0;
+	SWKey textkey;
+	char *word = 0;
+	char *wordBuf = 0;
+
+
+	// turn all filters to default values
+	StringList filterSettings;
+	for (FilterList::iterator filter = optionFilters->begin(); filter != optionFilters->end(); filter++) {
+		filterSettings.push_back((*filter)->getOptionValue());
+		(*filter)->setOptionValue(*((*filter)->getOptionValues().begin()));
+	}
+
+	
+	// be sure we give CLucene enough file handles	
+	FileMgr::getSystemFileMgr()->flush();
+
+	// save key information so as not to disrupt original
+	// module position
+	if (!key->Persist()) {
+		savekey = CreateKey();
+		*savekey = *key;
+	}
+	else	savekey = key;
+
+	searchkey = (key->Persist())?key->clone():0;
+	if (searchkey) {
+		searchkey->Persist(1);
+		setKey(*searchkey);
+	}
+
+	// position module at the beginning
+	*this = TOP;
+
+	// iterate thru each entry in module
+
+	IndexWriter *writer = NULL;
+	Directory *d = NULL;
+ 
+	standard::StandardAnalyzer *an = new standard::StandardAnalyzer();
+	SWBuf target = getConfigEntry("AbsoluteDataPath");
+	char ch = target.c_str()[strlen(target.c_str())-1];
+	if ((ch != '/') && (ch != '\\'))
+		target.append('/');
+	target.append("lucene");
+	FileMgr::createParent(target+"/dummy");
+
+	if (IndexReader::indexExists(target.c_str())) {
+		d = &FSDirectory::getDirectory(target.c_str(), false);
+		if (IndexReader::isLocked(*d)) {
+			IndexReader::unlock(*d);
+		}
+																		   
+		writer = new IndexWriter(*d, *an, false);
+	} else {
+		d = &FSDirectory::getDirectory(target.c_str(), true);
+		writer = new IndexWriter( *d ,*an, true);
+	}
+
+
+ 
+	char perc = 1;
+	VerseKey *vkcheck = 0;
+	SWTRY {
+		vkcheck = SWDYNAMIC_CAST(VerseKey, key);
+	}
+	SWCATCH (...) {}
+	long highIndex = (vkcheck)?32300/*vkcheck->NewIndex()*/:key->Index();
+	if (!highIndex)
+		highIndex = 1;		// avoid division by zero errors.
+
+	bool savePEA = isProcessEntryAttributes();
+	processEntryAttributes(true);
+
+	while (!Error()) {
+		long mindex = 0;
+		if (vkcheck)
+			mindex = vkcheck->NewIndex();
+		else mindex = key->Index();
+
+		// computer percent complete so we can report to our progress callback
+		float per = (float)mindex / highIndex;
+		// between 5%-98%
+		per *= 93; per += 5;
+		char newperc = (char)per;
+		if (newperc > perc) {
+			perc = newperc;
+			(*percent)(perc, percentUserData);
+		}
+
+		// get "content" field
+		const char *content = StripText();
+
+		if (content && *content) {
+
+			// get "key" field
+			SWBuf keyText = (vkcheck) ? vkcheck->getOSISRef() : getKeyText();
+			
+			// build "strong" field
+			SWBuf strong;
+		
+			AttributeTypeList::iterator words;
+			AttributeList::iterator word;
+			AttributeValue::iterator strongVal;
+
+			words = getEntryAttributes().find("Word");
+			if (words != getEntryAttributes().end()) {
+				for (word = words->second.begin();word != words->second.end(); word++) {
+					strongVal = word->second.find("Lemma");
+					if (strongVal != word->second.end()) {
+						// cheeze.  skip empty article tags that weren't assigned to any text
+						if (strongVal->second == "G3588") {
+							if (word->second.find("Text") == word->second.end())
+								continue;	// no text? let's skip
+						}
+						strong.append(strongVal->second);
+						strong.append(' ');
+					}
+				}
+			}
+
+			// add our entry to the clucene index		
+			Document *doc = new Document();
+			doc->add( Field::UnIndexed(_T("key"), keyText ) );
+			doc->add( Field::UnStored(_T("content"), content) );
+			if (strong.length() > 0)
+				doc->add( Field::UnStored(_T("lemma"), strong) );
+			writer->addDocument(*doc);
+			delete doc;
+		}
+
+		(*this)++;
+	}
+
+	writer->optimize();
+	writer->close();
+	delete writer;
+	delete an;
+
+	// reposition module back to where it was before we were called
+	setKey(*savekey);
+
+	if (!savekey->Persist())
+		delete savekey;
+
+	if (searchkey)
+		delete searchkey;
+
+	processEntryAttributes(savePEA);
+
+	// reset option filters back to original values
+	StringList::iterator origVal = filterSettings.begin();
+	for (FilterList::iterator filter = optionFilters->begin(); filter != optionFilters->end(); filter++) {
+		(*filter)->setOptionValue(*origVal++);
+	}
+
+	return 0;
+#else
+	return SWSearchable::createSearchFramework(percent, percentUserData);
+#endif
+}
+
+
+
 SWORD_NAMESPACE_END
