@@ -6,41 +6,30 @@
 
 #include <stdio.h>
 #include <fcntl.h>
+#include <sysdata.h>
 
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
-
-#include <utilfuns.h>
+#include <utilstr.h>
 #include <rawverse.h>
 #include <rawtext.h>
 
 #include <regex.h>	// GNU
-#ifdef USELUCENE
-#include <CLucene/CLucene.h>
-using namespace lucene::search;
-using namespace lucene::queryParser;
-#else
 #include <map>
 #include <list>
 #include <algorithm>
 
+#ifndef USELUCENE
 using std::map;
 using std::list;
 using std::find;
-
 #endif
 
-#ifndef O_BINARY
-#define O_BINARY 0
-#endif
 
 SWORD_NAMESPACE_START
 
+#ifndef USELUCENE
 typedef  map < SWBuf, list<long> > strlist;
 typedef list<long> longlist;
+#endif
 
 /******************************************************************************
  * RawText Constructor - Initializes data for instance of RawText
@@ -52,21 +41,9 @@ typedef list<long> longlist;
 
 RawText::RawText(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp, SWTextEncoding enc, SWTextDirection dir, SWTextMarkup mark, const char* ilang)
 		: SWText(iname, idesc, idisp, enc, dir, mark, ilang),
-          RawVerse(ipath) {
-          
-#ifdef USELUCENE
-	SWBuf fname;
-	fname = path;
-	ir = 0;
-	is = 0;
-	char ch = fname.c_str()[strlen(fname.c_str())-1];
-	if ((ch != '/') && (ch != '\\'))
-		fname += "/lucene";
-	if (IndexReader::indexExists(fname.c_str())) {
-		ir = &IndexReader::open(fname);
-		is = new IndexSearcher(*ir);
-	}
-#else
+		RawVerse(ipath) {
+		
+#ifndef USELUCENE
 	SWBuf fname;
 	fname = path;
 	char ch = fname.c_str()[strlen(fname.c_str())-1];
@@ -74,13 +51,13 @@ RawText::RawText(const char *ipath, const char *iname, const char *idesc, SWDisp
 		fname += "/";
 	
 	for (int loop = 0; loop < 2; loop++) {
-     	fastSearch[loop] = 0;
+		fastSearch[loop] = 0;
 		SWBuf fastidxname =(fname + ((loop)?"ntwords.dat":"otwords.dat"));
-		if (!access(fastidxname.c_str(), 04)) {
+		if (FileMgr::existsFile(fastidxname.c_str())) {
 			fastidxname = (fname + ((loop)?"ntwords.idx":"otwords.idx"));
-			if (!access(fastidxname.c_str(), 04))
+			if (FileMgr::existsFile(fastidxname.c_str()))
 				fastSearch[loop] = new RawStr((fname + ((loop)?"ntwords":"otwords")).c_str());
-        	}
+		}
 	}
 #endif
 }
@@ -91,13 +68,7 @@ RawText::RawText(const char *ipath, const char *iname, const char *idesc, SWDisp
  */
 
 RawText::~RawText() {
-#ifdef USELUCENE
-	if (is)
-		is->close();
-
-	if (ir)
-		delete ir;
-#else
+#ifndef USELUCENE
 	if (fastSearch[0])
 		delete fastSearch[0];
 
@@ -111,21 +82,21 @@ VerseKey &RawText::getVerseKey() {
 	static VerseKey tmpVK;
 	VerseKey *key;
 	// see if we have a VerseKey * or decendant
-	try {
+	SWTRY {
 		key = SWDYNAMIC_CAST(VerseKey, this->key);
 	}
-	catch ( ... ) {	}
+	SWCATCH ( ... ) {	}
 	if (!key) {
 		ListKey *lkTest = 0;
-		try {
+		SWTRY {
 			lkTest = SWDYNAMIC_CAST(ListKey, this->key);
 		}
-		catch ( ... ) {	}
+		SWCATCH ( ... ) {	}
 		if (lkTest) {
-			try {
+			SWTRY {
 				key = SWDYNAMIC_CAST(VerseKey, lkTest->GetElement());
 			}
-			catch ( ... ) {	}
+			SWCATCH ( ... ) {	}
 		}
 	}
 	if (!key) {
@@ -164,85 +135,8 @@ SWBuf &RawText::getRawEntryBuf() {
 }
 
 
-signed char RawText::createSearchFramework() {
-#ifdef USELUCENE
-	SWKey *savekey = 0;
-	SWKey *searchkey = 0;
-	SWKey textkey;
-	char *word = 0;
-	char *wordBuf = 0;
-
-
-	// save key information so as not to disrupt original
-	// module position
-	if (!key->Persist()) {
-		savekey = CreateKey();
-		*savekey = *key;
-	}
-	else	savekey = key;
-
-	searchkey = (key->Persist())?key->clone():0;
-	if (searchkey) {
-		searchkey->Persist(1);
-		setKey(*searchkey);
-	}
-
-	// position module at the beginning
-	*this = TOP;
-
-	VerseKey *lkey = (VerseKey *)key;
-
-	// iterate thru each entry in module
-
-	IndexWriter* writer = NULL;
-	Directory* d = NULL;
- 
-	lucene::analysis::SimpleAnalyzer& an = *new lucene::analysis::SimpleAnalyzer();
-	SWBuf target = path;
-	char ch = target.c_str()[strlen(target.c_str())-1];
-	if ((ch != '/') && (ch != '\\'))
-		target += "/lucene";
-
-	if (IndexReader::indexExists(target.c_str())) {
-		d = &FSDirectory::getDirectory(target.c_str(), false);
-		if (IndexReader::isLocked(*d)) {
-			IndexReader::unlock(*d);
-		}
-																		   
-		writer = new IndexWriter(*d, an, false);
-	} else {
-		d = &FSDirectory::getDirectory(target.c_str(), true);
-		writer = new IndexWriter( *d ,an, true);
-	}
-
-
- 
-	while (!Error()) {
-		Document &doc = *new Document();
-		doc.add( Field::Text(_T("key"), (const char *)*lkey ) );
-		doc.add( Field::Text(_T("content"), StripText()) );
-		writer->addDocument(doc);
-		delete &doc;
-
-		(*this)++;
-	}
-
-	writer->optimize();
-	writer->close();
-	delete writer;
-	delete &an;
-
-	// reposition module back to where it was before we were called
-	setKey(*savekey);
-
-	if (!savekey->Persist())
-		delete savekey;
-
-	if (searchkey)
-		delete searchkey;
-
-	
-#else
+signed char RawText::createSearchFramework(void (*percent)(char, void *), void *percentUserData) {
+#ifndef USELUCENE
 	SWKey *savekey = 0;
 	SWKey *searchkey = 0;
 	SWKey textkey;
@@ -308,8 +202,8 @@ signed char RawText::createSearchFramework() {
 
 	
 	// --------- Let's output an index from our dictionary -----------
-	int datfd;
-	int idxfd;
+	FileDesc *datfd;
+	FileDesc *idxfd;
 	strlist::iterator it;
 	longlist::iterator it2;
 	unsigned long offset, entryoff;
@@ -323,10 +217,12 @@ signed char RawText::createSearchFramework() {
 
 	// for old and new testament do...
 	for (int loop = 0; loop < 2; loop++) {
-		if ((datfd = open((fname + ((loop)?"ntwords.dat":"otwords.dat")).c_str(), O_CREAT|O_WRONLY|O_BINARY, 00644 )) == -1)
+		datfd = FileMgr::getSystemFileMgr()->open((fname + ((loop)?"ntwords.dat":"otwords.dat")).c_str(), FileMgr::CREAT|FileMgr::WRONLY, 00644);
+		if (datfd->getFd() == -1)
 			return -1;
-		if ((idxfd = open((fname + ((loop)?"ntwords.idx":"otwords.idx")).c_str(), O_CREAT|O_WRONLY|O_BINARY, 00644 )) == -1) {
-			close(datfd);
+		idxfd = FileMgr::getSystemFileMgr()->open((fname + ((loop)?"ntwords.idx":"otwords.idx")).c_str(), FileMgr::CREAT|FileMgr::WRONLY, 00644);
+		if (idxfd->getFd() == -1) {
+			FileMgr::getSystemFileMgr()->close(datfd);
 			return -1;
 		}
 
@@ -336,12 +232,12 @@ signed char RawText::createSearchFramework() {
 
 			// get our current offset in our word.dat file and write this as the start
 			// of the next entry in our database
-			offset = lseek(datfd, 0, SEEK_CUR);
-			write(idxfd, &offset, 4);
+			offset = datfd->seek(0, SEEK_CUR);
+			idxfd->write(&offset, 4);
 
 			// write our word out to the word.dat file, delineating with a \n
-			write(datfd, it->first.c_str(), strlen(it->first.c_str()));
-			write(datfd, "\n", 1);
+			datfd->write(it->first.c_str(), strlen(it->first.c_str()));
+			datfd->write("\n", 1);
 
 			// force our mod position list for this word to be unique (remove
 			// duplicates that may exist if the word was found more than once
@@ -353,23 +249,41 @@ signed char RawText::createSearchFramework() {
 			unsigned short count = 0;
 			for (it2 = it->second.begin(); it2 != it->second.end(); it2++) {
 				entryoff= *it2;
-				write(datfd, &entryoff, 4);
+				datfd->write(&entryoff, 4);
 				count++;
 			}
 			
 			// now see what our new position is in our word.dat file and
 			// determine the size of this database entry
-			size = lseek(datfd, 0, SEEK_CUR) - offset;
+			size = datfd->seek(0, SEEK_CUR) - offset;
 
 			// store the size of this database entry
-			write(idxfd, &size, 2);
+			idxfd->write(&size, 2);
 			printf("%d entries (size: %d)\n", count, size);
 		}
-		close(datfd);
-		close(idxfd);
+		FileMgr::getSystemFileMgr()->close(datfd);
+		FileMgr::getSystemFileMgr()->close(idxfd);
 	}
-#endif
 	return 0;
+#else
+	return SWModule::createSearchFramework(percent, percentUserData);
+#endif
+}
+
+
+void RawText::deleteSearchFramework() {
+#ifndef USELUCENE
+	SWBuf target = path;
+	char ch = target.c_str()[strlen(target.c_str())-1];
+	if ((ch != '/') && (ch != '\\'))
+		target += "/lucene";
+	FileMgr::removeFile(target + "ntwords.dat");
+	FileMgr::removeFile(target + "otwords.dat");
+	FileMgr::removeFile(target + "ntwords.idx");
+	FileMgr::removeFile(target + "otwords.idx");
+#else
+	SWModule::deleteSearchFramework();
+#endif
 }
 
 
@@ -389,88 +303,7 @@ signed char RawText::createSearchFramework() {
  */
 
 ListKey &RawText::search(const char *istr, int searchType, int flags, SWKey *scope, bool *justCheckIfSupported, void (*percent)(char, void *), void *percentUserData) {
-#ifdef USELUCENE
-	listkey.ClearList();
-
-	if ((is) && (ir)) {
-
-		switch (searchType) {
-		case -2: {	// let lucene replace multiword for now
-
-
-			// test to see if our scope for this search is bounded by a
-			// VerseKey
-			VerseKey *testKeyType = 0, vk;
-			try {
-				testKeyType = SWDYNAMIC_CAST(VerseKey, ((scope)?scope:key));
-			}
-			catch ( ... ) {}
-			// if we don't have a VerseKey * decendant we can't handle
-			// because of scope.
-			// In the future, add bool SWKey::isValid(const char *tryString);
-			if (!testKeyType)
-				break;
-
-
-			// check if we just want to see if search is supported.
-			// If we've gotten this far, then it is supported.
-			if (justCheckIfSupported) {
-				*justCheckIfSupported = true;
-				return listkey;
-			}
-
-			(*percent)(10, percentUserData);
-
-			standard::StandardAnalyzer analyzer;
-			Query &q =  QueryParser::Parse(istr, _T("content"), analyzer);
-			(*percent)(20, percentUserData);
-			Hits &h = is->search(q);
-			(*percent)(80, percentUserData);
-
-
-			// iterate thru each good module position that meets the search
-			for (long i = 0; i < h.Length(); i++) {
-				Document &doc = h.doc(i);
-
-				// set a temporary verse key to this module position
-				vk = doc.get(_T("key"));
-
-				// check scope
-				// Try to set our scope key to this verse key
-				if (scope) {
-					*testKeyType = vk;
-
-					// check to see if it set ok and if so, add to our return list
-					if (*testKeyType == vk)
-						listkey << (const char *) vk;
-						listkey.GetElement()->userData = (void *)(int)(h.score(i)*100);
-				}
-				else {
-					listkey << (const char*) vk;
-					listkey.GetElement()->userData = (void *)(int)(h.score(i)*100);
-				}
-			}
-			(*percent)(98, percentUserData);
-
-			delete &h;
-			delete &q;
-
-			listkey = TOP;
-			(*percent)(100, percentUserData);
-			return listkey;
-		}
-
-		default:
-			break;
-		}
-	}
-
-	// check if we just want to see if search is supported
-	if (justCheckIfSupported) {
-		*justCheckIfSupported = false;
-		return listkey;
-	}
-#else
+#ifndef USELUCENE
 	listkey.ClearList();
 
 	if ((fastSearch[0]) && (fastSearch[1])) {
@@ -485,10 +318,10 @@ ListKey &RawText::search(const char *istr, int searchType, int flags, SWKey *sco
 			// test to see if our scope for this search is bounded by a
 			// VerseKey
 			VerseKey *testKeyType = 0;
-			try {
+			SWTRY {
 				testKeyType = SWDYNAMIC_CAST(VerseKey, ((scope)?scope:key));
 			}
-			catch ( ... ) {}
+			SWCATCH ( ... ) {}
 			// if we don't have a VerseKey * decendant we can't handle
 			// because of scope.
 			// In the future, add bool SWKey::isValid(const char *tryString);
@@ -666,10 +499,10 @@ void RawText::linkEntry(const SWKey *inkey) {
 	const VerseKey *srckey = 0;
 
 	// see if we have a VerseKey * or decendant
-	try {
+	SWTRY {
 		srckey = SWDYNAMIC_CAST(VerseKey, inkey);
 	}
-	catch ( ... ) {}
+	SWCATCH ( ... ) {}
 	// if we don't have a VerseKey * decendant, create our own
 	if (!srckey)
 		srckey = new VerseKey(inkey);
