@@ -1,3 +1,23 @@
+/******************************************************************************
+ *  utilxml.cpp   - implementaion of utility classes to handle XML processing
+ *
+ * $Id: utilxml.cpp 1688 2005-01-01 04:42:26Z scribe $
+ *
+ * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
 
 #include <utilxml.h>
 #include <ctype.h>
@@ -5,11 +25,14 @@
 
 SWORD_NAMESPACE_START
 
+const char *XMLTag::nullstr = "";
 void XMLTag::parse() const {
 	int i;
 	int start;
 	char *name = 0;
 	char *value = 0;
+	attributes.clear();
+	
 	if (!buf)
 		return;
 	for (i = 0; ((buf[i]) && (!isalpha(buf[i]))); i++);
@@ -113,7 +136,7 @@ const StringList XMLTag::getAttributeNames() const {
 	if (!parsed)
 		parse();
 
-	for (StringPairMap::iterator it = attributes.begin(); it != attributes.end(); it++)
+	for (StringPairMap::const_iterator it = attributes.begin(); it != attributes.end(); it++)
 		retVal.push_back(it->first.c_str());
 
 	return retVal;
@@ -150,11 +173,16 @@ int XMLTag::getAttributePartCount(const char *attribName, char partSplit) const
 
 
 const char *XMLTag::getAttribute(const char *attribName, int partNum, char partSplit) const {
+
 	if (!parsed)
 		parse();
 
-	StringPairMap::iterator it = attributes.find(attribName);
-	const char *retVal = (it == attributes.end()) ? 0 : it->second.c_str();
+	StringPairMap::const_iterator it = attributes.find(attribName);
+
+	const char *retVal = 0;
+	if (it != attributes.end()) 
+		retVal = it->second.c_str();		
+		
 	if ((retVal) && (partNum > -1))
 		retVal = getPart(retVal, partNum, partSplit);
 
@@ -177,17 +205,22 @@ const char *XMLTag::toString() const {
 		parse();
 
 	if (isEndTag())
-		tag += "/";
+		tag.append('/');
 
-	tag += getName();
+	tag.append(getName());
 	for (StringPairMap::iterator it = attributes.begin(); it != attributes.end(); it++) {
-		tag.appendFormatted(" %s=\"%s\"", it->first.c_str(), it->second.c_str());
+		//tag.appendFormatted(" %s=\"%s\"", it->first.c_str(), it->second.c_str());
+		tag.append(' ');
+		tag.append(it->first.c_str());
+		tag.append("=\"");
+		tag.append(it->second.c_str());
+		tag.append('"');
 	}
 
 	if (isEmpty())
-		tag += "/";
+		tag.append('/');
 
-	tag += ">";
+	tag.append('>');
 
 
 	if (buf)
