@@ -4,7 +4,9 @@
 #include <stdio.h>
 #include <treekeyidx.h>
 #include <rawgenbook.h>
-
+#ifndef NO_SWORD_NAMESPACE
+using namespace sword;
+#endif
 
 void printTree(TreeKeyIdx treeKey, TreeKeyIdx *target = 0, int level = 1) {
 	if (!target)
@@ -54,7 +56,7 @@ void viewEntryText(RawGenBook *book) {
 
 
 void setEntryText(RawGenBook *book) {
-	string body;
+	std::string body;
 	TreeKeyIdx *treeKey = (TreeKeyIdx *)(SWKey *)(*book);
 	if (treeKey->getOffset()) {
 		char buf[1023];
@@ -123,7 +125,7 @@ int main(int argc, char **argv) {
 	TreeKeyIdx root = *((TreeKeyIdx *)((SWKey *)(*book)));
 	treeKey = (TreeKeyIdx *)(SWKey *)(*book);
 
-	string input;
+	std::string input;
 	char line[1024];
 
 	do {
