@@ -15,7 +15,7 @@ int main(int argc, char **argv) {
 	}
 
 	if (argc > 2)
-		LocaleMgr::systemLocaleMgr.setDefaultLocaleName(argv[2]);
+		LocaleMgr::getSystemLocaleMgr()->setDefaultLocaleName(argv[2]);
 
 	VerseKey DefaultVSKey;
 
@@ -38,6 +38,6 @@ int main(int argc, char **argv) {
 		verses.setText(argv[3]);
 		std::cout << "Verse is" << ((verses.Error()) ? " NOT" : "") << " in set.\n\n";
 	}
-
+	
 	return 0;
 }
