@@ -2,9 +2,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
-extern "C" {
 #include <roman.h>
-}
+
+#ifndef NO_SWORD_NAMESPACE
+using sword::from_rom;
+#endif
 
 int main(int argc, char **argv) {
 	if (argc != 2) {
