@@ -3,9 +3,6 @@
 #else
 #include <unistd.h>
 #endif
-#ifndef O_BINARY
-#define O_BINARY 0
-#endif
 #include <fcntl.h>
 #include <errno.h>
 #include <iostream>
