@@ -1,13 +1,17 @@
 #!/bin/sh
 
-OPTIONS="--prefix=/usr"
-OPTIONS="--disable-shared $OPTIONS"
+OPTIONS="--prefix=/usr $OPTIONS"
 OPTIONS="--without-conf $OPTIONS"
 OPTIONS="--sysconfdir=/etc $OPTIONS"
-#OPTIONS="--with-vcl $OPTIONS"
-OPTIONS="--enable-debug $OPTIONS"
+#OPTIONS="--with-lucene $OPTIONS"
+#OPTIONS="--with-icu $OPTIONS"
+#OPTIONS="--without-curl $OPTIONS"
+#OPTIONS="--enable-tests $OPTIONS"
 #OPTIONS="--enable-profile $OPTIONS"
-OPTIONS="--without-lucene $OPTIONS"
+#OPTIONS="--enable-debug $OPTIONS"
+#OPTIONS="--disable-shared $OPTIONS"
+#OPTIONS="--disable-utilities $OPTIONS"
+
 
 CPPFLAGS="$CFLAGS $CPPFLAGS -DUSBINARY" ./configure $OPTIONS $*
 
