@@ -23,10 +23,6 @@ using sword::ListKey;
 using sword::SWModule;
 #endif
 
-#ifndef O_BINARY
-#define O_BINARY 0
-#endif
-
 int main(int argc, char **argv) {
   
   const char * helptext = "addvs 1.1 Bible & Commentary module creation tool for the SWORD Project\nUse -a to add a new verse from standard input or a file, -d to delete a verse,\n-l to link two verses, -c to create a new module.\n  usage:\n   %s -a </path/to/module> <verse> [</path/to/file/with/verse>]\n   %s -d </path/to/module> <key>\n   %s -l </path/to/module> <first verse (already assigned)> <second verse>\n   %s -c </path/to/module>\n";
