@@ -1,17 +1,43 @@
 #include <stdio.h>
 #include <rawtext.h>
 #include <swmgr.h>
+#include <markupfiltmgr.h>
+#include <swbuf.h>
+
+
 #ifndef NO_SWORD_NAMESPACE
 using sword::SWMgr;
 using sword::SWModule;
 using sword::ListKey;
 using sword::VerseKey;
 using sword::ModMap;
+using sword::SWBuf;
 #endif
 
+void percentUpdate(char percent, void *userData) {
+	static char printed = 0;
+	char maxHashes = *((char *)userData);
+	
+	while ((((float)percent)/100) * maxHashes > printed) {
+		printf("=");
+		printed++;
+		fflush(stdout);
+	}
+/*
+	std::cout << (int)percent << "% ";
+*/
+	fflush(stdout);
+}
+
+
 int main(int argc, char **argv)
 {
-	SWMgr manager(0,0,true);
+	SWMgr manager(new sword::MarkupFilterMgr(sword::FMT_HTMLHREF, sword::ENC_UTF16));
+	SWModule &kjv = *(manager.Modules["KJV"]);
+	for (kjv.setKey("Gen 1:1"); ((VerseKey *)kjv.getKey())->Chapter() == 1; kjv++) {
+		SWBuf x = kjv.RenderText();
+	}
+	
 	SWModule *target;
 	ListKey listkey;
 	VerseKey vk;
@@ -37,8 +63,11 @@ int main(int argc, char **argv)
 		exit(-2);
 	}
 
+	printf("Deleting any existing framework...\n");
+	target->deleteSearchFramework();
 	printf("Building framework, please wait...\n");
-	char error = target->createSearchFramework();
+	char lineLen = 70;
+	char error = target->createSearchFramework(&percentUpdate, &lineLen);
 	if (error) {
 		fprintf(stderr, "%s: couldn't create search framework (permissions?)\n", *argv);
 	}
