@@ -4,12 +4,6 @@
 #include <fstream>
 #include <string>
 
-#ifndef __GNUC__
-#include <io.h>
-#else
-#include <unistd.h>
-#endif
-
 #include <ztext.h>
 #include <zld.h>
 #include <zcom.h>
@@ -57,8 +51,13 @@ int main(int argc, char **argv)
 		if (find(values.begin(), values.end(), "On") != values.end()) {
 			mgr.setGlobalOption(it->c_str(), "On");
 		}
+		if (find(values.begin(), values.end(), "All Readings") != values.end()) {
+			mgr.setGlobalOption(it->c_str(), "All Readings");
+		}
 	}
 
+//	mgr.setGlobalOption("Strong's Numbers", "Off");
+//	mgr.setGlobalOption("Morphological Tags", "Off");
 
 	ModMap::iterator it = mgr.Modules.find(argv[1]);
 	if (it == mgr.Modules.end()) {
@@ -97,12 +96,17 @@ int main(int argc, char **argv)
 
 
 	cout << "<osis";
+		cout << " xmlns=\"http://www.bibletechnologies.net/2003/OSIS/namespace\"";
 		cout << " xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"";
-		cout << " xsi:noNamespaceSchemaLocation=\"http://www.bibletechnologies.net/osisCore.1.1.1.xsd\">\n\n";
+		cout << " xsi:schemaLocation=\"http://www.bibletechnologies.net/2003/OSIS/namespace osisCore.2.5.xsd\">\n\n";
 	cout << "<osisText";
 		cout << " osisIDWork=\"";
 		cout << inModule->Name() << "\"";
 		cout << " osisRefWork=\"defaultReferenceScheme\"";
+		if (inModule->Lang()) {
+			if (strlen(inModule->Lang()))
+				cout << " xml:lang=\"" << inModule->Lang() << "\"";
+		}
 		cout << ">\n\n";
 
 	cout << "\t<header>\n";
@@ -110,10 +114,6 @@ int main(int argc, char **argv)
 	cout << inModule->Name() << "\">\n";
 	cout << "\t\t\t<title>" << inModule->Description() << "</title>\n";
 	cout << "\t\t\t<identifier type=\"OSIS\">Bible." << inModule->Name() << "</identifier>\n";
-	if (inModule->Lang()) {
-		if (strlen(inModule->Lang()))
-			cout << "\t\t\t<language>" << inModule->Lang() << "</language>\n";
-	}
 	cout << "\t\t\t<refSystem>Bible.KJV</refSystem>\n";
 	cout << "\t\t</work>\n";
 	cout << "\t\t<work osisWork=\"defaultReferenceScheme\">\n";
@@ -145,7 +145,7 @@ int main(int argc, char **argv)
 				cout << "\t</div>\n";
 			if (opentest)
 				cout << "\t</div>\n";
-			cout << "\t<div type=\"testament\">\n";
+			cout << "\t<div type=\"x-testament\">\n";
 			opentest = true;
 			newTest = true;
 		}
@@ -183,16 +183,8 @@ int main(int argc, char **argv)
 			delete [] buf;
 			openchap = true;
 		}
-		/*
-		char *text = inModule->getRawEntry();
-		int len = (inModule->getEntrySize() + 1) * 15;
-		buf = new char [ len ];
-		memset(buf, 0, len);
-		memcpy(buf, inModule->getRawEntry(), inModule->getEntrySize());
-		filter.ProcessText(buf,  len - 3, vkey, inModule);
-		cout << buf << endl;
-		*/
-		cout << inModule->RenderText() << endl;
+		SWBuf verseText = inModule->RenderText();
+		cout << verseText.c_str() << endl;
 		lastChap = vkey->Chapter();
 		lastBook = vkey->Book();
 		lastTest = vkey->Testament();
